#include "appparameter.h"
#include <QDebug>
#include <QApplication>
#include <QGSettings>
#include <QFontDatabase>
#include <QIcon>
#include <QDBusConnection>

#include "settings/ukui-style-settings.h"
#include "../../qt5-ukui-platformtheme/platform-theme-fontdata.h"

using namespace UKUIQQC2Style;
APPParameter::APPParameter(QQuickItem *parent) : QQuickItem(parent)
{  
    if(!qApp)
        return;
    m_font = QApplication::font();
    m_palette = QApplication::palette();

    if (QGSettings::isSchemaInstalled("org.ukui.style")) {
        auto settings = UKUIStyleSettings::globalInstance();

        //set font
        auto fontName = settings->get("systemFont").toString();
        auto fontSize = settings->get("systemFontSize").toString().toDouble();
        if (qApp->property("noChangeSystemFontSize").isValid() && qApp->property("noChangeSystemFontSize").toBool())
            fontSize = 11;
        QFont tempFont = m_font;
        tempFont.setFamily(fontName);
        tempFont.setPointSizeF(fontSize);
        setFont(tempFont);
        /*!
         * \bug
         * if we set app font, qwizard title's font will
         * become very small. I handle the wizard title
         * in ProxyStyle::polish().
         */
        //Skip QGuiApplication avoid it crash when we setfont
        if (qApp->applicationName().toLower().contains(QLatin1String("kwin"))) {
            QDBusConnection::sessionBus().connect(QString(),
                                                  QStringLiteral("/UKUIPlatformTheme"),
                                                  QStringLiteral("org.ukui.UKUIPlatformTheme"),
                                                  QStringLiteral("refreshFonts"),
                                                  this,
                                                  SLOT(slotChangeStyle(QString)));
        }

        connect(settings, &QGSettings::changed, this, &APPParameter::slotChangeStyle);
    }

}

APPParameter::~APPParameter()
{

}

APPParameter* APPParameter::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new APPParameter(p);
}

const QFont &APPParameter::font() const
{
    return m_font;
}

void APPParameter::setFont(const QFont &newFont)
{
    if (m_font == newFont)
        return;
    m_font = newFont;
    emit fontChanged();
}

void APPParameter::slotChangeStyle(const QString& key)
{
    auto settings = UKUIStyleSettings::globalInstance();
//    if (key == "iconThemeName" || key == "icon-theme-name") {
//        QString icontheme = settings->get("icon-theme-name").toString();

//        QIcon::setThemeName(icontheme);

//        QIcon icon = qApp->windowIcon();
//        qApp->setWindowIcon(QIcon::fromTheme(icon.name()));
//        // update all widgets for repaint new themed icons.
//        for (auto widget : QApplication::allWidgets()) {
//            widget->update();
//        }
//    }

    if (key == "systemFont" || key == "system-font") {
        //Skip QGuiApplication avoid it crash when we setfont
        auto *app = qobject_cast<QApplication *>(qApp);
        if(app == nullptr)
            return;

        QString font = settings->get("system-font").toString();

        QFontDatabase db;
        int id = 0;
        if (!db.families().contains(font)) {
            PlatformThemeFontData fontData;
            QMap<QString, QString> fontMap = fontData.getAllFontInformation();
            if(fontMap.contains(font)){
                auto iter = fontMap.find(font);
                id = QFontDatabase::addApplicationFont(iter.value());
            }
        }

        QFontDatabase newDb;
        if (newDb.families().contains(font)) {
            QFont tempFont = font;
            setFont(tempFont);
        }
    }
    if (key == "systemFontSize" || key == "system-font-size") {
        //Skip QGuiApplication avoid it crash when we setfont
        auto *app = qobject_cast<QApplication *>(qApp);
        if(app == nullptr)
            return;

        if (qApp->property("noChangeSystemFontSize").isValid() && qApp->property("noChangeSystemFontSize").toBool())
            return;
        double fontSize = settings->get("system-font-size").toString().toDouble();
        if (fontSize > 0) {
            QFont oldFont = QApplication::font();

            QFont tempFont = m_font;
            tempFont.setPointSize(fontSize);
            setFont(tempFont);
        }
    }
}

const QPalette &APPParameter::palette() const
{
    return m_palette;
}


void APPParameter::setPalette(const QPalette &newPalette)
{
    if (m_palette == newPalette)
        return;
    m_palette = newPalette;
    emit paletteChanged();
}
