#include <QApplication>
#include "ukuibutton.h"
#include "qdebug.h"
using namespace UKUIQQC2Style;

UKUIButton::UKUIButton(QQuickItem *parent) : QQuickItem(parent)
{
    {
        m_normalBC         = DTColor(QColor("#E6E6E6"));
        m_clickedBC        = DTColor(QColor("#B9B9B9"));
        m_hoveredBC        = DTColor(QColor("#DCDCDC"));
        m_disableBC        = DTColor(QColor("#EEEEEE"));
        m_disableTextColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.35));
        m_normalTextColor  = DTColor(QColor::fromRgbF(0, 0, 0, 0.85));
        m_normalHBC        = DTColor(QColor("#3790FA"));
        m_clickedHBC       = DTColor(QColor("#3790FA"));
        m_hoveredHBC       = DTColor(QColor("#3790FA"));
        m_disableHBC       = DTColor(QColor("#EEEEEE"));
    }
    qDebug() << "UKUIButton..............";
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIButton::~UKUIButton()
{

}

UKUIButton* UKUIButton::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIButton(p);
}

void UKUIButton::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setNormalBC(instance->buttonActive());
    setClickedBC(instance->kComponentClick());
    //setHoveredBC(instance->kComponentHover());
    setDisableBC(instance->buttonDisable());

    setNormalHBC(instance->highLightActive());
    //setHoveredHBC(instance->kBrandHover());
    setClickedHBC(instance->kBrandClick());
    setDisableHBC(instance->highLightDisable());

    setNormalTextColor(instance->buttonTextActive());
    setDisableTextColor(instance->buttonTextDisable());

    setBorderWidth(1);
    setFocusBorderWidth(instance->focusline());
    setNormalBorderColor(instance->kLineComponentNormal());
    setClickBorderColor(instance->kLineComponentClick());
    setHoverBorderColor(instance->kLineComponentHover());
    setDisableBorderColor(instance->kLineComponentDisable());

    setNormalBorderHColor(instance->kLineBrandNormal());
    setClickBorderHColor(instance->kLineBrandClick());
    setHoverBorderHColor(instance->kLineBrandHover());
    setDisableBorderHColor(instance->kLineBrandDisable());
    setFocusBorderColor(instance->kBrandFocus());

//    qDebug() << "instance->highLightActive()..." << m_normalHBC.red() << m_normalHBC.green() << m_normalHBC.blue();
//    qDebug() << "instance->setHoveredHBC()..." << m_hoveredHBC.red() << m_hoveredHBC.green() << m_hoveredHBC.blue();
}


double UKUIButton::radius() const
{
    return m_radius;
}

void UKUIButton::setRadius(double newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}

double UKUIButton::leftRightMargin() const
{
    return m_leftRightMargin;
}

void UKUIButton::setLeftRightMargin(double newMargin)
{
    if (m_leftRightMargin == newMargin)
        return;
    m_leftRightMargin = newMargin;
    emit leftRightMarginChanged();
}

double UKUIButton::upDownMargin() const
{
    return m_upDownMargin;
}

void UKUIButton::setUpDownMargin(double newUpDownMargin)
{
    if (m_upDownMargin == newUpDownMargin)
        return;
    m_upDownMargin = newUpDownMargin;
    emit upDownMarginChanged();
}

double UKUIButton::space() const
{
    return m_space;
}

void UKUIButton::setSpace(double newSpace)
{
    if (qFuzzyCompare(m_space, newSpace))
        return;
    m_space = newSpace;
    emit spaceChanged();
}

int UKUIButton::normalWidth() const
{
    return m_normalWidth;
}

void UKUIButton::setNormalWidth(int newNormalWidth)
{
    if (m_normalWidth == newNormalWidth)
        return;
    m_normalWidth = newNormalWidth;
    emit normalWidthChanged();
}

int UKUIButton::normalHeight() const
{
    return m_normalHeight;
}

void UKUIButton::setNormalHeight(int newNormalHeight)
{
    if (m_normalHeight == newNormalHeight)
        return;
    m_normalHeight = newNormalHeight;
    emit normalHeightChanged();
}

DTColor UKUIButton::normalBC() const
{
    return m_normalBC;
}

void UKUIButton::setNormalBC(DTColor newNormalBC)
{
    if (m_normalBC != newNormalBC)
    {
        m_normalBC = newNormalBC;
        emit normalBCChanged();
    }
}

DTColor UKUIButton::clickedBC() const
{
    return m_clickedBC;
}

void UKUIButton::setClickedBC(DTColor newClickedBC)
{
    if (m_clickedBC != newClickedBC){
    m_clickedBC = newClickedBC;
    emit clickedBCChanged();
    }
}

DTColor UKUIButton::hoveredBC() const
{
    return m_hoveredBC;
}

void UKUIButton::setHoveredBC(DTColor newHoveredBC)
{
    if (m_hoveredBC != newHoveredBC){
        m_hoveredBC = newHoveredBC;
        emit hoveredBCChanged();
    }
}

DTColor UKUIButton::disableBC() const
{
    return m_disableBC;
}

void UKUIButton::setDisableBC(DTColor newDisableBC)
{
    if (m_disableBC != newDisableBC){
        m_disableBC = newDisableBC;
        emit disableBCChanged();
    }
}

DTColor UKUIButton::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUIButton::setDisableTextColor(DTColor newDisableTextColor)
{
    if (m_disableTextColor != newDisableTextColor){
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
    }
}

DTColor UKUIButton::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUIButton::setNormalTextColor(DTColor newNormalTextColor)
{
    if (m_normalTextColor != newNormalTextColor){
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
    }
}

DTColor UKUIButton::normalHBC() const
{
    return m_normalHBC;
}

void UKUIButton::setNormalHBC(DTColor newNormalHBC)
{
    if (m_normalHBC != newNormalHBC){
    m_normalHBC = newNormalHBC;
    emit normalHBCChanged();
    }
}

DTColor UKUIButton::clickedHBC() const
{
    return m_clickedHBC;
}

void UKUIButton::setClickedHBC(DTColor newClickedHBC)
{
    if (m_clickedHBC != newClickedHBC){
    m_clickedHBC = newClickedHBC;
    emit clickedHBCChanged();
    }
}

DTColor UKUIButton::hoveredHBC()
{
    return m_hoveredHBC;
}

void UKUIButton::setHoveredHBC(DTColor newHoveredHBC)
{
    if (m_hoveredHBC != newHoveredHBC){
    m_hoveredHBC = newHoveredHBC;
    emit hoveredHBCChanged();
    }
}

DTColor UKUIButton::disableHBC() const
{
    return m_disableHBC;
}

void UKUIButton::setDisableHBC(DTColor newDisableHBC)
{
    if (m_disableHBC != newDisableHBC){
    m_disableHBC = newDisableHBC;
    emit disableHBCChanged();
    }
}

int UKUIButton::borderWidth() const
{
    return m_borderWidth;
}

void UKUIButton::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

DTColor UKUIButton::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUIButton::setNormalBorderColor(DTColor newNormalBorderColor)
{
    if (m_normalBorderColor != newNormalBorderColor){
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
    }
}

DTColor UKUIButton::hoverBorderColor() const
{
    return m_hoverBorderColor;
}

void UKUIButton::setHoverBorderColor(DTColor newHoverBorderColor)
{
    if (m_hoverBorderColor != newHoverBorderColor){
    m_hoverBorderColor = newHoverBorderColor;
    emit hoverBorderColorChanged();
    }
}

DTColor UKUIButton::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUIButton::setClickBorderColor(DTColor newClickBorderColor)
{
    if (m_clickBorderColor!= newClickBorderColor){
    m_clickBorderColor = newClickBorderColor;
    emit clickBorderColorChanged();
    }
}

DTColor UKUIButton::disableBorderColor() const
{
    return m_disableBorderColor;
}

void UKUIButton::setDisableBorderColor(DTColor newDisableBorderColor)
{
    if (m_disableBorderColor != newDisableBorderColor){
    m_disableBorderColor = newDisableBorderColor;
    emit disableBorderColorChanged();
    }
}

DTColor UKUIButton::normalBorderHColor() const
{
    return m_normalBorderHColor;
}

void UKUIButton::setNormalBorderHColor(DTColor newNormalBorderHColor)
{
    if (m_normalBorderHColor != newNormalBorderHColor){
    m_normalBorderHColor = newNormalBorderHColor;
    emit normalBorderHColorChanged();
    }
}

DTColor UKUIButton::hoverBorderHColor() const
{
    return m_hoverBorderHColor;
}

void UKUIButton::setHoverBorderHColor(DTColor newHoverBorderHColor)
{
    if (m_hoverBorderHColor != newHoverBorderHColor){
    m_hoverBorderHColor = newHoverBorderHColor;
    emit hoverBorderHColorChanged();
    }
}

DTColor UKUIButton::clickBorderHColor() const
{
    return m_clickBorderHColor;
}

void UKUIButton::setClickBorderHColor(DTColor newClickBorderHColor)
{
    if (m_clickBorderHColor != newClickBorderHColor){
    m_clickBorderHColor = newClickBorderHColor;
    emit clickBorderHColorChanged();
    }
}

DTColor UKUIButton::disableBorderHColor() const
{
    return m_disableBorderHColor;
}

void UKUIButton::setDisableBorderHColor(DTColor newDisableBorderHColor)
{
    if (m_disableBorderHColor != newDisableBorderHColor){
    m_disableBorderHColor = newDisableBorderHColor;
    emit disableBorderHColorChanged();
    }
}

DTColor UKUIButton::focusBorderColor() const
{
    return m_focusBorderColor;
}

void UKUIButton::setFocusBorderColor(DTColor newFocusBorderColor)
{
    if (m_focusBorderColor != newFocusBorderColor){
    m_focusBorderColor = newFocusBorderColor;
    emit focusBorderColorChanged();
    }
}

int UKUIButton::focusBorderWidth() const
{
    return m_focusBorderWidth;
}

void UKUIButton::setFocusBorderWidth(int newFocusBorderWidth)
{
    if (m_focusBorderWidth == newFocusBorderWidth)
        return;
    m_focusBorderWidth = newFocusBorderWidth;
    emit focusBorderWidthChanged();
}
