/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUIBUTTON_H
#define UKUIBUTTON_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QQuickItem>
#include "tokenparameter.h"
#include "parsedtcolor.h"

using namespace UKUIGlobalDTConfig;
namespace UKUIQQC2Style {

class UKUIButton : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(double radius READ radius WRITE setRadius NOTIFY radiusChanged)
    Q_PROPERTY(double leftRightMargin READ leftRightMargin WRITE setLeftRightMargin NOTIFY leftRightMarginChanged)
    Q_PROPERTY(double upDownMargin READ upDownMargin WRITE setUpDownMargin NOTIFY upDownMarginChanged)
    Q_PROPERTY(double space READ space WRITE setSpace NOTIFY spaceChanged)
    Q_PROPERTY(int normalWidth READ normalWidth WRITE setNormalWidth NOTIFY normalWidthChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(DTColor normalBC READ normalBC WRITE setNormalBC NOTIFY normalBCChanged)
    Q_PROPERTY(DTColor clickedBC READ clickedBC WRITE setClickedBC NOTIFY clickedBCChanged)
    Q_PROPERTY(DTColor hoveredBC READ hoveredBC WRITE setHoveredBC NOTIFY hoveredBCChanged)
    Q_PROPERTY(DTColor disableBC READ disableBC WRITE setDisableBC NOTIFY disableBCChanged)
    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)
    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY normalTextColorChanged)


    Q_PROPERTY(DTColor normalHBC READ normalHBC WRITE setNormalHBC NOTIFY normalHBCChanged)
    Q_PROPERTY(DTColor clickedHBC READ clickedHBC WRITE setClickedHBC NOTIFY clickedHBCChanged)
    Q_PROPERTY(DTColor hoveredHBC READ hoveredHBC WRITE setHoveredHBC NOTIFY hoveredHBCChanged)
    Q_PROPERTY(DTColor disableHBC READ disableHBC WRITE setDisableHBC NOTIFY disableHBCChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(int focusBorderWidth READ focusBorderWidth WRITE setFocusBorderWidth NOTIFY focusBorderWidthChanged)
    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor hoverBorderColor READ hoverBorderColor WRITE setHoverBorderColor NOTIFY hoverBorderColorChanged)
    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickBorderColorChanged)
    Q_PROPERTY(DTColor disableBorderColor READ disableBorderColor WRITE setDisableBorderColor NOTIFY disableBorderColorChanged)
    Q_PROPERTY(DTColor focusBorderColor READ focusBorderColor WRITE setFocusBorderColor NOTIFY focusBorderColorChanged)

    Q_PROPERTY(DTColor normalBorderHColor READ normalBorderHColor WRITE setNormalBorderHColor NOTIFY normalBorderHColorChanged)
    Q_PROPERTY(DTColor hoverBorderHColor READ hoverBorderHColor WRITE setHoverBorderHColor NOTIFY hoverBorderHColorChanged)
    Q_PROPERTY(DTColor clickBorderHColor READ clickBorderHColor WRITE setClickBorderHColor NOTIFY clickBorderHColorChanged)
    Q_PROPERTY(DTColor disableBorderHColor READ disableBorderHColor WRITE setDisableBorderHColor NOTIFY disableBorderHColorChanged)

public:
    explicit UKUIButton(QQuickItem *parent = nullptr);
    ~UKUIButton();

    static UKUIButton* qmlAttachedProperties(QObject* parent);

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);
    double radius() const;
    void setRadius(double newRadius);

    double leftRightMargin() const;
    void setLeftRightMargin(double newMargin);

    double upDownMargin() const;
    void setUpDownMargin(double newUpDownMargin);

    double space() const;
    void setSpace(double newSpace);

    int normalWidth() const;
    void setNormalWidth(int newNormalWidth);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    Q_INVOKABLE DTColor normalBC() const;
    void setNormalBC(DTColor newNormalBC);

    Q_INVOKABLE DTColor clickedBC() const;
    void setClickedBC(DTColor newClickedBC);

    Q_INVOKABLE DTColor hoveredBC() const;
    void setHoveredBC(DTColor newHoveredBC);

    Q_INVOKABLE DTColor disableBC() const;
    void setDisableBC(DTColor newDisableBC);

    Q_INVOKABLE DTColor disableTextColor() const;
    void setDisableTextColor(DTColor newDisableTextColor);

    Q_INVOKABLE DTColor normalTextColor() const;
    void setNormalTextColor(DTColor newNormalTextColor);

    Q_INVOKABLE DTColor normalHBC() const;
    void setNormalHBC(DTColor newNormalHBC);

    Q_INVOKABLE DTColor clickedHBC() const;
    void setClickedHBC(DTColor newClickedHBC);

    Q_INVOKABLE DTColor hoveredHBC();
    void setHoveredHBC(DTColor newHoveredHBC);

    Q_INVOKABLE DTColor disableHBC() const;
    void setDisableHBC(DTColor newDisableHBC);
    
    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);
    
    Q_INVOKABLE DTColor normalBorderColor() const;
    void setNormalBorderColor(DTColor newNormalBorderColor);
    
    Q_INVOKABLE DTColor hoverBorderColor() const;
    void setHoverBorderColor(DTColor newHoverBorderColor);
    
    Q_INVOKABLE DTColor clickBorderColor() const;
    void setClickBorderColor(DTColor newClickBorderColor);
    
    Q_INVOKABLE DTColor disableBorderColor() const;
    void setDisableBorderColor(DTColor newDisableBorderColor);
    
    Q_INVOKABLE DTColor normalBorderHColor() const;
    void setNormalBorderHColor(DTColor newNormalBorderHColor);

    Q_INVOKABLE DTColor hoverBorderHColor() const;
    void setHoverBorderHColor(DTColor newHoverBorderHColor);

    Q_INVOKABLE DTColor clickBorderHColor() const;
    void setClickBorderHColor(DTColor newClickBorderHColor);

    Q_INVOKABLE DTColor disableBorderHColor() const;
    void setDisableBorderHColor(DTColor newDisableBorderHColor);

    Q_INVOKABLE DTColor focusBorderColor() const;
    void setFocusBorderColor(DTColor newFocusBorderColor);

    int focusBorderWidth() const;
    void setFocusBorderWidth(int newFocusBorderWidth);

signals:
    void radiusChanged();

    void leftRightMarginChanged();

    void upDownMarginChanged();

    void spaceChanged();

    void normalWidthChanged();

    void normalHeightChanged();

    void normalBCChanged();

    void clickedBCChanged();

    void hoveredBCChanged();

    void disableBCChanged();

    void disableTextColorChanged();

    void normalHBCChanged();

    void clickedHBCChanged();

    void hoveredHBCChanged();

    void disableHBCChanged();
    
    void borderWidthChanged();
    
    void normalBorderColorChanged();
    
    void hoverBorderColorChanged();
    
    void clickBorderColorChanged();
    
    void disableBorderColorChanged();
    
    void normalBorderHColorChanged();

    void hoverBorderHColorChanged();

    void clickBorderHColorChanged();

    void disableBorderHColorChanged();

    void focusBorderColorChanged();

    void focusBorderWidthChanged();

    void normalTextColorChanged();

private:
    double m_radius = 6.0;
    double m_leftRightMargin = 10.0;
    double m_upDownMargin = 10.0;
    double m_space = 4.0;
    int m_normalWidth = 96;
    int m_normalHeight = 36;
    int m_borderWidth;
    int m_focusBorderWidth;

    DTColor m_normalBC            ;
    DTColor m_clickedBC           ;
    DTColor m_hoveredBC           ;
    DTColor m_disableBC           ;
    DTColor m_disableTextColor    ;
    DTColor m_normalTextColor     ;
    DTColor m_normalHBC           ;
    DTColor m_clickedHBC          ;
    DTColor m_hoveredHBC          ;
    DTColor m_disableHBC          ;
    DTColor m_normalBorderColor   ;
    DTColor m_hoverBorderColor    ;
    DTColor m_clickBorderColor    ;
    DTColor m_disableBorderColor  ;
    DTColor m_normalBorderHColor  ;
    DTColor m_hoverBorderHColor   ;
    DTColor m_clickBorderHColor   ;
    DTColor m_disableBorderHColor ;
    DTColor m_focusBorderColor    ;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance ;
};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIButton, QML_HAS_ATTACHED_PROPERTIES)

//Q_DECLARE_METATYPE(UKUIQQC2Style::UKUIButton);
//Q_DECLARE_METATYPE(std::shared_ptr<UKUIQQC2Style::UKUIButton>)

#endif // UKUIBUTTON_H
