#include <QApplication>
#include "ukuicheckbox.h"
#include "qdebug.h"
using namespace UKUIQQC2Style;

UKUICheckBox::UKUICheckBox(QQuickItem *parent) : QQuickItem(parent)
{
    qDebug() << "UKUICheckBox..............";
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUICheckBox::~UKUICheckBox()
{

}

UKUICheckBox* UKUICheckBox::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUICheckBox(p);
}

void UKUICheckBox::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setNormalTextColor(instance->kFontPrimary());
    setDisableTextColor(instance->kFontPrimaryDisable());
    setNormalIndicatorColor(instance->buttonActive());
    setHoverIndicatorColor(instance->kComponentHover());
    setClickIndicatorColor(instance->kComponentClick());
    setDisableIndicatorColor(instance->buttonDisable());
    setNormalIndicatorBorderColor(instance->kLineNormal());
    setHoverIndicatorBorderColor(instance->kLineNormal());
    setClickIndicatorBorderColor(instance->kLineNormal());
    setDisableIndicatorBorderColor(instance->kLineDisable());

    setChecked_NormalIndicatorColor(instance->highLightActive());
    setChecked_HoverIndicatorColor(instance->kBrandHover());
    setChecked_ClickIndicatorColor(instance->kBrandClick());
    setChecked_DisableIndicatorColor(instance->buttonDisable());
    setChecked_NormalIndicatorBorderColor(instance->kLineNormal());
    setChecked_HoverIndicatorBorderColor(instance->kLineNormal());
    setChecked_ClickIndicatorBorderColor(instance->kLineNormal());
    setChecked_DisableIndicatorBorderColor(instance->kLineDisable());

    setChecked_NormalChildrenColor(instance->highLightedTextActive());
    setChecked_HoverChildrenColor(instance->highLightedTextActive());
    setChecked_ClickChildrenColor(instance->highLightedTextActive());
    setChecked_DisableChildrenColor(instance->highLightedTextDisable());

    setBorderWidth(instance->normalline());
    setSpace(8);
    setIndicatorWidth(16);
    setChildrenWidth(8);
    setRadius(instance->kradiusMin());
}



double UKUICheckBox::leftRightMargin() const
{
    return m_leftRightMargin;
}

void UKUICheckBox::setLeftRightMargin(double newLeftRightMargin)
{
    if (qFuzzyCompare(m_leftRightMargin, newLeftRightMargin))
        return;
    m_leftRightMargin = newLeftRightMargin;
    emit leftRightMarginChanged();
}

double UKUICheckBox::upDownMargin() const
{
    return m_upDownMargin;
}

void UKUICheckBox::setUpDownMargin(double newUpDownMargin)
{
    if (qFuzzyCompare(m_upDownMargin, newUpDownMargin))
        return;
    m_upDownMargin = newUpDownMargin;
    emit upDownMarginChanged();
}

double UKUICheckBox::space() const
{
    return m_space;
}

void UKUICheckBox::setSpace(double newSpace)
{
    if (qFuzzyCompare(m_space, newSpace))
        return;
    m_space = newSpace;
    emit spaceChanged();
}

DTColor UKUICheckBox::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUICheckBox::setDisableTextColor(DTColor newDisableTextColor)
{
    if (m_disableTextColor != newDisableTextColor){
        m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
    }
}

DTColor UKUICheckBox::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUICheckBox::setNormalTextColor(DTColor newNormalTextColor)
{
    if (m_normalTextColor != newNormalTextColor){
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
    }
}

DTColor UKUICheckBox::normalIndicatorColor() const
{
    return m_normalIndicatorColor;
}

void UKUICheckBox::setNormalIndicatorColor(DTColor newNormalIndicatorColor)
{
    if (m_normalIndicatorColor != newNormalIndicatorColor){
    m_normalIndicatorColor = newNormalIndicatorColor;
    emit normalIndicatorColorChanged();
    }
}

DTColor UKUICheckBox::hoverIndicatorColor() const
{
    return m_hoverIndicatorColor;
}

void UKUICheckBox::setHoverIndicatorColor(DTColor newHoverIndicatorColor)
{
    if (m_hoverIndicatorColor != newHoverIndicatorColor){
    m_hoverIndicatorColor = newHoverIndicatorColor;
    emit hoverIndicatorColorChanged();
    }
}

DTColor UKUICheckBox::clickIndicatorColor() const
{
    return m_clickIndicatorColor;
}

void UKUICheckBox::setClickIndicatorColor(DTColor newClickIndicatorColor)
{
    if (m_clickIndicatorColor != newClickIndicatorColor){
    m_clickIndicatorColor = newClickIndicatorColor;
    emit clickIndicatorColorChanged();
    }
}

DTColor UKUICheckBox::disableIndicatorColor() const
{
    return m_disableIndicatorColor;
}

void UKUICheckBox::setDisableIndicatorColor(DTColor newDisableIndicatorColor)
{
    if (m_disableIndicatorColor != newDisableIndicatorColor){
    m_disableIndicatorColor = newDisableIndicatorColor;
    emit disableIndicatorColorChanged();
    }
}

DTColor UKUICheckBox::normalIndicatorBorderColor() const
{
    return m_normalIndicatorBorderColor;
}

void UKUICheckBox::setNormalIndicatorBorderColor(DTColor newNormalIndicatorBorderColor)
{
    if (m_normalIndicatorBorderColor != newNormalIndicatorBorderColor){
    m_normalIndicatorBorderColor = newNormalIndicatorBorderColor;
    emit normalIndicatorBorderColorChanged();
    }
}

DTColor UKUICheckBox::hoverIndicatorBorderColor() const
{
    return m_hoverIndicatorBorderColor;
}

void UKUICheckBox::setHoverIndicatorBorderColor(DTColor newHoverIndicatorBorderColor)
{
    if (m_hoverIndicatorBorderColor != newHoverIndicatorBorderColor){
    m_hoverIndicatorBorderColor = newHoverIndicatorBorderColor;
    emit hoverIndicatorBorderColorChanged();
    }
}

DTColor UKUICheckBox::clickIndicatorBorderColor() const
{
    return m_clickIndicatorBorderColor;
}

void UKUICheckBox::setClickIndicatorBorderColor(DTColor newClickIndicatorBorderColor)
{
    if (m_clickIndicatorBorderColor != newClickIndicatorBorderColor){
    m_clickIndicatorBorderColor = newClickIndicatorBorderColor;
    emit clickIndicatorBorderColorChanged();
    }
}

DTColor UKUICheckBox::disableIndicatorBorderColor() const
{
    return m_disableIndicatorBorderColor;
}

void UKUICheckBox::setDisableIndicatorBorderColor(DTColor newDisableIndicatorBorderColor)
{
    if (m_disableIndicatorBorderColor != newDisableIndicatorBorderColor){
    m_disableIndicatorBorderColor = newDisableIndicatorBorderColor;
    emit disableIndicatorBorderColorChanged();
    }
}

DTColor UKUICheckBox::checked_normalIndicatorColor() const
{
    return m_checked_normalIndicatorColor;
}

DTColor UKUICheckBox::checked_hoverIndicatorColor() const
{
    return m_checked_hoverIndicatorColor;
}

DTColor UKUICheckBox::checked_clickIndicatorColor() const
{
    return m_checked_clickIndicatorColor;
}

DTColor UKUICheckBox::checked_disableIndicatorColor() const
{
    return m_checked_disableIndicatorColor;
}

DTColor UKUICheckBox::checked_normalIndicatorBorderColor() const
{
    return m_checked_normalIndicatorBorderColor;
}

DTColor UKUICheckBox::checked_hoverIndicatorBorderColor() const
{
    return m_checked_hoverIndicatorBorderColor;
}

DTColor UKUICheckBox::checked_clickIndicatorBorderColor() const
{
    return m_checked_clickIndicatorBorderColor;
}

DTColor UKUICheckBox::checked_disableIndicatorBorderColor() const
{
    return m_checked_disableIndicatorBorderColor;
}

DTColor UKUICheckBox::checked_normalChildrenColor() const
{
    return m_checked_normalChildrenColor;
}

DTColor UKUICheckBox::checked_hoverChildrenColor() const
{
    return m_checked_hoverChildrenColor;
}

DTColor UKUICheckBox::checked_clickChildrenColor() const
{
    return m_checked_clickChildrenColor;
}


DTColor UKUICheckBox::checked_disableChildrenColor() const
{
    return m_checked_disableChildrenColor;
}

DTColor UKUICheckBox::checked_normalChildrenBorderColor() const
{
    return m_checked_normalChildrenBorderColor;
}

DTColor UKUICheckBox::checked_hoverChildrenBorderColor() const
{
    return m_checked_hoverChildrenBorderColor;
}

DTColor UKUICheckBox::checked_clickChildrenBorderColor() const
{
    return m_checked_clickChildrenBorderColor;
}


DTColor UKUICheckBox::checked_disableChildrenBorderColor() const
{
    return m_checked_disableChildrenBorderColor;
}


void UKUICheckBox::setChecked_NormalIndicatorColor(DTColor newChecked_normalIndicatorColor)
{
    if (m_checked_normalIndicatorColor != newChecked_normalIndicatorColor){
    m_checked_normalIndicatorColor = newChecked_normalIndicatorColor;
    emit checked_normalIndicatorColorChanged();
    }
}

void UKUICheckBox::setChecked_HoverIndicatorColor(DTColor newChecked_hoverIndicatorColor)
{
    if (m_checked_hoverIndicatorColor != newChecked_hoverIndicatorColor){
    m_checked_hoverIndicatorColor = newChecked_hoverIndicatorColor;
    emit checked_hoverIndicatorColorChanged();
    }
}

void UKUICheckBox::setChecked_ClickIndicatorColor(DTColor newChecked_clickIndicatorColor)
{
    if (m_checked_clickIndicatorColor != newChecked_clickIndicatorColor){
    m_checked_clickIndicatorColor = newChecked_clickIndicatorColor;
    emit checked_clickIndicatorColorChanged();
    }
}

void UKUICheckBox::setChecked_DisableIndicatorColor(DTColor newChecked_disableIndicatorColor)
{
    if (m_checked_disableIndicatorColor != newChecked_disableIndicatorColor){
    m_checked_disableIndicatorColor = newChecked_disableIndicatorColor;
    emit checked_disableIndicatorColorChanged();
    }
}

void UKUICheckBox::setChecked_NormalIndicatorBorderColor(DTColor newChecked_normalIndicatorBorderColor)
{
    if (m_checked_normalIndicatorBorderColor != newChecked_normalIndicatorBorderColor){
    m_checked_normalIndicatorBorderColor = newChecked_normalIndicatorBorderColor;
    emit checked_normalIndicatorBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_HoverIndicatorBorderColor(DTColor newChecked_hoverIndicatorBorderColor)
{
    if (m_checked_hoverIndicatorBorderColor != newChecked_hoverIndicatorBorderColor){
    m_checked_hoverIndicatorBorderColor = newChecked_hoverIndicatorBorderColor;
    emit checked_hoverIndicatorBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_ClickIndicatorBorderColor(DTColor newChecked_clickIndicatorBorderColor)
{
    if (m_checked_clickIndicatorBorderColor != newChecked_clickIndicatorBorderColor){
    m_checked_clickIndicatorBorderColor = newChecked_clickIndicatorBorderColor;
    emit checked_clickIndicatorBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_DisableIndicatorBorderColor(DTColor newChecked_disableIndicatorBorderColor)
{
    if (m_checked_disableIndicatorBorderColor != newChecked_disableIndicatorBorderColor){
    m_checked_disableIndicatorBorderColor = newChecked_disableIndicatorBorderColor;
    emit checked_disableIndicatorBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_NormalChildrenColor(DTColor newChecked_normalChildrenColor)
{
    if (m_checked_normalChildrenColor != newChecked_normalChildrenColor){
    m_checked_normalChildrenColor = newChecked_normalChildrenColor;
    emit checked_normalChildrenColorChanged();
    }
}

void UKUICheckBox::setChecked_HoverChildrenColor(DTColor newChecked_hoverChildrenColor)
{
    if (m_checked_hoverChildrenColor != newChecked_hoverChildrenColor){
    m_checked_hoverChildrenColor = newChecked_hoverChildrenColor;
    emit checked_hoverChildrenColorChanged();
    }
}

void UKUICheckBox::setChecked_ClickChildrenColor(DTColor newChecked_clickChildrenColor)
{
    if (m_checked_clickChildrenColor != newChecked_clickChildrenColor){
    m_checked_clickChildrenColor = newChecked_clickChildrenColor;
    emit checked_clickChildrenColorChanged();
    }
}

void UKUICheckBox::setChecked_DisableChildrenColor(DTColor newChecked_disableChildrenColor)
{
    if (m_checked_disableChildrenColor != newChecked_disableChildrenColor){
    m_checked_disableChildrenColor = newChecked_disableChildrenColor;
    emit checked_disableChildrenColorChanged();
    }
}

void UKUICheckBox::setChecked_NormalChildrenBorderColor(DTColor newChecked_normalChildrenBorderColor)
{
    if (m_checked_normalChildrenBorderColor != newChecked_normalChildrenBorderColor){
    m_checked_normalChildrenBorderColor = newChecked_normalChildrenBorderColor;
    emit checked_normalChildrenBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_HoverChildrenBorderColor(DTColor newChecked_hoverChildrenBorderColor)
{
    if (m_checked_hoverChildrenBorderColor != newChecked_hoverChildrenBorderColor){
    m_checked_hoverChildrenBorderColor = newChecked_hoverChildrenBorderColor;
    emit checked_hoverChildrenBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_ClickChildrenBorderColor(DTColor newChecked_clickChildrenBorderColor)
{
    if (m_checked_clickChildrenBorderColor != newChecked_clickChildrenBorderColor){
    m_checked_clickChildrenBorderColor = newChecked_clickChildrenBorderColor;
    emit checked_clickChildrenBorderColorChanged();
    }
}

void UKUICheckBox::setChecked_DisableChildrenBorderColor(DTColor newChecked_disableChildrenBorderColor)
{
    if (m_checked_disableChildrenBorderColor != newChecked_disableChildrenBorderColor){
    m_checked_disableChildrenBorderColor = newChecked_disableChildrenBorderColor;
    emit checked_disableChildrenBorderColorChanged();
    }
}

int UKUICheckBox::borderWidth() const
{
    return m_borderWidth;
}

void UKUICheckBox::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

int UKUICheckBox::indicatorWidth() const
{
    return m_indicatorWidth;
}

void UKUICheckBox::setIndicatorWidth(int newIndicatorWidth)
{
    if (m_indicatorWidth == newIndicatorWidth)
        return;
    m_indicatorWidth = newIndicatorWidth;
    emit indicatorWidthChanged();
}

int UKUICheckBox::childrenWidth() const
{
    return m_childrenWidth;
}

void UKUICheckBox::setChildrenWidth(int newChildrenWidth)
{
    if (m_childrenWidth == newChildrenWidth)
        return;
    m_childrenWidth = newChildrenWidth;
    emit childrenWidthChanged();
}

int UKUICheckBox::radius() const
{
    return m_radius;
}

void UKUICheckBox::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}
