#include <QApplication>
#include "ukuicombobox.h"
#include "qdebug.h"
using namespace UKUIQQC2Style;

UKUIComboBox::UKUIComboBox(QQuickItem *parent) : QQuickItem(parent)
{
    qDebug() << "UKUIComboBox..............";
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIComboBox::~UKUIComboBox()
{

}

UKUIComboBox* UKUIComboBox::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIComboBox(p);
}

void UKUIComboBox::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setLeftRightPadding(instance->kmarginNormal());
    setRadius(instance->kradiusNormal());
    setBorderWidth(instance->normalline());
    setFocusBorderWidth(instance->focusline());
    setNormalWidth(240);
    setNormalHeight(36);
    setNormalBC(instance->buttonActive());
    setNormalBorderColor(instance->kLineComponentNormal());
    setDisableBorderColor(instance->kLineComponentDisable());
    setFocusBorderColor(instance->kBrandFocus());
    setNormalTextColor(instance->buttonTextActive());
    setDisableTextColor(instance->buttonTextDisable());
}

double UKUIComboBox::radius() const
{
    return m_radius;
}

void UKUIComboBox::setRadius(double newRadius)
{
    if (qFuzzyCompare(m_radius, newRadius))
        return;
    m_radius = newRadius;
    emit radiusChanged();
}

double UKUIComboBox::leftRightPadding() const
{
    return m_leftRightPadding;
}

void UKUIComboBox::setLeftRightPadding(double newLeftRightPadding)
{
    if (qFuzzyCompare(m_leftRightPadding, newLeftRightPadding))
        return;
    m_leftRightPadding = newLeftRightPadding;
    emit leftRightPaddingChanged();
}

double UKUIComboBox::upDownMargin() const
{
    return m_upDownMargin;
}

void UKUIComboBox::setUpDownMargin(double newUpDownMargin)
{
    if (qFuzzyCompare(m_upDownMargin, newUpDownMargin))
        return;
    m_upDownMargin = newUpDownMargin;
    emit upDownMarginChanged();
}

double UKUIComboBox::space() const
{
    return m_space;
}

void UKUIComboBox::setSpace(double newSpace)
{
    if (qFuzzyCompare(m_space, newSpace))
        return;
    m_space = newSpace;
    emit spaceChange();
}

int UKUIComboBox::normalWidth() const
{
    return m_normalWidth;
}

void UKUIComboBox::setNormalWidth(int newNormalWidth)
{
    if (m_normalWidth == newNormalWidth)
        return;
    m_normalWidth = newNormalWidth;
    emit normalWidthChanged();
}

int UKUIComboBox::normalHeight() const
{
    return m_normalHeight;
}

void UKUIComboBox::setNormalHeight(int newNormalHeight)
{
    if (m_normalHeight == newNormalHeight)
        return;
    m_normalHeight = newNormalHeight;
    emit normalHeightChanged();
}

DTColor UKUIComboBox::normalBC() const
{
    return m_normalBC;
}

void UKUIComboBox::setNormalBC(DTColor newNormalBC)
{
    if (m_normalBC !=newNormalBC){
    m_normalBC = newNormalBC;
    emit normalBCChanged();
    }
}

DTColor UKUIComboBox::clickedBC() const
{
    return m_clickedBC;
}

void UKUIComboBox::setClickedBC(DTColor newClickedBC)
{
    if (m_clickedBC != newClickedBC){
    m_clickedBC = newClickedBC;
    emit clickedBCChanged();
    }
}

DTColor UKUIComboBox::hoveredBC() const
{
    return m_hoveredBC;
}

void UKUIComboBox::setHoveredBC(DTColor newHoveredBC)
{
    if (m_hoveredBC != newHoveredBC){
    m_hoveredBC = newHoveredBC;
    emit hoveredBCChanged();
    }
}

DTColor UKUIComboBox::disableBC() const
{
    return m_disableBC;
}

void UKUIComboBox::setDisableBC(DTColor newDisableBC)
{
    if (m_disableBC != newDisableBC){
    m_disableBC = newDisableBC;
    emit disableBCChanged();
    }
}

DTColor UKUIComboBox::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUIComboBox::setDisableTextColor(DTColor newDisableTextColor)
{
    if (m_disableTextColor != newDisableTextColor){
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
    }
}

DTColor UKUIComboBox::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUIComboBox::setNormalTextColor(DTColor newNormalTextColor)
{
    if (m_normalTextColor != newNormalTextColor){
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
    }
}

int UKUIComboBox::borderWidth() const
{
    return m_borderWidth;
}

void UKUIComboBox::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

int UKUIComboBox::focusBorderWidth() const
{
    return m_focusBorderWidth;
}

void UKUIComboBox::setFocusBorderWidth(int newFocusBorderWidth)
{
    if (m_focusBorderWidth == newFocusBorderWidth)
        return;
    m_focusBorderWidth = newFocusBorderWidth;
    emit focusBorderWidthChanged();
}

DTColor UKUIComboBox::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUIComboBox::setNormalBorderColor(DTColor newNormalBorderColor)
{
    if (m_normalBorderColor != newNormalBorderColor){
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
    }
}

DTColor UKUIComboBox::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUIComboBox::setClickBorderColor(DTColor newClickBorderColor)
{
    if (m_clickBorderColor != newClickBorderColor){
    m_clickBorderColor = newClickBorderColor;
    emit clickBorderColorChanged();
    }
}

DTColor UKUIComboBox::disableBorderColor() const
{
    return m_disableBorderColor;
}

void UKUIComboBox::setDisableBorderColor(DTColor newDisableBorderColor)
{
    if (m_disableBorderColor != newDisableBorderColor){
    m_disableBorderColor = newDisableBorderColor;
    emit disableBorderColorChanged();
    }
}

DTColor UKUIComboBox::focusBorderColor() const
{
    return m_focusBorderColor;
}

void UKUIComboBox::setFocusBorderColor(DTColor newFocusBorderColor)
{
    if (m_focusBorderColor != newFocusBorderColor){
    m_focusBorderColor = newFocusBorderColor;
    emit focusBorderColorChanged();
    }
}
