/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUICOMBOBOX_H
#define UKUICOMBOBOX_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIComboBox : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(double radius READ radius WRITE setRadius NOTIFY radiusChanged)
    Q_PROPERTY(double leftRightPadding READ leftRightPadding WRITE setLeftRightPadding NOTIFY leftRightPaddingChanged)
    Q_PROPERTY(double upDownMargin READ upDownMargin WRITE setUpDownMargin NOTIFY upDownMarginChanged)
    Q_PROPERTY(double space READ space WRITE setSpace NOTIFY spaceChange)

    Q_PROPERTY(int normalWidth READ normalWidth WRITE setNormalWidth NOTIFY normalWidthChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(DTColor normalBC READ normalBC WRITE setNormalBC NOTIFY normalBCChanged)
    Q_PROPERTY(DTColor clickedBC READ clickedBC WRITE setClickedBC NOTIFY clickedBCChanged)
    Q_PROPERTY(DTColor hoveredBC READ hoveredBC WRITE setHoveredBC NOTIFY hoveredBCChanged)
    Q_PROPERTY(DTColor disableBC READ disableBC WRITE setDisableBC NOTIFY disableBCChanged)
    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)
    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY normalTextColorChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(int focusBorderWidth READ focusBorderWidth WRITE setFocusBorderWidth NOTIFY focusBorderWidthChanged)
    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickBorderColorChanged)
    Q_PROPERTY(DTColor disableBorderColor READ disableBorderColor WRITE setDisableBorderColor NOTIFY disableBorderColorChanged)
    Q_PROPERTY(DTColor focusBorderColor READ focusBorderColor WRITE setFocusBorderColor NOTIFY focusBorderColorChanged)


public:
    explicit UKUIComboBox(QQuickItem *parent = nullptr);
    ~UKUIComboBox();

    static UKUIComboBox* qmlAttachedProperties(QObject* parent);

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);


    double radius() const;
    void setRadius(double newRadius);

    double leftRightPadding() const;
    void setLeftRightPadding(double newLeftRightPadding);

    double upDownMargin() const;
    void setUpDownMargin(double newUpDownMargin);

    double space() const;
    void setSpace(double newSpace);

    int normalWidth() const;
    void setNormalWidth(int newNormalWidth);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    Q_INVOKABLE DTColor normalBC() const;
    void setNormalBC(DTColor newNormalBC);

    Q_INVOKABLE DTColor clickedBC() const;
    void setClickedBC(DTColor newClickedBC);

    Q_INVOKABLE DTColor hoveredBC() const;
    void setHoveredBC(DTColor newHoveredBC);

    Q_INVOKABLE DTColor disableBC() const;
    void setDisableBC(DTColor newDisableBC);

    Q_INVOKABLE DTColor disableTextColor() const;
    void setDisableTextColor(DTColor newDisableTextColor);

    Q_INVOKABLE DTColor normalTextColor() const;
    void setNormalTextColor(DTColor newNormalTextColor);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    int focusBorderWidth() const;
    void setFocusBorderWidth(int newFocusBorderWidth);

    Q_INVOKABLE DTColor normalBorderColor() const;
    void setNormalBorderColor(DTColor newNormalBorderColor);

    Q_INVOKABLE DTColor clickBorderColor() const;
    void setClickBorderColor(DTColor newClickBorderColor);

    Q_INVOKABLE DTColor disableBorderColor() const;
    void setDisableBorderColor(DTColor newDisableBorderColor);

    Q_INVOKABLE DTColor focusBorderColor() const;
    void setFocusBorderColor(DTColor newFocusBorderColor);

signals:

    void radiusChanged();

    void leftRightPaddingChanged();

    void upDownMarginChanged();

    void spaceChange();

    void normalWidthChanged();

    void normalHeightChanged();

    void normalBCChanged();

    void clickedBCChanged();

    void hoveredBCChanged();

    void disableBCChanged();

    void disableTextColorChanged();

    void normalTextColorChanged();

    void borderWidthChanged();

    void focusBorderWidthChanged();

    void normalBorderColorChanged();

    void clickBorderColorChanged();

    void disableBorderColorChanged();

    void focusBorderColorChanged();

private:

    double m_radius;
    double m_leftRightPadding;
    double m_upDownMargin;
    double m_space;
    int m_normalWidth;
    int m_normalHeight;
    int m_borderWidth;
    int m_focusBorderWidth;

    Q_INVOKABLE DTColor m_normalBC           ;
    Q_INVOKABLE DTColor m_clickedBC          ;
    Q_INVOKABLE DTColor m_hoveredBC          ;
    Q_INVOKABLE DTColor m_disableBC          ;
    Q_INVOKABLE DTColor m_disableTextColor   ;
    Q_INVOKABLE DTColor m_normalTextColor    ;
    Q_INVOKABLE DTColor m_normalBorderColor  ;
    Q_INVOKABLE DTColor m_clickBorderColor   ;
    Q_INVOKABLE DTColor m_disableBorderColor ;
    Q_INVOKABLE DTColor m_focusBorderColor   ;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance ;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIComboBox, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUICOMBOBOX_H
