#include "ukuiitemdelegate.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUIItemDelegate::UKUIItemDelegate(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIItemDelegate::~UKUIItemDelegate()
{

}

void UKUIItemDelegate::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setRadius(instance->kradiusNormal());
    setNormalTextColor(instance->textActive());
    setDisableTextColor(instance->textDisable());

    setNormalBC(DTColor(QColor(0,0,0,0)));
    setClickedBC(instance->kContainClick());
    setHoveredBC(instance->kContainHover());
    setDisableBC(DTColor(QColor(0,0,0,0)));

    setBorderWidth(1);
    setNormalBorderColor(instance->kLineComponentNormal());
    setClickBorderColor(instance->kLineComponentClick());
    setHoverBorderColor(instance->kLineComponentHover());
    setDisableBorderColor(instance->kLineComponentDisable());

}


UKUIItemDelegate* UKUIItemDelegate::qmlAttachedProperties(QObject *parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIItemDelegate(p);
}

DTColor UKUIItemDelegate::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUIItemDelegate::setNormalTextColor(DTColor newNormalTextColor)
{
    if (m_normalTextColor == newNormalTextColor)
        return;
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
}

DTColor UKUIItemDelegate::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUIItemDelegate::setDisableTextColor(DTColor newDisableTextColor)
{
    if (m_disableTextColor == newDisableTextColor)
        return;
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
}

DTColor UKUIItemDelegate::normalBC() const
{
    return m_normalBC;
}

void UKUIItemDelegate::setNormalBC(DTColor newNormalBC)
{
    if (m_normalBC == newNormalBC)
        return;
    m_normalBC = newNormalBC;
    emit normalBCChanged();
}

DTColor UKUIItemDelegate::clickedBC() const
{
    return m_clickedBC;
}

void UKUIItemDelegate::setClickedBC(DTColor newClickedBC)
{
    if (m_clickedBC == newClickedBC)
        return;
    m_clickedBC = newClickedBC;
    emit clickedBCChanged();
}

DTColor UKUIItemDelegate::hoveredBC() const
{
    return m_hoveredBC;
}

void UKUIItemDelegate::setHoveredBC(DTColor newHoveredBC)
{
    if (m_hoveredBC == newHoveredBC)
        return;
    m_hoveredBC = newHoveredBC;
    emit hoveredBCChanged();
}

DTColor UKUIItemDelegate::disableBC() const
{
    return m_disableBC;
}

void UKUIItemDelegate::setDisableBC(DTColor newDisableBC)
{
    if (m_disableBC == newDisableBC)
        return;
    m_disableBC = newDisableBC;
    emit disableBCChanged();
}

int UKUIItemDelegate::radius() const
{
    return m_radius;
}

void UKUIItemDelegate::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}

int UKUIItemDelegate::borderWidth() const
{
    return m_borderWidth;
}

void UKUIItemDelegate::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

DTColor UKUIItemDelegate::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUIItemDelegate::setNormalBorderColor(DTColor newNormalBorderColor)
{
    if (m_normalBorderColor == newNormalBorderColor)
        return;
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
}

DTColor UKUIItemDelegate::hoverBorderColor() const
{
    return m_hoverBorderColor;
}

void UKUIItemDelegate::setHoverBorderColor(DTColor newHoverBorderColor)
{
    if (m_hoverBorderColor == newHoverBorderColor)
        return;
    m_hoverBorderColor = newHoverBorderColor;
    emit hoverBorderColorChanged();
}

DTColor UKUIItemDelegate::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUIItemDelegate::setClickBorderColor(DTColor newClickBorderColor)
{
    if (m_clickBorderColor == newClickBorderColor)
        return;
    m_clickBorderColor = newClickBorderColor;
    emit clickBorderColorChanged();
}

DTColor UKUIItemDelegate::disableBorderColor() const
{
    return m_disableBorderColor;
}

void UKUIItemDelegate::setDisableBorderColor(DTColor newDisableBorderColor)
{
    if (m_disableBorderColor == newDisableBorderColor)
        return;
    m_disableBorderColor = newDisableBorderColor;
    emit disableBorderColorChanged();
}
