/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUIITEMDELEGATE_H
#define UKUIITEMDELEGATE_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIItemDelegate : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(int radius READ radius WRITE setRadius NOTIFY radiusChanged)

    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY normalTextColorChanged)
    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)
    Q_PROPERTY(DTColor normalBC READ normalBC WRITE setNormalBC NOTIFY normalBCChanged)
    Q_PROPERTY(DTColor clickedBC READ clickedBC WRITE setClickedBC NOTIFY clickedBCChanged)
    Q_PROPERTY(DTColor hoveredBC READ hoveredBC WRITE setHoveredBC NOTIFY hoveredBCChanged)
    Q_PROPERTY(DTColor disableBC READ disableBC WRITE setDisableBC NOTIFY disableBCChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor hoverBorderColor READ hoverBorderColor WRITE setHoverBorderColor NOTIFY hoverBorderColorChanged)
    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickBorderColorChanged)
    Q_PROPERTY(DTColor disableBorderColor READ disableBorderColor WRITE setDisableBorderColor NOTIFY disableBorderColorChanged)

public:
    explicit UKUIItemDelegate(QQuickItem *parent = nullptr);
    ~UKUIItemDelegate();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUIItemDelegate* qmlAttachedProperties(QObject* parent);


    Q_INVOKABLE DTColor normalTextColor() const;
    void setNormalTextColor(DTColor newNormalTextColor);

    Q_INVOKABLE DTColor disableTextColor() const;
    void setDisableTextColor(DTColor newDisableTextColor);

    Q_INVOKABLE DTColor normalBC() const;
    void setNormalBC(DTColor newNormalBC);

    Q_INVOKABLE DTColor clickedBC() const;
    void setClickedBC(DTColor newClickedBC);

    Q_INVOKABLE DTColor hoveredBC() const;
    void setHoveredBC(DTColor newHoveredBC);

    Q_INVOKABLE DTColor disableBC() const;
    void setDisableBC(DTColor newDisableBC);

    int radius() const;
    void setRadius(int newRadius);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    Q_INVOKABLE DTColor normalBorderColor() const;
    void setNormalBorderColor(DTColor newNormalBorderColor);

    Q_INVOKABLE DTColor hoverBorderColor() const;
    void setHoverBorderColor(DTColor newHoverBorderColor);

    Q_INVOKABLE DTColor clickBorderColor() const;
    void setClickBorderColor(DTColor newClickBorderColor);

    Q_INVOKABLE DTColor disableBorderColor() const;
    void setDisableBorderColor(DTColor newDisableBorderColor);

signals:

    void normalTextColorChanged();

    void disableTextColorChanged();

    void normalBCChanged();

    void clickedBCChanged();

    void hoveredBCChanged();

    void disableBCChanged();

    void radiusChanged();

    void borderWidthChanged();

    void normalBorderColorChanged();

    void hoverBorderColorChanged();

    void clickBorderColorChanged();

    void disableBorderColorChanged();

private:
    Q_INVOKABLE DTColor m_normalTextColor    ;
    Q_INVOKABLE DTColor m_disableTextColor   ;
    Q_INVOKABLE DTColor m_normalBC           ;
    Q_INVOKABLE DTColor m_clickedBC          ;
    Q_INVOKABLE DTColor m_hoveredBC          ;
    Q_INVOKABLE DTColor m_disableBC          ;
    Q_INVOKABLE DTColor m_normalBorderColor  ;
    Q_INVOKABLE DTColor m_hoverBorderColor   ;
    Q_INVOKABLE DTColor m_clickBorderColor   ;
    Q_INVOKABLE DTColor m_disableBorderColor ;
    int m_radius;
    int m_borderWidth;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIItemDelegate, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUIITEMDELEGATE_H
