#include "ukuimenu.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUIMenu::UKUIMenu(QQuickItem *parent) : QQuickItem(parent)
{
    qDebug() << "UKUIMenu..............";
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIMenu::~UKUIMenu()
{

}

void UKUIMenu::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setshadowNormalColor(instance->shadowActive());
    setshadowDisableColor(instance->shadowDisable());
    setNormalBC(instance->baseActive());
    setNormalBorderColor(instance->kLineWindowAcitive());
    setBorder(1);
}

UKUIMenu* UKUIMenu::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIMenu(p);
}

int UKUIMenu::leftRightPadding() const
{
    return m_leftRightPadding;
}

void UKUIMenu::setLeftRightPadding(int newLeftRightPadding)
{
    if (m_leftRightPadding == newLeftRightPadding)
        return;
    m_leftRightPadding = newLeftRightPadding;
    emit leftRightPaddingChanged();
}

int UKUIMenu::topBottomPadding() const
{
    return m_topBottomPadding;
}

void UKUIMenu::setTopBottomPadding(int newTopBottomPadding)
{
    if (m_topBottomPadding == newTopBottomPadding)
        return;
    m_topBottomPadding = newTopBottomPadding;
    emit topBottomPaddingChanged();
}


int UKUIMenu::radius() const
{
    return m_radius;
}

void UKUIMenu::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}


const DTColor  &UKUIMenu::shadowNormalColor() const
{
    return m_shadowNormalColor;
}

void UKUIMenu::setshadowNormalColor(const DTColor  &newshadowNormalColor)
{
    if (m_shadowNormalColor == newshadowNormalColor)
        return;
    m_shadowNormalColor = newshadowNormalColor;
    emit shadowNormalColorChanged();
}

const DTColor  &UKUIMenu::shadowDisableColor() const
{
    return m_shadowDisableColor;
}

void UKUIMenu::setshadowDisableColor(const DTColor  &newShadowDisableColor)
{
    if (m_shadowDisableColor == newShadowDisableColor)
        return;
    m_shadowDisableColor = newShadowDisableColor;
    emit shadowDisableColorChanged();
}

const DTColor  &UKUIMenu::normalBC() const
{
    return m_normalBC;
}

void UKUIMenu::setNormalBC(const DTColor  &newNormalBC)
{
    if (m_normalBC == newNormalBC)
        return;
    m_normalBC = newNormalBC;
    emit normalBCChanged();
}

const DTColor  &UKUIMenu::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUIMenu::setNormalBorderColor(const DTColor  &newNormalBorderColor)
{
    if (m_normalBorderColor == newNormalBorderColor)
        return;
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
}

int UKUIMenu::border() const
{
    return m_border;
}

void UKUIMenu::setBorder(int newBorder)
{
    if (m_border == newBorder)
        return;
    m_border = newBorder;
    emit borderChanged();
}
