#include "ukuimenuitem.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUIMenuItem::UKUIMenuItem(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIMenuItem::~UKUIMenuItem()
{

}

void UKUIMenuItem::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setBorderWidth(1);
    setNormalBC(DTColor(QColor(0,0,0,0)));
    setHoveredBC(instance->kComponentHover());
    setClickedBC(instance->kComponentClick());
    setDisableBC(DTColor(QColor(0,0,0,0)));
    setNormalBorderColor(DTColor(QColor(0,0,0,0)));
    setHoverBorderColor(instance->kLineComponentHover());
    setClickBorderColor(instance->kLineComponentClick());
    setDisableBorderColor(DTColor(QColor(0,0,0,0)));
    setNormalTextColor(instance->kFontPrimary());
    setDisableTextColor(instance->kFontPrimaryDisable());
}

UKUIMenuItem* UKUIMenuItem::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIMenuItem(p);
}

int UKUIMenuItem::leftRightPadding() const
{
    return m_leftRightPadding;
}

void UKUIMenuItem::setLeftRightPadding(int newLeftRightPadding)
{
    if (m_leftRightPadding == newLeftRightPadding)
        return;
    m_leftRightPadding = newLeftRightPadding;
    emit leftRightPaddingChanged();
}

int UKUIMenuItem::topBottomPadding() const
{
    return m_topBottomPadding;
}

void UKUIMenuItem::setTopBottomPadding(int newTopBottomPadding)
{
    if (m_topBottomPadding == newTopBottomPadding)
        return;
    m_topBottomPadding = newTopBottomPadding;
    emit topBottomPaddingChanged();
}

int UKUIMenuItem::imageWidth() const
{
    return m_imageWidth;
}

void UKUIMenuItem::setImageWidth(int newImageWidth)
{
    if (m_imageWidth == newImageWidth)
        return;
    m_imageWidth = newImageWidth;
    emit imageWidthChanged();
}

int UKUIMenuItem::imageSpace() const
{
    return m_imageSpace;
}

void UKUIMenuItem::setImageSpace(int newImageSpace)
{
    if (m_imageSpace == newImageSpace)
        return;
    m_imageSpace = newImageSpace;
    emit imageSpaceChanged();
}

int UKUIMenuItem::normalHeight() const
{
    return m_normalHeight;
}

void UKUIMenuItem::setNormalHeight(int newNormalHeight)
{
    if (m_normalHeight == newNormalHeight)
        return;
    m_normalHeight = newNormalHeight;
    emit normalHeightChanged();
}

int UKUIMenuItem::radius() const
{
    return m_radius;
}

void UKUIMenuItem::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit RadiusChanged();
}


const DTColor &UKUIMenuItem::normalBC() const
{
    return m_normalBC;
}

void UKUIMenuItem::setNormalBC(const DTColor &newNormalBC)
{
    if (m_normalBC == newNormalBC)
        return;
    m_normalBC = newNormalBC;
    emit normalBCChanged();
}

const DTColor &UKUIMenuItem::clickedBC() const
{
    return m_clickedBC;
}

void UKUIMenuItem::setClickedBC(const DTColor &newClickedBC)
{
    if (m_clickedBC == newClickedBC)
        return;
    m_clickedBC = newClickedBC;
    emit clickedBCChanged();
}

const DTColor &UKUIMenuItem::hoveredBC() const
{
    return m_hoveredBC;
}

void UKUIMenuItem::setHoveredBC(const DTColor &newHoveredBC)
{
    if (m_hoveredBC == newHoveredBC)
        return;
    m_hoveredBC = newHoveredBC;
    emit hoveredBCChanged();
}

const DTColor &UKUIMenuItem::disableBC() const
{
    return m_disableBC;
}

void UKUIMenuItem::setDisableBC(const DTColor &newDisableBC)
{
    if (m_disableBC == newDisableBC)
        return;
    m_disableBC = newDisableBC;
    emit disableBCChanged();
}

const DTColor &UKUIMenuItem::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUIMenuItem::setDisableTextColor(const DTColor &newDisableTextColor)
{
    if (m_disableTextColor == newDisableTextColor)
        return;
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
}

const DTColor &UKUIMenuItem::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUIMenuItem::setNormalTextColor(const DTColor &newNormalTextColor)
{
    if (m_normalTextColor == newNormalTextColor)
        return;
    m_normalTextColor = newNormalTextColor;
    emit disableTextColorChanged();
}

int UKUIMenuItem::borderWidth() const
{
    return m_borderWidth;
}

void UKUIMenuItem::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

const DTColor &UKUIMenuItem::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUIMenuItem::setNormalBorderColor(const DTColor &newNormalBorderColor)
{
    if (m_normalBorderColor == newNormalBorderColor)
        return;
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
}

const DTColor &UKUIMenuItem::hoverBorderColor() const
{
    return m_hoverBorderColor;
}

void UKUIMenuItem::setHoverBorderColor(const DTColor &newHoverBorderColor)
{
    if (m_hoverBorderColor == newHoverBorderColor)
        return;
    m_hoverBorderColor = newHoverBorderColor;
    emit hoverBorderColorChanged();
}

const DTColor &UKUIMenuItem::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUIMenuItem::setClickBorderColor(const DTColor &newClickBorderColor)
{
    if (m_clickBorderColor == newClickBorderColor)
        return;
    m_clickBorderColor = newClickBorderColor;
    emit clickBorderColorChanged();
}

const DTColor &UKUIMenuItem::disableBorderColor() const
{
    return m_disableBorderColor;
}

void UKUIMenuItem::setDisableBorderColor(const DTColor &newDisableBorderColor)
{
    if (m_disableBorderColor == newDisableBorderColor)
        return;
    m_disableBorderColor = newDisableBorderColor;
    emit disableBorderColorChanged();
}
