/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUIMENUITEM_H
#define UKUIMENUITEM_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIMenuItem : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(int leftRightPadding READ leftRightPadding WRITE setLeftRightPadding NOTIFY leftRightPaddingChanged)
    Q_PROPERTY(int topBottomPadding READ topBottomPadding WRITE setTopBottomPadding NOTIFY topBottomPaddingChanged)
    Q_PROPERTY(int imageWidth READ imageWidth WRITE setImageWidth NOTIFY imageWidthChanged)
    Q_PROPERTY(int imageSpace READ imageSpace WRITE setImageSpace NOTIFY imageSpaceChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(int radius READ radius WRITE setRadius NOTIFY RadiusChanged)

    Q_PROPERTY(DTColor normalBC READ normalBC WRITE setNormalBC NOTIFY normalBCChanged)
    Q_PROPERTY(DTColor clickedBC READ clickedBC WRITE setClickedBC NOTIFY clickedBCChanged)
    Q_PROPERTY(DTColor hoveredBC READ hoveredBC WRITE setHoveredBC NOTIFY hoveredBCChanged)
    Q_PROPERTY(DTColor disableBC READ disableBC WRITE setDisableBC NOTIFY disableBCChanged)
    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)
    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY disableTextColorChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor hoverBorderColor READ hoverBorderColor WRITE setHoverBorderColor NOTIFY hoverBorderColorChanged)
    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickBorderColorChanged)
    Q_PROPERTY(DTColor disableBorderColor READ disableBorderColor WRITE setDisableBorderColor NOTIFY disableBorderColorChanged)

public:
    explicit UKUIMenuItem(QQuickItem *parent = nullptr);
    ~UKUIMenuItem();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUIMenuItem* qmlAttachedProperties(QObject* parent);

    int leftRightPadding() const;
    void setLeftRightPadding(int newLeftRightPadding);

    int topBottomPadding() const;
    void setTopBottomPadding(int newTopBottomPadding);

    int imageWidth() const;
    void setImageWidth(int newImageWidth);

    int imageSpace() const;
    void setImageSpace(int newImageSpace);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    int radius() const;
    void setRadius(int newRadius);

    const DTColor &normalBC() const;
    void setNormalBC(const DTColor &newNormalBC);

    const DTColor &clickedBC() const;
    void setClickedBC(const DTColor &newClickedBC);

    const DTColor &hoveredBC() const;
    void setHoveredBC(const DTColor &newHoveredBC);

    const DTColor &disableBC() const;
    void setDisableBC(const DTColor &newDisableBC);

    const DTColor &disableTextColor() const;
    void setDisableTextColor(const DTColor &newDisableTextColor);

    const DTColor &normalTextColor() const;
    void setNormalTextColor(const DTColor &newNormalTextColor);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    const DTColor &normalBorderColor() const;
    void setNormalBorderColor(const DTColor &newNormalBorderColor);

    const DTColor &hoverBorderColor() const;
    void setHoverBorderColor(const DTColor &newHoverBorderColor);

    const DTColor &clickBorderColor() const;
    void setClickBorderColor(const DTColor &newClickBorderColor);

    const DTColor &disableBorderColor() const;
    void setDisableBorderColor(const DTColor &newDisableBorderColor);

signals:
    void leftRightPaddingChanged();

    void topBottomPaddingChanged();

    void imageWidthChanged();

    void imageSpaceChanged();

    void normalHeightChanged();

    void RadiusChanged();

    void normalBCChanged();

    void clickedBCChanged();

    void hoveredBCChanged();

    void disableBCChanged();

    void disableTextColorChanged();

    void borderWidthChanged();

    void normalBorderColorChanged();

    void hoverBorderColorChanged();

    void clickBorderColorChanged();

    void disableBorderColorChanged();

private:
    int m_leftRightPadding = 8;
    int m_topBottomPadding = 6;
    int m_imageWidth = 16;
    int m_imageSpace = 4;
    int m_normalHeight = 36;
    int m_radius = 8;
    Q_INVOKABLE DTColor m_normalBC;
    Q_INVOKABLE DTColor m_clickedBC;
    Q_INVOKABLE DTColor m_hoveredBC;
    Q_INVOKABLE DTColor m_disableBC;
    Q_INVOKABLE DTColor m_disableTextColor;
    Q_INVOKABLE DTColor m_normalTextColor;
    int m_borderWidth;
    Q_INVOKABLE DTColor m_normalBorderColor;
    Q_INVOKABLE DTColor m_hoverBorderColor;
    Q_INVOKABLE DTColor m_clickBorderColor;
    Q_INVOKABLE DTColor m_disableBorderColor;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIMenuItem, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUIMENUITEM_H
