#include "ukuipopup.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUIPopup::UKUIPopup(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIPopup::~UKUIPopup()
{

}

void UKUIPopup::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setBackColor(instance->baseActive());
    setBackBorderColor(instance->kLineWindowAcitive());
    setRadius(instance->kradiusMenu());
    //setShadowColor(instance->kShadowMenu());
}

UKUIPopup* UKUIPopup::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIPopup(p);
}

const DTColor &UKUIPopup::normalColor() const
{
    return m_normalColor;
}

void UKUIPopup::setNormalColor(const DTColor &newNormalColor)
{
    if (m_normalColor == newNormalColor)
        return;
    m_normalColor = newNormalColor;
    emit normalColorChanged();
}


int UKUIPopup::padding() const
{
    return m_padding;
}

void UKUIPopup::setPadding(int newPadding)
{
    if (m_padding == newPadding)
        return;
    m_padding = newPadding;
    emit paddingChanged();
}

const DTColor &UKUIPopup::backColor() const
{
    return m_backColor;
}

void UKUIPopup::setBackColor(const DTColor &newBackColor)
{
    if (m_backColor == newBackColor)
        return;
    m_backColor = newBackColor;
    emit backColorChanged();
}

const DTColor &UKUIPopup::backBorderColor() const
{
    return m_backBorderColor;
}

void UKUIPopup::setBackBorderColor(const DTColor &newBackBorderColor)
{
    if (m_backBorderColor == newBackBorderColor)
        return;
    m_backBorderColor = newBackBorderColor;
    emit backBorderColorChanged();
}

const DTColor &UKUIPopup::shadowColor() const
{
    return m_shadowColor;
}

void UKUIPopup::setShadowColor(const DTColor &newShadowColor)
{
    if (m_shadowColor == newShadowColor)
        return;
    m_shadowColor = newShadowColor;
    emit shadowColorChanged();
}

int UKUIPopup::radius() const
{
    return m_radius;
}

void UKUIPopup::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}
