/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUIPOPUP_H
#define UKUIPOPUP_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIPopup : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(int radius READ radius WRITE setRadius NOTIFY radiusChanged)

    Q_PROPERTY(DTColor normalColor READ normalColor WRITE setNormalColor NOTIFY normalColorChanged)
    Q_PROPERTY(int padding READ padding WRITE setPadding NOTIFY paddingChanged)
    Q_PROPERTY(DTColor backColor READ backColor WRITE setBackColor NOTIFY backColorChanged)
    Q_PROPERTY(DTColor backBorderColor READ backBorderColor WRITE setBackBorderColor NOTIFY backBorderColorChanged)
    Q_PROPERTY(DTColor shadowColor READ shadowColor WRITE setShadowColor NOTIFY shadowColorChanged)

public:
    explicit UKUIPopup(QQuickItem *parent = nullptr);
    ~UKUIPopup();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUIPopup* qmlAttachedProperties(QObject* parent);

    const DTColor &normalColor() const;
    void setNormalColor(const DTColor &newNormalColor);

    int padding() const;
    void setPadding(int newPadding);

    const DTColor &backColor() const;
    void setBackColor(const DTColor &newBackColor);

    const DTColor &backBorderColor() const;
    void setBackBorderColor(const DTColor &newBackBorderColor);

    const DTColor &shadowColor() const;
    void setShadowColor(const DTColor &newShadowColor);

    int radius() const;
    void setRadius(int newRadius);

signals:
    void normalColorChanged();

    void paddingChanged();

    void backColorChanged();

    void backBorderColorChanged();

    void shadowColorChanged();

    void radiusChanged();

private:
    Q_INVOKABLE DTColor m_normalColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.85));

    int m_padding = 12;
    Q_INVOKABLE DTColor m_backColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.85));
    Q_INVOKABLE DTColor m_backBorderColor = DTColor(QColor::fromRgbF(1, 1, 1));
    Q_INVOKABLE DTColor m_shadowColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.3));
    int m_radius;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIPopup, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUIPOPUP_H
