/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUIPROGRESSBAR_H
#define UKUIPROGRESSBAR_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIProgressBar : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(int radius READ radius WRITE setRadius NOTIFY radiusChanged)
    Q_PROPERTY(DTColor normalColor READ normalColor WRITE setNormalColor NOTIFY normalColorChanged)
    Q_PROPERTY(DTColor childrenColor READ childrenColor WRITE setChildrenColor NOTIFY childrenColorChanged)
    Q_PROPERTY(int normalWidth READ normalWidth WRITE setNormalWidth NOTIFY normalWidthChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(int indeterminateChildrenWidth READ indeterminateChildrenWidth  WRITE setIndeterminateChildrenWidth  NOTIFY indeterminateChildrenWidthChanged)
    Q_PROPERTY(DTColor indeterminateChildrenStartColor READ indeterminateChildrenStartColor  WRITE setIndeterminateChildrenStartColor  NOTIFY indeterminateChildrenStartColorChanged)
    Q_PROPERTY(DTColor indeterminateChildrenEndColor READ indeterminateChildrenEndColor  WRITE setIndeterminateChildrenEndColor  NOTIFY indeterminateChildrenEndColorChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(DTColor borderColor READ borderColor WRITE setBorderColor NOTIFY borderColorChanged)
public:
    explicit UKUIProgressBar(QQuickItem *parent = nullptr);
    ~UKUIProgressBar();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUIProgressBar* qmlAttachedProperties(QObject* parent);

    const DTColor &normalColor() const;
    void setNormalColor(const DTColor &newNormalColor);

    int radius() const;
    void setRadius(int newRadius);

    const DTColor &childrenColor() const;
    void setChildrenColor(const DTColor &newChildrenColor);

    int normalWidth() const;
    void setNormalWidth(int newNormalWidth);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    int indeterminateChildrenWidth() const;
    void setIndeterminateChildrenWidth(int newIndeterminateChildrenWidth);

    const DTColor &indeterminateChildrenStartColor() const;
    void setIndeterminateChildrenStartColor(const DTColor &newIndeterminateChildrenStartColor);

    const DTColor &indeterminateChildrenEndColor() const;
    void setIndeterminateChildrenEndColor(const DTColor &newIndeterminateChildrenEndColor);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    const DTColor &borderColor() const;
    void setBorderColor(const DTColor &newBorderColor);

signals:
    void normalColorChanged();

    void radiusChanged();

    void childrenColorChanged();

    void normalWidthChanged();

    void normalHeightChanged();

    void indeterminateChildrenWidthChanged();

    void indeterminateChildrenStartColorChanged();

    void indeterminateChildrenEndColorChanged();

    void borderWidthChanged();

    void borderColorChanged();

private:
    Q_INVOKABLE DTColor m_normalColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.85));

    int m_radius;
    Q_INVOKABLE DTColor m_childrenColor;
    int m_normalWidth;
    int m_normalHeight;
    int m_indeterminateChildrenWidth;
    Q_INVOKABLE DTColor m_indeterminateChildrenStartColor;
    Q_INVOKABLE DTColor m_indeterminateChildrenEndColor;
    int m_borderWidth;
    Q_INVOKABLE DTColor m_borderColor;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIProgressBar, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUIPROGRESSBAR_H
