#include <QApplication>
#include "ukuiradiobutton.h"
#include "qdebug.h"
using namespace UKUIQQC2Style;

UKUIRadioButton::UKUIRadioButton(QQuickItem *parent) : QQuickItem(parent)
{
    qDebug() << "UKUIRadioButton..............";
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIRadioButton::~UKUIRadioButton()
{

}

UKUIRadioButton* UKUIRadioButton::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIRadioButton(p);
}

void UKUIRadioButton::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setNormalTextColor(instance->kFontPrimary());
    setDisableTextColor(instance->kFontPrimaryDisable());
    setNormalIndicatorColor(instance->buttonActive());
    setHoverIndicatorColor(instance->kComponentHover());
    setClickIndicatorColor(instance->kComponentClick());
    setDisableIndicatorColor(instance->buttonDisable());
    setNormalIndicatorBorderColor(instance->kLineNormal());
    setHoverIndicatorBorderColor(instance->kLineNormal());
    setClickIndicatorBorderColor(instance->kLineNormal());
    setDisableIndicatorBorderColor(instance->kLineDisable());

    setChecked_NormalIndicatorColor(instance->highLightActive());
    setChecked_HoverIndicatorColor(instance->kBrandHover());
    setChecked_ClickIndicatorColor(instance->kBrandClick());
    setChecked_DisableIndicatorColor(instance->buttonDisable());
    setChecked_NormalIndicatorBorderColor(instance->kLineNormal());
    setChecked_HoverIndicatorBorderColor(instance->kLineNormal());
    setChecked_ClickIndicatorBorderColor(instance->kLineNormal());
    setChecked_DisableIndicatorBorderColor(instance->kLineDisable());

    setChecked_NormalChildrenColor(instance->highLightedTextActive());
    setChecked_HoverChildrenColor(instance->highLightedTextActive());
    setChecked_ClickChildrenColor(instance->highLightedTextActive());
    setChecked_DisableChildrenColor(instance->highLightedTextDisable());

    setBorderWidth(instance->normalline());
    setSpace(8);
    setIndicatorWidth(16);
    setChildrenWidth(8);
}



double UKUIRadioButton::leftRightMargin() const
{
    return m_leftRightMargin;
}

void UKUIRadioButton::setLeftRightMargin(double newLeftRightMargin)
{
    if (qFuzzyCompare(m_leftRightMargin, newLeftRightMargin))
        return;
    m_leftRightMargin = newLeftRightMargin;
    emit leftRightMarginChanged();
}

double UKUIRadioButton::upDownMargin() const
{
    return m_upDownMargin;
}

void UKUIRadioButton::setUpDownMargin(double newUpDownMargin)
{
    if (qFuzzyCompare(m_upDownMargin, newUpDownMargin))
        return;
    m_upDownMargin = newUpDownMargin;
    emit upDownMarginChanged();
}

double UKUIRadioButton::space() const
{
    return m_space;
}

void UKUIRadioButton::setSpace(double newSpace)
{
    if (qFuzzyCompare(m_space, newSpace))
        return;
    m_space = newSpace;
    emit spaceChanged();
}

const DTColor &UKUIRadioButton::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUIRadioButton::setDisableTextColor(const DTColor &newDisableTextColor)
{
    if (m_disableTextColor == newDisableTextColor)
        return;
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
}

const DTColor &UKUIRadioButton::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUIRadioButton::setNormalTextColor(const DTColor &newNormalTextColor)
{
    if (m_normalTextColor == newNormalTextColor)
        return;
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
}

const DTColor &UKUIRadioButton::normalIndicatorColor() const
{
    return m_normalIndicatorColor;
}

void UKUIRadioButton::setNormalIndicatorColor(const DTColor &newNormalIndicatorColor)
{
    if (m_normalIndicatorColor == newNormalIndicatorColor)
        return;
    m_normalIndicatorColor = newNormalIndicatorColor;
    emit normalIndicatorColorChanged();
}

const DTColor &UKUIRadioButton::hoverIndicatorColor() const
{
    return m_hoverIndicatorColor;
}

void UKUIRadioButton::setHoverIndicatorColor(const DTColor &newHoverIndicatorColor)
{
    if (m_hoverIndicatorColor == newHoverIndicatorColor)
        return;
    m_hoverIndicatorColor = newHoverIndicatorColor;
    emit hoverIndicatorColorChanged();
}

const DTColor &UKUIRadioButton::clickIndicatorColor() const
{
    return m_clickIndicatorColor;
}

void UKUIRadioButton::setClickIndicatorColor(const DTColor &newClickIndicatorColor)
{
    if (m_clickIndicatorColor == newClickIndicatorColor)
        return;
    m_clickIndicatorColor = newClickIndicatorColor;
    emit clickIndicatorColorChanged();
}

const DTColor &UKUIRadioButton::disableIndicatorColor() const
{
    return m_disableIndicatorColor;
}

void UKUIRadioButton::setDisableIndicatorColor(const DTColor &newDisableIndicatorColor)
{
    if (m_disableIndicatorColor == newDisableIndicatorColor)
        return;
    m_disableIndicatorColor = newDisableIndicatorColor;
    emit disableIndicatorColorChanged();
}

const DTColor &UKUIRadioButton::normalIndicatorBorderColor() const
{
    return m_normalIndicatorBorderColor;
}

void UKUIRadioButton::setNormalIndicatorBorderColor(const DTColor &newNormalIndicatorBorderColor)
{
    if (m_normalIndicatorBorderColor == newNormalIndicatorBorderColor)
        return;
    m_normalIndicatorBorderColor = newNormalIndicatorBorderColor;
    emit normalIndicatorBorderColorChanged();
}

const DTColor &UKUIRadioButton::hoverIndicatorBorderColor() const
{
    return m_hoverIndicatorBorderColor;
}

void UKUIRadioButton::setHoverIndicatorBorderColor(const DTColor &newHoverIndicatorBorderColor)
{
    if (m_hoverIndicatorBorderColor == newHoverIndicatorBorderColor)
        return;
    m_hoverIndicatorBorderColor = newHoverIndicatorBorderColor;
    emit hoverIndicatorBorderColorChanged();
}

const DTColor &UKUIRadioButton::clickIndicatorBorderColor() const
{
    return m_clickIndicatorBorderColor;
}

void UKUIRadioButton::setClickIndicatorBorderColor(const DTColor &newClickIndicatorBorderColor)
{
    if (m_clickIndicatorBorderColor == newClickIndicatorBorderColor)
        return;
    m_clickIndicatorBorderColor = newClickIndicatorBorderColor;
    emit clickIndicatorBorderColorChanged();
}

const DTColor &UKUIRadioButton::disableIndicatorBorderColor() const
{
    return m_disableIndicatorBorderColor;
}

void UKUIRadioButton::setDisableIndicatorBorderColor(const DTColor &newDisableIndicatorBorderColor)
{
    if (m_disableIndicatorBorderColor == newDisableIndicatorBorderColor)
        return;
    m_disableIndicatorBorderColor = newDisableIndicatorBorderColor;
    emit disableIndicatorBorderColorChanged();
}

const DTColor &UKUIRadioButton::checked_normalIndicatorColor() const
{
    return m_checked_normalIndicatorColor;
}

const DTColor &UKUIRadioButton::checked_hoverIndicatorColor() const
{
    return m_checked_hoverIndicatorColor;
}

const DTColor &UKUIRadioButton::checked_clickIndicatorColor() const
{
    return m_checked_clickIndicatorColor;
}

const DTColor &UKUIRadioButton::checked_disableIndicatorColor() const
{
    return m_checked_disableIndicatorColor;
}

const DTColor &UKUIRadioButton::checked_normalIndicatorBorderColor() const
{
    return m_checked_normalIndicatorBorderColor;
}

const DTColor &UKUIRadioButton::checked_hoverIndicatorBorderColor() const
{
    return m_checked_hoverIndicatorBorderColor;
}

const DTColor &UKUIRadioButton::checked_clickIndicatorBorderColor() const
{
    return m_checked_clickIndicatorBorderColor;
}

const DTColor &UKUIRadioButton::checked_disableIndicatorBorderColor() const
{
    return m_checked_disableIndicatorBorderColor;
}

const DTColor &UKUIRadioButton::checked_normalChildrenColor() const
{
    return m_checked_normalChildrenColor;
}

const DTColor &UKUIRadioButton::checked_hoverChildrenColor() const
{
    return m_checked_hoverChildrenColor;
}

const DTColor &UKUIRadioButton::checked_clickChildrenColor() const
{
    return m_checked_clickChildrenColor;
}


const DTColor &UKUIRadioButton::checked_disableChildrenColor() const
{
    return m_checked_disableChildrenColor;
}

const DTColor &UKUIRadioButton::checked_normalChildrenBorderColor() const
{
    return m_checked_normalChildrenBorderColor;
}

const DTColor &UKUIRadioButton::checked_hoverChildrenBorderColor() const
{
    return m_checked_hoverChildrenBorderColor;
}

const DTColor &UKUIRadioButton::checked_clickChildrenBorderColor() const
{
    return m_checked_clickChildrenBorderColor;
}


const DTColor &UKUIRadioButton::checked_disableChildrenBorderColor() const
{
    return m_checked_disableChildrenBorderColor;
}


void UKUIRadioButton::setChecked_NormalIndicatorColor(const DTColor &newChecked_normalIndicatorColor)
{
    if (m_checked_normalIndicatorColor == newChecked_normalIndicatorColor)
        return;
    m_checked_normalIndicatorColor = newChecked_normalIndicatorColor;
    emit checked_normalIndicatorColorChanged();
}

void UKUIRadioButton::setChecked_HoverIndicatorColor(const DTColor &newChecked_hoverIndicatorColor)
{
    if (m_checked_hoverIndicatorColor == newChecked_hoverIndicatorColor)
        return;
    m_checked_hoverIndicatorColor = newChecked_hoverIndicatorColor;
    emit checked_hoverIndicatorColorChanged();
}

void UKUIRadioButton::setChecked_ClickIndicatorColor(const DTColor &newChecked_clickIndicatorColor)
{
    if (m_checked_clickIndicatorColor == newChecked_clickIndicatorColor)
        return;
    m_checked_clickIndicatorColor = newChecked_clickIndicatorColor;
    emit checked_clickIndicatorColorChanged();
}

void UKUIRadioButton::setChecked_DisableIndicatorColor(const DTColor &newChecked_disableIndicatorColor)
{
    if (m_checked_disableIndicatorColor == newChecked_disableIndicatorColor)
        return;
    m_checked_disableIndicatorColor = newChecked_disableIndicatorColor;
    emit checked_disableIndicatorColorChanged();
}

void UKUIRadioButton::setChecked_NormalIndicatorBorderColor(const DTColor &newChecked_normalIndicatorBorderColor)
{
    if (m_checked_normalIndicatorBorderColor == newChecked_normalIndicatorBorderColor)
        return;
    m_checked_normalIndicatorBorderColor = newChecked_normalIndicatorBorderColor;
    emit checked_normalIndicatorBorderColorChanged();
}

void UKUIRadioButton::setChecked_HoverIndicatorBorderColor(const DTColor &newChecked_hoverIndicatorBorderColor)
{
    if (m_checked_hoverIndicatorBorderColor == newChecked_hoverIndicatorBorderColor)
        return;
    m_checked_hoverIndicatorBorderColor = newChecked_hoverIndicatorBorderColor;
    emit checked_hoverIndicatorBorderColorChanged();
}

void UKUIRadioButton::setChecked_ClickIndicatorBorderColor(const DTColor &newChecked_clickIndicatorBorderColor)
{
    if (m_checked_clickIndicatorBorderColor == newChecked_clickIndicatorBorderColor)
        return;
    m_checked_clickIndicatorBorderColor = newChecked_clickIndicatorBorderColor;
    emit checked_clickIndicatorBorderColorChanged();
}

void UKUIRadioButton::setChecked_DisableIndicatorBorderColor(const DTColor &newChecked_disableIndicatorBorderColor)
{
    if (m_checked_disableIndicatorBorderColor == newChecked_disableIndicatorBorderColor)
        return;
    m_checked_disableIndicatorBorderColor = newChecked_disableIndicatorBorderColor;
    emit checked_disableIndicatorBorderColorChanged();
}

void UKUIRadioButton::setChecked_NormalChildrenColor(const DTColor &newChecked_normalChildrenColor)
{
    if (m_checked_normalChildrenColor == newChecked_normalChildrenColor)
        return;
    m_checked_normalChildrenColor = newChecked_normalChildrenColor;
    emit checked_normalChildrenColorChanged();
}

void UKUIRadioButton::setChecked_HoverChildrenColor(const DTColor &newChecked_hoverChildrenColor)
{
    if (m_checked_hoverChildrenColor == newChecked_hoverChildrenColor)
        return;
    m_checked_hoverChildrenColor = newChecked_hoverChildrenColor;
    emit checked_hoverChildrenColorChanged();
}

void UKUIRadioButton::setChecked_ClickChildrenColor(const DTColor &newChecked_clickChildrenColor)
{
    if (m_checked_clickChildrenColor == newChecked_clickChildrenColor)
        return;
    m_checked_clickChildrenColor = newChecked_clickChildrenColor;
    emit checked_clickChildrenColorChanged();
}

void UKUIRadioButton::setChecked_DisableChildrenColor(const DTColor &newChecked_disableChildrenColor)
{
    if (m_checked_disableChildrenColor == newChecked_disableChildrenColor)
        return;
    m_checked_disableChildrenColor = newChecked_disableChildrenColor;
    emit checked_disableChildrenColorChanged();
}

void UKUIRadioButton::setChecked_NormalChildrenBorderColor(const DTColor &newChecked_normalChildrenBorderColor)
{
    if (m_checked_normalChildrenBorderColor == newChecked_normalChildrenBorderColor)
        return;
    m_checked_normalChildrenBorderColor = newChecked_normalChildrenBorderColor;
    emit checked_normalChildrenBorderColorChanged();
}

void UKUIRadioButton::setChecked_HoverChildrenBorderColor(const DTColor &newChecked_hoverChildrenBorderColor)
{
    if (m_checked_hoverChildrenBorderColor == newChecked_hoverChildrenBorderColor)
        return;
    m_checked_hoverChildrenBorderColor = newChecked_hoverChildrenBorderColor;
    emit checked_hoverChildrenBorderColorChanged();
}

void UKUIRadioButton::setChecked_ClickChildrenBorderColor(const DTColor &newChecked_clickChildrenBorderColor)
{
    if (m_checked_clickChildrenBorderColor == newChecked_clickChildrenBorderColor)
        return;
    m_checked_clickChildrenBorderColor = newChecked_clickChildrenBorderColor;
    emit checked_clickChildrenBorderColorChanged();
}

void UKUIRadioButton::setChecked_DisableChildrenBorderColor(const DTColor &newChecked_disableChildrenBorderColor)
{
    if (m_checked_disableChildrenBorderColor == newChecked_disableChildrenBorderColor)
        return;
    m_checked_disableChildrenBorderColor = newChecked_disableChildrenBorderColor;
    emit checked_disableChildrenBorderColorChanged();
}

int UKUIRadioButton::borderWidth() const
{
    return m_borderWidth;
}

void UKUIRadioButton::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

int UKUIRadioButton::indicatorWidth() const
{
    return m_indicatorWidth;
}

void UKUIRadioButton::setIndicatorWidth(int newIndicatorWidth)
{
    if (m_indicatorWidth == newIndicatorWidth)
        return;
    m_indicatorWidth = newIndicatorWidth;
    emit indicatorWidthChanged();
}

int UKUIRadioButton::childrenWidth() const
{
    return m_childrenWidth;
}

void UKUIRadioButton::setChildrenWidth(int newChildrenWidth)
{
    if (m_childrenWidth == newChildrenWidth)
        return;
    m_childrenWidth = newChildrenWidth;
    emit childrenWidthChanged();
}
