/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUIRADIOBUTTON_H
#define UKUIRADIOBUTTON_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIRadioButton : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(double leftRightMargin READ leftRightMargin WRITE setLeftRightMargin NOTIFY leftRightMarginChanged)
    Q_PROPERTY(double upDownMargin READ upDownMargin WRITE setUpDownMargin NOTIFY upDownMarginChanged)
    Q_PROPERTY(double space READ space WRITE setSpace NOTIFY spaceChanged)
    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)


    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)
    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY normalTextColorChanged)

    Q_PROPERTY(DTColor normalIndicatorColor READ normalIndicatorColor WRITE setNormalIndicatorColor NOTIFY normalIndicatorColorChanged)
    Q_PROPERTY(DTColor hoverIndicatorColor READ hoverIndicatorColor WRITE setHoverIndicatorColor NOTIFY hoverIndicatorColorChanged)
    Q_PROPERTY(DTColor clickIndicatorColor READ clickIndicatorColor WRITE setClickIndicatorColor NOTIFY clickIndicatorColorChanged)
    Q_PROPERTY(DTColor disableIndicatorColor READ disableIndicatorColor WRITE setDisableIndicatorColor NOTIFY disableIndicatorColorChanged)
    Q_PROPERTY(DTColor normalIndicatorBorderColor READ normalIndicatorBorderColor WRITE setNormalIndicatorBorderColor NOTIFY normalIndicatorBorderColorChanged)
    Q_PROPERTY(DTColor hoverIndicatorBorderColor READ hoverIndicatorBorderColor WRITE setHoverIndicatorBorderColor NOTIFY hoverIndicatorBorderColorChanged)
    Q_PROPERTY(DTColor clickIndicatorBorderColor READ clickIndicatorBorderColor WRITE setClickIndicatorBorderColor NOTIFY clickIndicatorBorderColorChanged)
    Q_PROPERTY(DTColor disableIndicatorBorderColor READ disableIndicatorBorderColor WRITE setDisableIndicatorBorderColor NOTIFY disableIndicatorBorderColorChanged)

    Q_PROPERTY(DTColor checked_normalIndicatorColor        READ checked_normalIndicatorColor        WRITE setChecked_NormalIndicatorColor        NOTIFY checked_normalIndicatorColorChanged)
    Q_PROPERTY(DTColor checked_hoverIndicatorColor         READ checked_hoverIndicatorColor         WRITE setChecked_HoverIndicatorColor         NOTIFY checked_hoverIndicatorColorChanged)
    Q_PROPERTY(DTColor checked_clickIndicatorColor         READ checked_clickIndicatorColor         WRITE setChecked_ClickIndicatorColor         NOTIFY checked_clickIndicatorColorChanged)
    Q_PROPERTY(DTColor checked_disableIndicatorColor       READ checked_disableIndicatorColor       WRITE setChecked_DisableIndicatorColor       NOTIFY checked_disableIndicatorColorChanged)
    Q_PROPERTY(DTColor checked_normalIndicatorBorderColor  READ checked_normalIndicatorBorderColor  WRITE setChecked_NormalIndicatorBorderColor  NOTIFY checked_normalIndicatorBorderColorChanged)
    Q_PROPERTY(DTColor checked_hoverIndicatorBorderColor   READ checked_hoverIndicatorBorderColor   WRITE setChecked_HoverIndicatorBorderColor   NOTIFY checked_hoverIndicatorBorderColorChanged)
    Q_PROPERTY(DTColor checked_clickIndicatorBorderColor   READ checked_clickIndicatorBorderColor   WRITE setChecked_ClickIndicatorBorderColor   NOTIFY checked_clickIndicatorBorderColorChanged)
    Q_PROPERTY(DTColor checked_disableIndicatorBorderColor READ checked_disableIndicatorBorderColor WRITE setChecked_DisableIndicatorBorderColor NOTIFY checked_disableIndicatorBorderColorChanged)

    Q_PROPERTY(DTColor checked_normalChildrenColor        READ checked_normalChildrenColor        WRITE setChecked_NormalChildrenColor        NOTIFY checked_normalChildrenColorChanged)
    Q_PROPERTY(DTColor checked_hoverChildrenColor         READ checked_hoverChildrenColor         WRITE setChecked_HoverChildrenColor         NOTIFY checked_hoverChildrenColorChanged)
    Q_PROPERTY(DTColor checked_clickChildrenColor         READ checked_clickChildrenColor         WRITE setChecked_ClickChildrenColor         NOTIFY checked_clickChildrenColorChanged)
    Q_PROPERTY(DTColor checked_disableChildrenColor       READ checked_disableChildrenColor       WRITE setChecked_DisableChildrenColor       NOTIFY checked_disableChildrenColorChanged)
    Q_PROPERTY(DTColor checked_normalChildrenBorderColor  READ checked_normalChildrenBorderColor  WRITE setChecked_NormalChildrenBorderColor  NOTIFY checked_normalChildrenBorderColorChanged)
    Q_PROPERTY(DTColor checked_hoverChildrenBorderColor   READ checked_hoverChildrenBorderColor   WRITE setChecked_HoverChildrenBorderColor   NOTIFY checked_hoverChildrenBorderColorChanged)
    Q_PROPERTY(DTColor checked_clickChildrenBorderColor   READ checked_clickChildrenBorderColor   WRITE setChecked_ClickChildrenBorderColor   NOTIFY checked_clickChildrenBorderColorChanged)
    Q_PROPERTY(DTColor checked_disableChildrenBorderColor READ checked_disableChildrenBorderColor WRITE setChecked_DisableChildrenBorderColor NOTIFY checked_disableChildrenBorderColorChanged)

    Q_PROPERTY(int indicatorWidth READ indicatorWidth WRITE setIndicatorWidth NOTIFY indicatorWidthChanged)
    Q_PROPERTY(int childrenWidth READ childrenWidth WRITE setChildrenWidth NOTIFY childrenWidthChanged)


public:
    explicit UKUIRadioButton(QQuickItem *parent = nullptr);
    ~UKUIRadioButton();

    static UKUIRadioButton* qmlAttachedProperties(QObject* parent);

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);
    double leftRightMargin() const;
    void setLeftRightMargin(double newLeftRightMargin);

    double upDownMargin() const;
    void setUpDownMargin(double newUpDownMargin);

    double space() const;
    void setSpace(double newSpace);

    const DTColor &disableTextColor() const;
    void setDisableTextColor(const DTColor &newDisableTextColor);

    const DTColor &normalTextColor() const;
    void setNormalTextColor(const DTColor &newNormalTextColor);

    const DTColor &normalIndicatorColor() const;
    void setNormalIndicatorColor(const DTColor &newNormalIndicatorColor);

    const DTColor &hoverIndicatorColor() const;
    void setHoverIndicatorColor(const DTColor &newHoverIndicatorColor);

    const DTColor &clickIndicatorColor() const;
    void setClickIndicatorColor(const DTColor &newClickIndicatorColor);

    const DTColor &disableIndicatorColor() const;
    void setDisableIndicatorColor(const DTColor &newDisableIndicatorColor);

    const DTColor &normalIndicatorBorderColor() const;
    void setNormalIndicatorBorderColor(const DTColor &newNormalIndicatorBorderColor);

    const DTColor &hoverIndicatorBorderColor() const;
    void setHoverIndicatorBorderColor(const DTColor &newHoverIndicatorBorderColor);

    const DTColor &clickIndicatorBorderColor() const;
    void setClickIndicatorBorderColor(const DTColor &newClickIndicatorBorderColor);

    const DTColor &disableIndicatorBorderColor() const;
    void setDisableIndicatorBorderColor(const DTColor &newDisableIndicatorBorderColor);

    const DTColor &checked_normalIndicatorColor() const;
    void setChecked_NormalIndicatorColor(const DTColor &newChecked_normalIndicatorColor);

    const DTColor &checked_hoverIndicatorColor() const;
    void setChecked_HoverIndicatorColor(const DTColor &newChecked_hoverIndicatorColor);

    const DTColor &checked_clickIndicatorColor() const;
    void setChecked_ClickIndicatorColor(const DTColor &newChecked_clickIndicatorColor);

    const DTColor &checked_disableIndicatorColor() const;
    void setChecked_DisableIndicatorColor(const DTColor &newChecked_disableIndicatorColor);

    const DTColor &checked_normalIndicatorBorderColor() const;
    void setChecked_NormalIndicatorBorderColor(const DTColor &newChecked_normalIndicatorBorderColor);

    const DTColor &checked_hoverIndicatorBorderColor() const;
    void setChecked_HoverIndicatorBorderColor(const DTColor &newChecked_hoverIndicatorBorderColor);

    const DTColor &checked_clickIndicatorBorderColor() const;
    void setChecked_ClickIndicatorBorderColor(const DTColor &newChecked_clickIndicatorBorderColor);

    const DTColor &checked_disableIndicatorBorderColor() const;
    void setChecked_DisableIndicatorBorderColor(const DTColor &newChecked_disableIndicatorBorderColor);

    const DTColor &checked_normalChildrenColor() const;
    void setChecked_NormalChildrenColor(const DTColor &newChecked_normalChildrenColor);

    const DTColor &checked_hoverChildrenColor() const;
    void setChecked_HoverChildrenColor(const DTColor &newChecked_hoverChildrenColor);

    const DTColor &checked_clickChildrenColor() const;
    void setChecked_ClickChildrenColor(const DTColor &newChecked_clickChildrenColor);

    const DTColor &checked_disableChildrenColor() const;
    void setChecked_DisableChildrenColor(const DTColor &newChecked_disableChildrenColor);

    const DTColor &checked_normalChildrenBorderColor() const;
    void setChecked_NormalChildrenBorderColor(const DTColor &newChecked_normalChildrenBorderColor);

    const DTColor &checked_hoverChildrenBorderColor() const;
    void setChecked_HoverChildrenBorderColor(const DTColor &newChecked_hoverChildrenBorderColor);

    const DTColor &checked_clickChildrenBorderColor() const;
    void setChecked_ClickChildrenBorderColor(const DTColor &newChecked_clickChildrenBorderColor);

    const DTColor &checked_disableChildrenBorderColor() const;
    void setChecked_DisableChildrenBorderColor(const DTColor &newChecked_disableChildrenBorderColor);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    int indicatorWidth() const;
    void setIndicatorWidth(int newIndicatorWidth);

    int childrenWidth() const;
    void setChildrenWidth(int newChildrenWidth);

signals:

    void leftRightMarginChanged();

    void upDownMarginChanged();

    void spaceChanged();

    void disableTextColorChanged();

    void normalTextColorChanged();

    void normalIndicatorColorChanged();

    void hoverIndicatorColorChanged();

    void clickIndicatorColorChanged();

    void disableIndicatorColorChanged();

    void normalIndicatorBorderColorChanged();

    void hoverIndicatorBorderColorChanged();

    void clickIndicatorBorderColorChanged();

    void disableIndicatorBorderColorChanged();

    void checked_normalIndicatorColorChanged();

    void checked_hoverIndicatorColorChanged();

    void checked_clickIndicatorColorChanged();

    void checked_disableIndicatorColorChanged();

    void checked_normalIndicatorBorderColorChanged();

    void checked_hoverIndicatorBorderColorChanged();

    void checked_clickIndicatorBorderColorChanged();

    void checked_disableIndicatorBorderColorChanged();

    void checked_normalChildrenColorChanged();

    void checked_hoverChildrenColorChanged();

    void checked_clickChildrenColorChanged();

    void checked_disableChildrenColorChanged();

    void checked_normalChildrenBorderColorChanged();

    void checked_hoverChildrenBorderColorChanged();

    void checked_clickChildrenBorderColorChanged();

    void checked_disableChildrenBorderColorChanged();

    void borderWidthChanged();

    void indicatorWidthChanged();

    void childrenWidthChanged();

private:
    double m_leftRightMargin;
    double m_upDownMargin;
    double m_space;
    Q_INVOKABLE DTColor m_disableTextColor;
    Q_INVOKABLE DTColor m_normalTextColor;
    Q_INVOKABLE DTColor m_normalIndicatorColor;
    Q_INVOKABLE DTColor m_hoverIndicatorColor;
    Q_INVOKABLE DTColor m_clickIndicatorColor;
    Q_INVOKABLE DTColor m_disableIndicatorColor;
    Q_INVOKABLE DTColor m_normalIndicatorBorderColor;
    Q_INVOKABLE DTColor m_hoverIndicatorBorderColor;
    Q_INVOKABLE DTColor m_clickIndicatorBorderColor;
    Q_INVOKABLE DTColor m_disableIndicatorBorderColor;
    Q_INVOKABLE DTColor m_checked_normalIndicatorColor;
    Q_INVOKABLE DTColor m_checked_hoverIndicatorColor;
    Q_INVOKABLE DTColor m_checked_clickIndicatorColor;
    Q_INVOKABLE DTColor m_checked_disableIndicatorColor;
    Q_INVOKABLE DTColor m_checked_normalIndicatorBorderColor;
    Q_INVOKABLE DTColor m_checked_hoverIndicatorBorderColor;
    Q_INVOKABLE DTColor m_checked_clickIndicatorBorderColor;
    Q_INVOKABLE DTColor m_checked_disableIndicatorBorderColor;
    Q_INVOKABLE DTColor m_checked_normalChildrenColor;
    Q_INVOKABLE DTColor m_checked_hoverChildrenColor;
    Q_INVOKABLE DTColor m_checked_clickChildrenColor;
    Q_INVOKABLE DTColor m_checked_disableChildrenColor;
    Q_INVOKABLE DTColor m_checked_normalChildrenBorderColor;
    Q_INVOKABLE DTColor m_checked_hoverChildrenBorderColor;
    Q_INVOKABLE DTColor m_checked_clickChildrenBorderColor;
    Q_INVOKABLE DTColor m_checked_disableChildrenBorderColor;
    int m_borderWidth;
    int m_indicatorWidth;
    int m_childrenWidth;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIRadioButton, QML_HAS_ATTACHED_PROPERTIES)

//Q_DECLARE_METATYPE(UKUIQQC2Style::UKUIButton);
//Q_DECLARE_METATYPE(std::shared_ptr<UKUIQQC2Style::UKUIButton>)

#endif // UKUIRADIOBUTTON_H
