#include "ukuiscrollbar.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUIScrollBar::UKUIScrollBar(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });

}

UKUIScrollBar::~UKUIScrollBar()
{

}

void UKUIScrollBar::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setNormalColor(instance->kGray6());
    setHoverColor(instance->kComponentHover());
    setClickColor(instance->kComponentClick());
    setDisableColor(instance->kGray3());
}

UKUIScrollBar* UKUIScrollBar::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIScrollBar(p);
}

const DTColor &UKUIScrollBar::normalColor() const
{
    return m_normalColor;
}

void UKUIScrollBar::setNormalColor(const DTColor &newNormalColor)
{
    if (m_normalColor == newNormalColor)
        return;
    m_normalColor = newNormalColor;
    emit normalColorChanged();
}


int UKUIScrollBar::padding() const
{
    return m_padding;
}

void UKUIScrollBar::setPadding(int newPadding)
{
    if (m_padding == newPadding)
        return;
    m_padding = newPadding;
    emit paddingChanged();
}

const DTColor &UKUIScrollBar::hoverColor() const
{
    return m_hoverColor;
}

void UKUIScrollBar::setHoverColor(const DTColor &newHoverColor)
{
    if (m_hoverColor == newHoverColor)
        return;
    m_hoverColor = newHoverColor;
    emit hoverColorChanged();
}

const DTColor &UKUIScrollBar::clickColor() const
{
    return m_clickColor;
}

void UKUIScrollBar::setClickColor(const DTColor &newClickColor)
{
    if (m_clickColor == newClickColor)
        return;
    m_clickColor = newClickColor;
    emit clickColorChanged();
}

const DTColor &UKUIScrollBar::disableColor() const
{
    return m_disableColor;
}

void UKUIScrollBar::setDisableColor(const DTColor &newDisableColor)
{
    if (m_disableColor == newDisableColor)
        return;
    m_disableColor = newDisableColor;
    emit disableColorChanged();
}
