/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUISCROLLBAR_H
#define UKUISCROLLBAR_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUIScrollBar : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(DTColor normalColor READ normalColor WRITE setNormalColor NOTIFY normalColorChanged)
    Q_PROPERTY(DTColor hoverColor READ hoverColor WRITE setHoverColor NOTIFY hoverColorChanged)
    Q_PROPERTY(DTColor clickColor READ clickColor WRITE setClickColor NOTIFY clickColorChanged)
    Q_PROPERTY(DTColor disableColor READ disableColor WRITE setDisableColor NOTIFY disableColorChanged)

    Q_PROPERTY(int padding READ padding WRITE setPadding NOTIFY paddingChanged)

public:
    explicit UKUIScrollBar(QQuickItem *parent = nullptr);
    ~UKUIScrollBar();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUIScrollBar* qmlAttachedProperties(QObject* parent);

    const DTColor &normalColor() const;
    void setNormalColor(const DTColor &newNormalColor);

    int padding() const;
    void setPadding(int newPadding);

    const DTColor &hoverColor() const;
    void setHoverColor(const DTColor &newHoverColor);

    const DTColor &clickColor() const;
    void setClickColor(const DTColor &newClickColor);

    const DTColor &disableColor() const;
    void setDisableColor(const DTColor &newDisableColor);

signals:
    void normalColorChanged();

    void paddingChanged();

    void hoverColorChanged();

    void clickColorChanged();

    void disableColorChanged();

private:
    Q_INVOKABLE DTColor m_normalColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.85));

    int m_padding = 2;
    Q_INVOKABLE DTColor m_hoverColor;
    Q_INVOKABLE DTColor m_clickColor;
    Q_INVOKABLE DTColor m_disableColor;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUIScrollBar, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUISCROLLBAR_H
