#include "ukuislider.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUISlider::UKUISlider(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUISlider::~UKUISlider()
{

}

void UKUISlider::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    if(!instance && qApp->property("qqc2-globaltoken").isValid()){
        TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
        if(token){
            instance = token->getInstance();
        }
    }
    setNormalWidth(243);
    setNormalHeight(24);
    setGrooveHeight(4);
    setHandleHeight(20);
    setFocusBorderWidth(instance->focusline());
    qDebug() << "newFocusBorderColor11111....." << m_focusBorderColor.mixStartColor().red() <<
                m_focusBorderColor.mixStartColor().green() <<m_focusBorderColor.mixStartColor().blue();

    setFocusBorderColor(instance->kBrandFocus());
    qDebug() << "newFocusBorderColor22222....." << instance->kBrandFocus().mixStartColor().red() <<
                instance->kBrandFocus().mixStartColor().green() <<instance->kBrandFocus().mixStartColor().blue();


    setNormalGrooveColor(instance->kBrandClick());
    setDisableGrooveColor(instance->kGray12());
    setNormalGrooveBorderColor(instance->kLineBrandClick());
    setDisableGrooveBorderColor(instance->kLineBrandDisable());
    setGrooveBorderWidth(1);

    setNormalUnGrooveColor(instance->buttonActive());
    setDisableUnGrooveColor(instance->buttonDisable());
    setNormalUnGrooveBorderColor(instance->kLineComponentNormal());
    setDisableUnGrooveColor(instance->kLineComponentDisable());


    qDebug() << "handlehover....." << instance->kBrandHover().mixStartColor().red() << instance->kBrandHover().mixStartColor().green() << instance->kBrandHover().mixStartColor().blue();
    setNormalHandleColor(instance->highLightActive());
    setHoverHandleColor(instance->kBrandHover());
    setClickHandleColor(instance->kBrandClick());
    setDisableHandleColor(instance->kGray11());
    setNormalHandleBorderColor(instance->kLineBrandNormal());
    setHoverHandleBorderColor(instance->kLineBrandNormal());
    setClickHandleBorderColor(instance->kLineBrandNormal());
    setDisableHandleBorderColor(instance->kLineBrandDisable());
    setHandleBorderWidth(1);
}

UKUISlider* UKUISlider::qmlAttachedProperties(QObject *parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUISlider(p);
}


int UKUISlider::normalWidth() const
{
    return m_normalWidth;
}

void UKUISlider::setNormalWidth(int newNormalWidth)
{
    if (m_normalWidth == newNormalWidth)
        return;
    m_normalWidth = newNormalWidth;
    emit normalWidthChanged();
}

int UKUISlider::normalHeight() const
{
    return m_normalHeight;
}

void UKUISlider::setNormalHeight(int newNormalHeight)
{
    if (m_normalHeight == newNormalHeight)
        return;
    m_normalHeight = newNormalHeight;
    emit normalHeightChanged();
}

int UKUISlider::grooveHeight() const
{
    return m_grooveHeight;
}

void UKUISlider::setGrooveHeight(int newGrooveHeight)
{
    if (m_grooveHeight == newGrooveHeight)
        return;
    m_grooveHeight = newGrooveHeight;
    emit grooveHeightChanged();
}

int UKUISlider::handleHeight() const
{
    return m_handleHeight;
}

void UKUISlider::setHandleHeight(int newHandleHeight)
{
    if (m_handleHeight == newHandleHeight)
        return;
    m_handleHeight = newHandleHeight;
    emit handleHeightChanged();
}

int UKUISlider::focusBorderWidth() const
{
    return m_focusBorderWidth;
}

void UKUISlider::setFocusBorderWidth(int newFocusBorderWidth)
{
    if (m_focusBorderWidth == newFocusBorderWidth)
        return;
    m_focusBorderWidth = newFocusBorderWidth;
    emit focusBorderWidthChanged();
}

const DTColor &UKUISlider::focusBorderColor() const
{
    return m_focusBorderColor;
}

void UKUISlider::setFocusBorderColor(const DTColor &newFocusBorderColor)
{
    qDebug() << "newFocusBorderColor00000....." << m_focusBorderColor.mixStartColor().red() <<
                m_focusBorderColor.mixStartColor().green() <<m_focusBorderColor.mixStartColor().blue();

    if (m_focusBorderColor == newFocusBorderColor)
        return;
    m_focusBorderColor = newFocusBorderColor;
    emit focusBorderColorChanged();

}

const DTColor &UKUISlider::normalGrooveColor() const
{
    return m_normalGrooveColor;
}

void UKUISlider::setNormalGrooveColor(const DTColor &newNormalGrooveColor)
{
    if (m_normalGrooveColor == newNormalGrooveColor)
        return;
    m_normalGrooveColor = newNormalGrooveColor;
    emit normalGrooveColorChanged();
}

const DTColor &UKUISlider::disableGrooveColor() const
{
    return m_disableGrooveColor;
}

void UKUISlider::setDisableGrooveColor(const DTColor &newDisableGrooveColor)
{
    if (m_disableGrooveColor == newDisableGrooveColor)
        return;
    m_disableGrooveColor = newDisableGrooveColor;
    emit disableGrooveColorChanged();
}

const DTColor &UKUISlider::normalHandleColor() const
{
    return m_normalHandleColor;
}

void UKUISlider::setNormalHandleColor(const DTColor &newNormalHandleColor)
{
    if (m_normalHandleColor == newNormalHandleColor)
        return;
    m_normalHandleColor = newNormalHandleColor;
    emit normalHandleColorChanged();
}

const DTColor &UKUISlider::disableHandleColor() const
{
    return m_disableHandleColor;
}

void UKUISlider::setDisableHandleColor(const DTColor &newDisableHandleColor)
{
    if (m_disableHandleColor == newDisableHandleColor)
        return;
    m_disableHandleColor = newDisableHandleColor;
    emit DisableHandleColorChanged();
}

const DTColor &UKUISlider::normalGrooveBorderColor() const
{
    return m_normalGrooveBorderColor;
}

void UKUISlider::setNormalGrooveBorderColor(const DTColor &newNormalGrooveBorderColor)
{
    if (m_normalGrooveBorderColor == newNormalGrooveBorderColor)
        return;
    m_normalGrooveBorderColor = newNormalGrooveBorderColor;
    emit normalGrooveBorderColorChanged();
}

const DTColor &UKUISlider::disableGrooveBorderColor() const
{
    return m_disableGrooveBorderColor;
}

void UKUISlider::setDisableGrooveBorderColor(const DTColor &newDisableGrooveBorderColor)
{
    if (m_disableGrooveBorderColor == newDisableGrooveBorderColor)
        return;
    m_disableGrooveBorderColor = newDisableGrooveBorderColor;
    emit disableGrooveBorderColorChanged();
}

int UKUISlider::grooveBorderWidth() const
{
    return m_grooveBorderWidth;
}

void UKUISlider::setGrooveBorderWidth(int newGrooveBorderWidth)
{
    if (m_grooveBorderWidth == newGrooveBorderWidth)
        return;
    m_grooveBorderWidth = newGrooveBorderWidth;
    emit grooveBorderWidthChanged();
}

const DTColor &UKUISlider::normalHandleBorderColor() const
{
    return m_normalHandleBorderColor;
}

void UKUISlider::setNormalHandleBorderColor(const DTColor &newNormalHandleBorderColor)
{
    if (m_normalHandleBorderColor == newNormalHandleBorderColor)
        return;
    m_normalHandleBorderColor = newNormalHandleBorderColor;
    emit normalHandleBorderColorChanged();
}

const DTColor &UKUISlider::disableHandleBorderColor() const
{
    return m_disableHandleBorderColor;
}

void UKUISlider::setDisableHandleBorderColor(const DTColor &newDisableHandleBorderColor)
{
    if (m_disableHandleBorderColor == newDisableHandleBorderColor)
        return;
    m_disableHandleBorderColor = newDisableHandleBorderColor;
    emit disableHandleBorderColorChanged();
}

int UKUISlider::handleBorderWidth() const
{
    return m_handleBorderWidth;
}

void UKUISlider::setHandleBorderWidth(int newHandleBorderWidth)
{
    if (m_handleBorderWidth == newHandleBorderWidth)
        return;
    m_handleBorderWidth = newHandleBorderWidth;
    emit handleBorderWidthChanged();
}

const DTColor &UKUISlider::normalUnGrooveColor() const
{
    return m_normalUnGrooveColor;
}

void UKUISlider::setNormalUnGrooveColor(const DTColor &newNormalUnGrooveColor)
{
    if (m_normalUnGrooveColor == newNormalUnGrooveColor)
        return;
    m_normalUnGrooveColor = newNormalUnGrooveColor;
    emit normalUnGrooveColorChanged();
}

const DTColor &UKUISlider::disableUnGrooveColor() const
{
    return m_disableUnGrooveColor;
}

void UKUISlider::setDisableUnGrooveColor(const DTColor &newDisableUnGrooveColor)
{
    if (m_disableUnGrooveColor == newDisableUnGrooveColor)
        return;
    m_disableUnGrooveColor = newDisableUnGrooveColor;
    emit disableUnGrooveColorChanged();
}

const DTColor &UKUISlider::normalUnGrooveBorderColor() const
{
    return m_normalUnGrooveBorderColor;
}

void UKUISlider::setNormalUnGrooveBorderColor(const DTColor &newNormalUnGrooveBorderColor)
{
    if (m_normalUnGrooveBorderColor == newNormalUnGrooveBorderColor)
        return;
    m_normalUnGrooveBorderColor = newNormalUnGrooveBorderColor;
    emit normalUnGrooveBorderColorChanged();
}

const DTColor &UKUISlider::disableUnGrooveBorderColor() const
{
    return m_disableUnGrooveBorderColor;
}

void UKUISlider::setDisableUnGrooveBorderColor(const DTColor &newDisableUnGrooveBorderColor)
{
    if (m_disableUnGrooveBorderColor == newDisableUnGrooveBorderColor)
        return;
    m_disableUnGrooveBorderColor = newDisableUnGrooveBorderColor;
    emit disableUnGrooveBorderColorChanged();
}

const DTColor &UKUISlider::hoverHandleColor() const
{
    return m_hoverHandleColor;
}

void UKUISlider::setHoverHandleColor(const DTColor &newHoverHandleColor)
{
    if (m_hoverHandleColor == newHoverHandleColor)
        return;
    m_hoverHandleColor = newHoverHandleColor;
    emit hoverHandleColorChanged();
}

const DTColor &UKUISlider::clickHandleColor() const
{
    return m_clickHandleColor;
}

void UKUISlider::setClickHandleColor(const DTColor &newClickHandleColor)
{
    if (m_clickHandleColor == newClickHandleColor)
        return;
    m_clickHandleColor = newClickHandleColor;
    emit clickHandleColorChanged();
}

const DTColor &UKUISlider::hoverHandleBorderColor() const
{
    return m_hoverHandleBorderColor;
}

void UKUISlider::setHoverHandleBorderColor(const DTColor &newHoverHandleBorderColor)
{
    if (m_hoverHandleBorderColor == newHoverHandleBorderColor)
        return;
    m_hoverHandleBorderColor = newHoverHandleBorderColor;
    emit hoverHandleBorderColorChanged();
}

const DTColor &UKUISlider::clickHandleBorderColor() const
{
    return m_clickHandleBorderColor;
}

void UKUISlider::setClickHandleBorderColor(const DTColor &newClickHandleBorderColor)
{
    if (m_clickHandleBorderColor == newClickHandleBorderColor)
        return;
    m_clickHandleBorderColor = newClickHandleBorderColor;
    emit clickHandleBorderColorChanged();
}
