/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUISLIDER_H
#define UKUISLIDER_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUISlider : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(int normalWidth READ normalWidth WRITE setNormalWidth NOTIFY normalWidthChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(int grooveHeight READ grooveHeight WRITE setGrooveHeight NOTIFY grooveHeightChanged)
    Q_PROPERTY(int handleHeight READ handleHeight WRITE setHandleHeight NOTIFY handleHeightChanged)
    Q_PROPERTY(int focusBorderWidth READ focusBorderWidth WRITE setFocusBorderWidth NOTIFY focusBorderWidthChanged)
    Q_PROPERTY(DTColor focusBorderColor READ focusBorderColor WRITE setFocusBorderColor NOTIFY focusBorderColorChanged)

    Q_PROPERTY(DTColor normalGrooveColor READ normalGrooveColor WRITE setNormalGrooveColor NOTIFY normalGrooveColorChanged)
    Q_PROPERTY(DTColor disableGrooveColor READ disableGrooveColor WRITE setDisableGrooveColor NOTIFY disableGrooveColorChanged)
    Q_PROPERTY(DTColor normalGrooveBorderColor READ normalGrooveBorderColor WRITE setNormalGrooveBorderColor NOTIFY normalGrooveBorderColorChanged)
    Q_PROPERTY(DTColor disableGrooveBorderColor READ disableGrooveBorderColor WRITE setDisableGrooveBorderColor NOTIFY disableGrooveBorderColorChanged)
    Q_PROPERTY(int grooveBorderWidth READ grooveBorderWidth WRITE setGrooveBorderWidth NOTIFY grooveBorderWidthChanged)

    Q_PROPERTY(DTColor normalUnGrooveColor READ normalUnGrooveColor WRITE setNormalUnGrooveColor NOTIFY normalUnGrooveColorChanged)
    Q_PROPERTY(DTColor disableUnGrooveColor READ disableUnGrooveColor WRITE setDisableUnGrooveColor NOTIFY disableUnGrooveColorChanged)
    Q_PROPERTY(DTColor normalUnGrooveBorderColor READ normalUnGrooveBorderColor WRITE setNormalUnGrooveBorderColor NOTIFY normalUnGrooveBorderColorChanged)
    Q_PROPERTY(DTColor disableUnGrooveBorderColor READ disableUnGrooveBorderColor WRITE setDisableUnGrooveBorderColor NOTIFY disableUnGrooveBorderColorChanged)


    Q_PROPERTY(DTColor normalHandleColor READ normalHandleColor WRITE setNormalHandleColor NOTIFY normalHandleColorChanged)
    Q_PROPERTY(DTColor hoverHandleColor READ hoverHandleColor WRITE setHoverHandleColor NOTIFY hoverHandleColorChanged)
    Q_PROPERTY(DTColor clickHandleColor READ clickHandleColor WRITE setClickHandleColor NOTIFY clickHandleColorChanged)
    Q_PROPERTY(DTColor disableHandleColor READ disableHandleColor WRITE setDisableHandleColor NOTIFY DisableHandleColorChanged)
    Q_PROPERTY(DTColor normalHandleBorderColor READ normalHandleBorderColor WRITE setNormalHandleBorderColor NOTIFY normalHandleBorderColorChanged)
    Q_PROPERTY(DTColor hoverHandleBorderColor READ hoverHandleBorderColor WRITE setHoverHandleBorderColor NOTIFY hoverHandleBorderColorChanged)
    Q_PROPERTY(DTColor clickHandleBorderColor READ clickHandleBorderColor WRITE setClickHandleBorderColor NOTIFY clickHandleBorderColorChanged)
    Q_PROPERTY(DTColor disableHandleBorderColor READ disableHandleBorderColor WRITE setDisableHandleBorderColor NOTIFY disableHandleBorderColorChanged)
    Q_PROPERTY(int handleBorderWidth READ handleBorderWidth WRITE setHandleBorderWidth NOTIFY handleBorderWidthChanged)

public:
    explicit UKUISlider(QQuickItem *parent = nullptr);
    ~UKUISlider();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUISlider* qmlAttachedProperties(QObject* parent);

    int normalWidth() const;
    void setNormalWidth(int newNormalWidth);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    int grooveHeight() const;
    void setGrooveHeight(int newGrooveHeight);

    int handleHeight() const;
    void setHandleHeight(int newHandleHeight);

    int focusBorderWidth() const;
    void setFocusBorderWidth(int newFocusBorderWidth);

    const DTColor &focusBorderColor() const;
    void setFocusBorderColor(const DTColor &newFocusBorderColor);

    const DTColor &normalGrooveColor() const;
    void setNormalGrooveColor(const DTColor &newNormalGrooveColor);

    const DTColor &disableGrooveColor() const;
    void setDisableGrooveColor(const DTColor &newDisableGrooveColor);

    const DTColor &normalHandleColor() const;
    void setNormalHandleColor(const DTColor &newNormalHandleColor);

    const DTColor &disableHandleColor() const;
    void setDisableHandleColor(const DTColor &newDisableHandleColor);

    const DTColor &normalGrooveBorderColor() const;
    void setNormalGrooveBorderColor(const DTColor &newNormalGrooveBorderColor);

    const DTColor &disableGrooveBorderColor() const;
    void setDisableGrooveBorderColor(const DTColor &newDisableGrooveBorderColor);

    int grooveBorderWidth() const;
    void setGrooveBorderWidth(int newGrooveBorderWidth);

    const DTColor &normalHandleBorderColor() const;
    void setNormalHandleBorderColor(const DTColor &newNormalHandleBorderColor);

    const DTColor &disableHandleBorderColor() const;
    void setDisableHandleBorderColor(const DTColor &newDisableHandleBorderColor);

    int handleBorderWidth() const;
    void setHandleBorderWidth(int newHandleBorderWidth);

    const DTColor &normalUnGrooveColor() const;
    void setNormalUnGrooveColor(const DTColor &newNormalUnGrooveColor);

    const DTColor &disableUnGrooveColor() const;
    void setDisableUnGrooveColor(const DTColor &newDisableUnGrooveColor);

    const DTColor &normalUnGrooveBorderColor() const;
    void setNormalUnGrooveBorderColor(const DTColor &newNormalUnGrooveBorderColor);

    const DTColor &disableUnGrooveBorderColor() const;
    void setDisableUnGrooveBorderColor(const DTColor &newDisableUnGrooveBorderColor);

    const DTColor &hoverHandleColor() const;
    void setHoverHandleColor(const DTColor &newHoverHandleColor);

    const DTColor &clickHandleColor() const;
    void setClickHandleColor(const DTColor &newClickHandleColor);

    const DTColor &hoverHandleBorderColor() const;
    void setHoverHandleBorderColor(const DTColor &newHoverHandleBorderColor);

    const DTColor &clickHandleBorderColor() const;
    void setClickHandleBorderColor(const DTColor &newClickHandleBorderColor);

signals:
    void normalWidthChanged();

    void normalHeightChanged();

    void grooveHeightChanged();

    void handleHeightChanged();

    void focusBorderWidthChanged();

    void focusBorderColorChanged();

    void normalGrooveColorChanged();

    void disableGrooveColorChanged();

    void normalHandleColorChanged();

    void DisableHandleColorChanged();

    void normalGrooveBorderColorChanged();

    void disableGrooveBorderColorChanged();

    void grooveBorderWidthChanged();

    void normalHandleBorderColorChanged();

    void disableHandleBorderColorChanged();

    void handleBorderWidthChanged();

    void normalUnGrooveColorChanged();

    void disableUnGrooveColorChanged();

    void normalUnGrooveBorderColorChanged();

    void disableUnGrooveBorderColorChanged();

    void hoverHandleColorChanged();

    void clickHandleColorChanged();

    void hoverHandleBorderColorChanged();

    void clickHandleBorderColorChanged();

private:
    int m_normalWidth;
    int m_normalHeight;
    int m_grooveHeight;
    int m_handleHeight;
    int m_focusBorderWidth;
    Q_INVOKABLE DTColor m_focusBorderColor;
    Q_INVOKABLE DTColor m_normalGrooveColor;
    Q_INVOKABLE DTColor m_disableGrooveColor;
    Q_INVOKABLE DTColor m_normalHandleColor;
    Q_INVOKABLE DTColor m_disableHandleColor;
    Q_INVOKABLE DTColor m_normalGrooveBorderColor;
    Q_INVOKABLE DTColor m_disableGrooveBorderColor;
    int m_grooveBorderWidth;
    Q_INVOKABLE DTColor m_normalHandleBorderColor;
    Q_INVOKABLE DTColor m_disableHandleBorderColor;
    int m_handleBorderWidth;
    Q_INVOKABLE DTColor m_normalUnGrooveColor;
    Q_INVOKABLE DTColor m_disableUnGrooveColor;
    Q_INVOKABLE DTColor m_normalUnGrooveBorderColor;
    Q_INVOKABLE DTColor m_disableUnGrooveBorderColor;
    Q_INVOKABLE DTColor m_hoverHandleColor;
    Q_INVOKABLE DTColor m_clickHandleColor;
    Q_INVOKABLE DTColor m_hoverHandleBorderColor;
    Q_INVOKABLE DTColor m_clickHandleBorderColor;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUISlider, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUISLIDER_H
