#include "ukuispinbox.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUISpinBox::UKUISpinBox(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUISpinBox::~UKUISpinBox()
{

}

void UKUISpinBox::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setNormalColor(instance->buttonActive());
    setHoverColor(instance->kComponentHover());
    setClickColor(instance->kComponentClick());
    setDisableColor(instance->buttonDisable());
    setNormalTextColor(instance->buttonTextActive());
    setDisableTextColor(instance->buttonTextDisable());
    setNormalBorderColor(instance->kLineComponentNormal());
    setHoverBorderColor(instance->kLineComponentHover());
    setClickBorderColor(instance->kLineComponentClick());
    setDisableBorderColor(instance->kLineComponentDisable());
    setFocusBorderColor(instance->highLightActive());
    setFocusColor(instance->kContainGeneralNormal());

    setBtnNormalColor(instance->buttonActive());
    setBtnHoverColor(instance->kComponentHover());
    setBtnClickColor(instance->kComponentClick());
    setBtnDisableColor(instance->kComponentDisable());
    setBtnNormalBorderColor(instance->kLineComponentNormal());
    setBtnHoverBorderColor(instance->kLineComponentHover());
    setBtnClickBorderColor(instance->kLineComponentClick());
    setBtnDisableBorderColor(instance->kLineComponentDisable());

    setNormalWidth(160);
    setNormalHeight(36);
    setBtnNormalWidth(36);
    setBtnNormalHeight(18);
    setRadius(instance->kradiusNormal());
    setNormalBorderWidth(instance->normalline());
    setFocusBorderWidth(instance->focusline());
    setPadding(instance->kmarginNormal());
    setBtnBorderWidth(instance->normalline());
}

UKUISpinBox* UKUISpinBox::qmlAttachedProperties(QObject *parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUISpinBox(p);
}

const DTColor &UKUISpinBox::normalColor() const
{
    return m_normalColor;
}

void UKUISpinBox::setNormalColor(const DTColor &newNormalColor)
{
    if (m_normalColor == newNormalColor)
        return;
    m_normalColor = newNormalColor;
    emit normalColorChanged();
}

const DTColor &UKUISpinBox::disableColor() const
{
    return m_disableColor;
}

void UKUISpinBox::setDisableColor(const DTColor &newDisableColor)
{
    if (m_disableColor == newDisableColor)
        return;
    m_disableColor = newDisableColor;
    emit disableColorChanged();
}

const DTColor &UKUISpinBox::hoverColor() const
{
    return m_hoverColor;
}

void UKUISpinBox::setHoverColor(const DTColor &newHoverColor)
{
    if (m_hoverColor == newHoverColor)
        return;
    m_hoverColor = newHoverColor;
    emit hoverColorChanged();
}

const DTColor &UKUISpinBox::clickColor() const
{
    return m_clickColor;
}

void UKUISpinBox::setClickColor(const DTColor &newClickColor)
{
    if (m_clickColor == newClickColor)
        return;
    m_clickColor = newClickColor;
    emit clickColorChanged();
}

const DTColor &UKUISpinBox::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUISpinBox::setNormalTextColor(const DTColor &newNormalTextColor)
{
    if (m_normalTextColor == newNormalTextColor)
        return;
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
}

const DTColor &UKUISpinBox::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUISpinBox::setDisableTextColor(const DTColor &newDisableTextColor)
{
    if (m_disableTextColor == newDisableTextColor)
        return;
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
}

int UKUISpinBox::normalWidth() const
{
    return m_normalWidth;
}

void UKUISpinBox::setNormalWidth(int newNormalWidth)
{
    if (m_normalWidth == newNormalWidth)
        return;
    m_normalWidth = newNormalWidth;
    emit normalWidthChanged();
}

int UKUISpinBox::normalHeight() const
{
    return m_normalHeight;
}

void UKUISpinBox::setNormalHeight(int newNormalHeight)
{
    if (m_normalHeight == newNormalHeight)
        return;
    m_normalHeight = newNormalHeight;
    emit normalHeightChanged();
}

int UKUISpinBox::radius() const
{
    return m_radius;
}

void UKUISpinBox::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}

int UKUISpinBox::btnNormalWidth() const
{
    return m_btnNormalWidth;
}

void UKUISpinBox::setBtnNormalWidth(int newBtnNormalWidth)
{
    if (m_btnNormalWidth == newBtnNormalWidth)
        return;
    m_btnNormalWidth = newBtnNormalWidth;
    emit btnNormalWidthChanged();
}

int UKUISpinBox::btnNormalHeight() const
{
    return m_btnNormalHeight;
}

void UKUISpinBox::setBtnNormalHeight(int newBtnNormalHeight)
{
    if (m_btnNormalHeight == newBtnNormalHeight)
        return;
    m_btnNormalHeight = newBtnNormalHeight;
    emit btnNormalHeightChanged();
}

const DTColor &UKUISpinBox::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUISpinBox::setNormalBorderColor(const DTColor &newNormalBorderColor)
{
    if (m_normalBorderColor == newNormalBorderColor)
        return;
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
}

const DTColor &UKUISpinBox::hoverBorderColor() const
{
    return m_hoverBorderColor;
}

void UKUISpinBox::setHoverBorderColor(const DTColor &newHoverBorderColor)
{
    if (m_hoverBorderColor == newHoverBorderColor)
        return;
    m_hoverBorderColor = newHoverBorderColor;
    emit hoverColorBorderChanged();
}

const DTColor &UKUISpinBox::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUISpinBox::setClickBorderColor(const DTColor &newClickBorderColor)
{
    if (m_clickBorderColor == newClickBorderColor)
        return;
    m_clickBorderColor = newClickBorderColor;
    emit clickColorBorderChanged();
}

const DTColor &UKUISpinBox::disableBorderColor() const
{
    return m_disableBorderColor;
}

void UKUISpinBox::setDisableBorderColor(const DTColor &newDisableBorderColor)
{
    if (m_disableBorderColor == newDisableBorderColor)
        return;
    m_disableBorderColor = newDisableBorderColor;
    emit disableBorderColorChanged();
}

const DTColor &UKUISpinBox::focusBorderColor() const
{
    return m_focusBorderColor;
}

void UKUISpinBox::setFocusBorderColor(const DTColor &newFocusBorderColor)
{
    if (m_focusBorderColor == newFocusBorderColor)
        return;
    m_focusBorderColor = newFocusBorderColor;
    emit focusBorderColorChanged();
}

int UKUISpinBox::focusBorderWidth() const
{
    return m_focusBorderWidth;
}

void UKUISpinBox::setFocusBorderWidth(int newFocusBorderWidth)
{
    if (m_focusBorderWidth == newFocusBorderWidth)
        return;
    m_focusBorderWidth = newFocusBorderWidth;
    emit focusBorderWidthChanged();
}

int UKUISpinBox::normalBorderWidth() const
{
    return m_normalBorderWidth;
}

void UKUISpinBox::setNormalBorderWidth(int newNormalBorderWidth)
{
    if (m_normalBorderWidth == newNormalBorderWidth)
        return;
    m_normalBorderWidth = newNormalBorderWidth;
    emit normalBorderWidthChanged();
}

const DTColor &UKUISpinBox::focusColor() const
{
    return m_focusColor;
}

void UKUISpinBox::setFocusColor(const DTColor &newFocusColor)
{
    if (m_focusColor == newFocusColor)
        return;
    m_focusColor = newFocusColor;
    emit focusColorChanged();
}

int UKUISpinBox::padding() const
{
    return m_padding;
}

void UKUISpinBox::setPadding(int newPadding)
{
    if (m_padding == newPadding)
        return;
    m_padding = newPadding;
    emit paddingChanged();
}

const DTColor &UKUISpinBox::btnNormalColor() const
{
    return m_btnNormalColor;
}

void UKUISpinBox::setBtnNormalColor(const DTColor &newBtnNormalColor)
{
    if (m_btnNormalColor == newBtnNormalColor)
        return;
    m_btnNormalColor = newBtnNormalColor;
    emit btnNormalColorChanged();
}

const DTColor &UKUISpinBox::btnHoverColor() const
{
    return m_btnHoverColor;
}

void UKUISpinBox::setBtnHoverColor(const DTColor &newBtnHoverColor)
{
    if (m_btnHoverColor == newBtnHoverColor)
        return;
    m_btnHoverColor = newBtnHoverColor;
    emit btnHoverColorChanged();
}

const DTColor &UKUISpinBox::btnClickColor() const
{
    return m_btnClickColor;
}

void UKUISpinBox::setBtnClickColor(const DTColor &newBtnClickColor)
{
    if (m_btnClickColor == newBtnClickColor)
        return;
    m_btnClickColor = newBtnClickColor;
    emit btnClickColorChanged();
}

const DTColor &UKUISpinBox::btnDisableColor() const
{
    return m_btnDisableColor;
}

void UKUISpinBox::setBtnDisableColor(const DTColor &newBtnDisableColor)
{
    if (m_btnDisableColor == newBtnDisableColor)
        return;
    m_btnDisableColor = newBtnDisableColor;
    emit btnDisableColorChanged();
}

const DTColor &UKUISpinBox::btnFocusColor() const
{
    return m_btnFocusColor;
}

void UKUISpinBox::setBtnFocusColor(const DTColor &newBtnFocusColor)
{
    if (m_btnFocusColor == newBtnFocusColor)
        return;
    m_btnFocusColor = newBtnFocusColor;
    emit btnFocusColorChanged();
}

const DTColor &UKUISpinBox::btnNormalBorderColor() const
{
    return m_btnNormalBorderColor;
}

void UKUISpinBox::setBtnNormalBorderColor(const DTColor &newBtnNormalBorderColor)
{
    if (m_btnNormalBorderColor == newBtnNormalBorderColor)
        return;
    m_btnNormalBorderColor = newBtnNormalBorderColor;
    emit btnNormalBorderColorChanged();
}

const DTColor &UKUISpinBox::btnHoverBorderColor() const
{
    return m_btnHoverBorderColor;
}

void UKUISpinBox::setBtnHoverBorderColor(const DTColor &newBtnHoverBorderColor)
{
    if (m_btnHoverBorderColor == newBtnHoverBorderColor)
        return;
    m_btnHoverBorderColor = newBtnHoverBorderColor;
    emit btnHoverBorderColorChanged();
}

const DTColor &UKUISpinBox::btnClickBorderColor() const
{
    return m_btnClickBorderColor;
}

void UKUISpinBox::setBtnClickBorderColor(const DTColor &newBtnClickBorderColor)
{
    if (m_btnClickBorderColor == newBtnClickBorderColor)
        return;
    m_btnClickBorderColor = newBtnClickBorderColor;
    emit btnClickBorderColorChanged();
}

const DTColor &UKUISpinBox::btnDisableBorderColor() const
{
    return m_btnDisableBorderColor;
}

void UKUISpinBox::setBtnDisableBorderColor(const DTColor &newBtnDisableBorderColor)
{
    if (m_btnDisableBorderColor == newBtnDisableBorderColor)
        return;
    m_btnDisableBorderColor = newBtnDisableBorderColor;
    emit btnDisableBorderColorChanged();
}

const DTColor &UKUISpinBox::btnFocusBorderColor() const
{
    return m_btnFocusBorderColor;
}

void UKUISpinBox::setBtnFocusBorderColor(const DTColor &newBtnFocusBorderColor)
{
    if (m_btnFocusBorderColor == newBtnFocusBorderColor)
        return;
    m_btnFocusBorderColor = newBtnFocusBorderColor;
    emit btnFocusBorderColorChanged();
}

int UKUISpinBox::btnBorderWidth() const
{
    return m_btnBorderWidth;
}

void UKUISpinBox::setBtnBorderWidth(int newBtnBorderWidth)
{
    if (m_btnBorderWidth == newBtnBorderWidth)
        return;
    m_btnBorderWidth = newBtnBorderWidth;
    emit btnBorderWidthChanged();
}
