/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUISPINBOX_H
#define UKUISPINBOX_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUISpinBox : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(DTColor normalColor READ normalColor WRITE setNormalColor NOTIFY normalColorChanged)
    Q_PROPERTY(DTColor hoverColor READ hoverColor WRITE setHoverColor NOTIFY hoverColorChanged)
    Q_PROPERTY(DTColor clickColor READ clickColor WRITE setClickColor NOTIFY clickColorChanged)
    Q_PROPERTY(DTColor disableColor READ disableColor WRITE setDisableColor NOTIFY disableColorChanged)
    Q_PROPERTY(DTColor focusColor READ focusColor WRITE setFocusColor NOTIFY focusColorChanged)

    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor hoverBorderColor READ hoverBorderColor WRITE setHoverBorderColor NOTIFY hoverColorBorderChanged)
    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickColorBorderChanged)
    Q_PROPERTY(DTColor disableBorderColor READ disableBorderColor WRITE setDisableBorderColor NOTIFY disableBorderColorChanged)
    Q_PROPERTY(DTColor focusBorderColor READ focusBorderColor WRITE setFocusBorderColor NOTIFY focusBorderColorChanged)

    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY normalTextColorChanged)
    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)

    Q_PROPERTY(DTColor btnNormalColor READ btnNormalColor WRITE setBtnNormalColor NOTIFY btnNormalColorChanged)
    Q_PROPERTY(DTColor btnHoverColor READ btnHoverColor WRITE setBtnHoverColor NOTIFY btnHoverColorChanged)
    Q_PROPERTY(DTColor btnClickColor READ btnClickColor WRITE setBtnClickColor NOTIFY btnClickColorChanged)
    Q_PROPERTY(DTColor btnDisableColor READ btnDisableColor WRITE setBtnDisableColor NOTIFY btnDisableColorChanged)
    Q_PROPERTY(DTColor btnFocusColor READ btnFocusColor WRITE setBtnFocusColor NOTIFY btnFocusColorChanged)

    Q_PROPERTY(DTColor btnNormalBorderColor READ btnNormalBorderColor WRITE setBtnNormalBorderColor NOTIFY btnNormalBorderColorChanged)
    Q_PROPERTY(DTColor btnHoverBorderColor READ btnHoverBorderColor WRITE setBtnHoverBorderColor NOTIFY btnHoverBorderColorChanged)
    Q_PROPERTY(DTColor btnClickBorderColor READ btnClickBorderColor WRITE setBtnClickBorderColor NOTIFY btnClickBorderColorChanged)
    Q_PROPERTY(DTColor btnDisableBorderColor READ btnDisableBorderColor WRITE setBtnDisableBorderColor NOTIFY btnDisableBorderColorChanged)
    Q_PROPERTY(DTColor btnFocusBorderColor READ btnFocusBorderColor WRITE setBtnFocusBorderColor NOTIFY btnFocusBorderColorChanged)


    Q_PROPERTY(int normalWidth READ normalWidth WRITE setNormalWidth NOTIFY normalWidthChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(int radius READ radius WRITE setRadius NOTIFY radiusChanged)
    Q_PROPERTY(int btnNormalWidth READ btnNormalWidth WRITE setBtnNormalWidth NOTIFY btnNormalWidthChanged)
    Q_PROPERTY(int btnNormalHeight READ btnNormalHeight WRITE setBtnNormalHeight NOTIFY btnNormalHeightChanged)
    Q_PROPERTY(int focusBorderWidth READ focusBorderWidth WRITE setFocusBorderWidth NOTIFY focusBorderWidthChanged)
    Q_PROPERTY(int normalBorderWidth READ normalBorderWidth WRITE setNormalBorderWidth NOTIFY normalBorderWidthChanged)

    Q_PROPERTY(int padding READ padding WRITE setPadding NOTIFY paddingChanged)

    Q_PROPERTY(int btnBorderWidth READ btnBorderWidth WRITE setBtnBorderWidth NOTIFY btnBorderWidthChanged)

public:
    explicit UKUISpinBox(QQuickItem *parent = nullptr);
    ~UKUISpinBox();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUISpinBox* qmlAttachedProperties(QObject* parent);

    const DTColor &normalColor() const;
    void setNormalColor(const DTColor &newNormalColor);

    const DTColor &disableColor() const;
    void setDisableColor(const DTColor &newDisableColor);

    const DTColor &hoverColor() const;
    void setHoverColor(const DTColor &newHoverColor);

    const DTColor &clickColor() const;
    void setClickColor(const DTColor &newClickColor);

    const DTColor &normalTextColor() const;
    void setNormalTextColor(const DTColor &newNormalTextColor);

    const DTColor &disableTextColor() const;
    void setDisableTextColor(const DTColor &newDisableTextColor);

    int normalWidth() const;
    void setNormalWidth(int newNormalWidth);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    int radius() const;
    void setRadius(int newRadius);

    int btnNormalWidth() const;
    void setBtnNormalWidth(int newBtnNormalWidth);

    int btnNormalHeight() const;
    void setBtnNormalHeight(int newBtnNormalHeight);

    const DTColor &normalBorderColor() const;
    void setNormalBorderColor(const DTColor &newNormalBorderColor);

    const DTColor &hoverBorderColor() const;
    void setHoverBorderColor(const DTColor &newHoverBorderColor);

    const DTColor &clickBorderColor() const;
    void setClickBorderColor(const DTColor &newClickBorderColor);

    const DTColor &disableBorderColor() const;
    void setDisableBorderColor(const DTColor &newDisableBorderColor);

    const DTColor &focusBorderColor() const;
    void setFocusBorderColor(const DTColor &newFocusBorderColor);

    int focusBorderWidth() const;
    void setFocusBorderWidth(int newFocusBorderWidth);

    int normalBorderWidth() const;
    void setNormalBorderWidth(int newNormalBorderWidth);

    const DTColor &focusColor() const;
    void setFocusColor(const DTColor &newFocusColor);

    int padding() const;
    void setPadding(int newPadding);

    const DTColor &btnNormalColor() const;
    void setBtnNormalColor(const DTColor &newBtnNormalColor);

    const DTColor &btnHoverColor() const;
    void setBtnHoverColor(const DTColor &newBtnHoverColor);

    const DTColor &btnClickColor() const;
    void setBtnClickColor(const DTColor &newBtnClickColor);

    const DTColor &btnDisableColor() const;
    void setBtnDisableColor(const DTColor &newBtnDisableColor);

    const DTColor &btnFocusColor() const;
    void setBtnFocusColor(const DTColor &newBtnFocusColor);

    const DTColor &btnNormalBorderColor() const;
    void setBtnNormalBorderColor(const DTColor &newBtnNormalBorderColor);

    const DTColor &btnHoverBorderColor() const;
    void setBtnHoverBorderColor(const DTColor &newBtnHoverBorderColor);

    const DTColor &btnClickBorderColor() const;
    void setBtnClickBorderColor(const DTColor &newBtnClickBorderColor);

    const DTColor &btnDisableBorderColor() const;
    void setBtnDisableBorderColor(const DTColor &newBtnDisableBorderColor);

    const DTColor &btnFocusBorderColor() const;
    void setBtnFocusBorderColor(const DTColor &newBtnFocusBorderColor);

    int btnBorderWidth() const;
    void setBtnBorderWidth(int newBtnBorderWidth);

signals:
    void normalColorChanged();

    void linkColorChanged();

    void disableColorChanged();

    void hoverColorChanged();

    void clickColorChanged();

    void normalTextColorChanged();

    void disableTextColorChanged();

    void normalWidthChanged();

    void normalHeightChanged();

    void radiusChanged();

    void btnNormalWidthChanged();

    void btnNormalHeightChanged();

    void normalBorderColorChanged();

    void hoverColorBorderChanged();

    void clickColorBorderChanged();

    void disableBorderColorChanged();

    void focusBorderColorChanged();

    void focusBorderWidthChanged();

    void normalBorderWidthChanged();

    void focusColorChanged();

    void paddingChanged();

    void btnNormalColorChanged();

    void btnHoverColorChanged();

    void btnClickColorChanged();

    void btnDisableColorChanged();

    void btnFocusColorChanged();

    void btnNormalBorderColorChanged();

    void btnHoverBorderColorChanged();

    void btnClickBorderColorChanged();

    void btnDisableBorderColorChanged();

    void btnFocusBorderColorChanged();

    void btnBorderWidthChanged();

private:
    Q_INVOKABLE DTColor m_normalColor = DTColor(QColor::fromRgbF(0, 0, 0, 0.85));
    Q_INVOKABLE DTColor m_disableColor;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

    Q_INVOKABLE DTColor m_hoverColor;
    Q_INVOKABLE DTColor m_clickColor;
    Q_INVOKABLE DTColor m_normalTextColor;
    Q_INVOKABLE DTColor m_disableTextColor;
    int m_normalWidth;
    int m_normalHeight;
    int m_radius;
    int m_btnNormalWidth;
    int m_btnNormalHeight;
    Q_INVOKABLE DTColor m_normalBorderColor;
    Q_INVOKABLE DTColor m_hoverBorderColor;
    Q_INVOKABLE DTColor m_clickBorderColor;
    Q_INVOKABLE DTColor m_disableBorderColor;
    Q_INVOKABLE DTColor m_focusBorderColor;
    int m_focusBorderWidth;
    int m_normalBorderWidth;
    Q_INVOKABLE DTColor m_focusColor;
    int m_padding;
    Q_INVOKABLE DTColor m_btnNormalColor;
    Q_INVOKABLE DTColor m_btnHoverColor;
    Q_INVOKABLE DTColor m_btnClickColor;
    Q_INVOKABLE DTColor m_btnDisableColor;
    Q_INVOKABLE DTColor m_btnFocusColor;
    Q_INVOKABLE DTColor m_btnNormalBorderColor;
    Q_INVOKABLE DTColor m_btnHoverBorderColor;
    Q_INVOKABLE DTColor m_btnClickBorderColor;
    Q_INVOKABLE DTColor m_btnDisableBorderColor;
    Q_INVOKABLE DTColor m_btnFocusBorderColor;
    int m_btnBorderWidth;
};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUISpinBox, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUISPINBOX_H
