#include "ukuitabbutton.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUITabButton::UKUITabButton(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUITabButton::~UKUITabButton()
{

}

void UKUITabButton::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setNormalColor(DTColor(QColor(0,0,0,0)));
    setHoverColor(instance->kContainHover());
    setClickedColor(instance->kContainClick());
    setCheckedColor(instance->kContainGeneralNormal());
    setBorderWidth(1);
    setNormalBorderColor(instance->kLineComponentNormal());
    setHoverBorderColor(instance->kLineComponentHover());
    setClickBorderColor(instance->kLineComponentClick());
    setCheckedBorderColor(instance->kLineComponentNormal());
    setNormalTextColor(instance->kFontPrimary());
}

UKUITabButton* UKUITabButton::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUITabButton(p);
}

const DTColor &UKUITabButton::normalColor() const
{
    return m_normalColor;
}

void UKUITabButton::setNormalColor(const DTColor &newNormalColor)
{
    if (m_normalColor == newNormalColor)
        return;
    m_normalColor = newNormalColor;
    emit normalColorChanged();
}

const DTColor &UKUITabButton::hoverColor() const
{
    return m_hoverColor;
}

void UKUITabButton::setHoverColor(const DTColor &newHoverColor)
{
    if (m_hoverColor == newHoverColor)
        return;
    m_hoverColor = newHoverColor;
    emit hoverColorChanged();
}

const DTColor &UKUITabButton::checkedColor() const
{
    return m_checkedColor;
}

void UKUITabButton::setCheckedColor(const DTColor &newCheckedColor)
{
    if (m_checkedColor == newCheckedColor)
        return;
    m_checkedColor = newCheckedColor;
    emit checkedColorChanged();
}

const DTColor &UKUITabButton::clickedColor() const
{
    return m_clickedColor;
}

void UKUITabButton::setClickedColor(const DTColor &newClickedColor)
{
    if (m_clickedColor == newClickedColor)
        return;
    m_clickedColor = newClickedColor;
    emit clickedColorChanged();
}

int UKUITabButton::borderWidth() const
{
    return m_borderWidth;
}

void UKUITabButton::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

const DTColor &UKUITabButton::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUITabButton::setNormalBorderColor(const DTColor &newNormalBorderColor)
{
    if (m_normalBorderColor == newNormalBorderColor)
        return;
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
}

const DTColor &UKUITabButton::hoverBorderColor() const
{
    return m_hoverBorderColor;
}

void UKUITabButton::setHoverBorderColor(const DTColor &newHoverBorderColor)
{
    if (m_hoverBorderColor == newHoverBorderColor)
        return;
    m_hoverBorderColor = newHoverBorderColor;
    emit hoverBorderColorChanged();
}

const DTColor &UKUITabButton::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUITabButton::setClickBorderColor(const DTColor &newClickBorderColor)
{
    if (m_clickBorderColor == newClickBorderColor)
        return;
    m_clickBorderColor = newClickBorderColor;
    emit clickBorderColorChanged();
}

const DTColor &UKUITabButton::checkedBorderColor() const
{
    return m_checkedBorderColor;
}

void UKUITabButton::setCheckedBorderColor(const DTColor &newCheckedBorderColor)
{
    if (m_checkedBorderColor == newCheckedBorderColor)
        return;
    m_checkedBorderColor = newCheckedBorderColor;
    emit checkedBorderColorChanged();
}

const DTColor &UKUITabButton::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUITabButton::setNormalTextColor(const DTColor &newNormalTextColor)
{
    if (m_normalTextColor == newNormalTextColor)
        return;
    m_normalTextColor = newNormalTextColor;
    emit disableTextColorChanged();
}
