﻿/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUITABBUTTON_H
#define UKUITABBUTTON_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QApplication>
#include <QPalette>
#include <QtQml/qqml.h>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUITabButton : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(DTColor normalColor READ normalColor WRITE setNormalColor NOTIFY normalColorChanged)
    Q_PROPERTY(DTColor hoverColor READ hoverColor WRITE setHoverColor NOTIFY hoverColorChanged)
    Q_PROPERTY(DTColor checkedColor READ checkedColor WRITE setCheckedColor NOTIFY checkedColorChanged)
    Q_PROPERTY(DTColor clickedColor READ clickedColor WRITE setClickedColor NOTIFY clickedColorChanged)
    Q_PROPERTY(DTColor checkedColor READ checkedColor WRITE setCheckedColor NOTIFY checkedColorColorChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor hoverBorderColor READ hoverBorderColor WRITE setHoverBorderColor NOTIFY hoverBorderColorChanged)
    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickBorderColorChanged)
    Q_PROPERTY(DTColor checkedBorderColor READ checkedBorderColor WRITE setCheckedBorderColor NOTIFY checkedBorderColorChanged)

    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY disableTextColorChanged)

public:
    explicit UKUITabButton(QQuickItem *parent = nullptr);
    ~UKUITabButton();

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);

    static UKUITabButton* qmlAttachedProperties(QObject* parent);

    const DTColor &normalColor() const;
    void setNormalColor(const DTColor &newNormalColor);

    const DTColor &hoverColor() const;
    void setHoverColor(const DTColor &newHoverColor);

    const DTColor &checkedColor() const;
    void setCheckedColor(const DTColor &newCheckedColor);

    const DTColor &clickedColor() const;
    void setClickedColor(const DTColor &newClickedColor);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    const DTColor &normalBorderColor() const;
    void setNormalBorderColor(const DTColor &newNormalBorderColor);

    const DTColor &hoverBorderColor() const;
    void setHoverBorderColor(const DTColor &newHoverBorderColor);

    const DTColor &clickBorderColor() const;
    void setClickBorderColor(const DTColor &newClickBorderColor);

    const DTColor &checkedBorderColor() const;
    void setCheckedBorderColor(const DTColor &newCheckedBorderColor);

    const DTColor &normalTextColor() const;
    void setNormalTextColor(const DTColor &newNormalTextColor);

signals:
    void normalColorChanged();

    void hoverColorChanged();

    void checkedColorChanged();

    void clickedColorChanged();

    void checkedColorColorChanged();

    void borderWidthChanged();

    void normalBorderColorChanged();

    void hoverBorderColorChanged();

    void clickBorderColorChanged();

    void checkedBorderColorChanged();

    void disableTextColorChanged();

private:
    Q_INVOKABLE DTColor m_normalColor = DTColor("#FFFFFF");
    Q_INVOKABLE DTColor m_hoverColor = DTColor("#F2F2F2");
    Q_INVOKABLE DTColor m_checkedColor = DTColor("#F2F2F2");
    Q_INVOKABLE DTColor m_clickedColor = DTColor("#EEEEEE");
    int m_borderWidth;
    Q_INVOKABLE DTColor m_normalBorderColor;
    Q_INVOKABLE DTColor m_hoverBorderColor;
    Q_INVOKABLE DTColor m_clickBorderColor;
    Q_INVOKABLE DTColor m_checkedBorderColor;
    Q_INVOKABLE DTColor m_normalTextColor;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUITabButton, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUITABBUTTON_H
