#include <QApplication>
#include "ukuitextfiled.h"
#include "qdebug.h"
using namespace UKUIQQC2Style;

UKUITextFiled::UKUITextFiled(QQuickItem *parent) : QQuickItem(parent)
{
    qDebug() << "UKUITextFiled..............";
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUITextFiled::~UKUITextFiled()
{

}

UKUITextFiled* UKUITextFiled::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUITextFiled(p);
}

void UKUITextFiled::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setLeftRightPadding(instance->kmarginNormal());
    setRadius(instance->kradiusNormal());
    setBorderWidth(instance->normalline());
    setFocusBorderWidth(instance->focusline());
    setNormalWidth(180);
    setNormalHeight(36);

    setNormalBC(instance->kComponentNormal());
    setInputNormalBC(instance->kContainGeneralNormal());
    setPlaceHolderNormalBC(instance->buttonActive());
    setPlaceHolderHoveredBC(instance->kComponentHover());
    setPlaceHolderClickedBC(instance->kComponentClick());
    setPlaceHolderDisableBC(instance->buttonDisable());
    setNormalBorderColor(instance->kLineComponentNormal());
    setHoverBorderColor(instance->kLineComponentHover());
    setDisableBorderColor(instance->kLineComponentDisable());
    setFocusBorderColor(instance->kBrandFocus());

    setPlaceHolderNormalTextColor(instance->placeholderTextActive());
    setPlaceHolderDisableTextColor(instance->placeholderTextDisable());
    setNormalTextColor(instance->buttonTextActive());
    setDisableTextColor(instance->placeholderTextDisable());
}

double UKUITextFiled::radius() const
{
    return m_radius;
}

void UKUITextFiled::setRadius(double newRadius)
{
    if (qFuzzyCompare(m_radius, newRadius))
        return;
    m_radius = newRadius;
    emit radiusChanged();
}

double UKUITextFiled::leftRightPadding() const
{
    return m_leftRightPadding;
}

void UKUITextFiled::setLeftRightPadding(double newLeftRightPadding)
{
    if (qFuzzyCompare(m_leftRightPadding, newLeftRightPadding))
        return;
    m_leftRightPadding = newLeftRightPadding;
    emit leftRightPaddingChanged();
}

double UKUITextFiled::upDownMargin() const
{
    return m_upDownMargin;
}

void UKUITextFiled::setUpDownMargin(double newUpDownMargin)
{
    if (qFuzzyCompare(m_upDownMargin, newUpDownMargin))
        return;
    m_upDownMargin = newUpDownMargin;
    emit upDownMarginChanged();
}

double UKUITextFiled::space() const
{
    return m_space;
}

void UKUITextFiled::setSpace(double newSpace)
{
    if (qFuzzyCompare(m_space, newSpace))
        return;
    m_space = newSpace;
    emit spaceChange();
}

int UKUITextFiled::normalWidth() const
{
    return m_normalWidth;
}

void UKUITextFiled::setNormalWidth(int newNormalWidth)
{
    if (m_normalWidth == newNormalWidth)
        return;
    m_normalWidth = newNormalWidth;
    emit normalWidthChanged();
}

int UKUITextFiled::normalHeight() const
{
    return m_normalHeight;
}

void UKUITextFiled::setNormalHeight(int newNormalHeight)
{
    if (m_normalHeight == newNormalHeight)
        return;
    m_normalHeight = newNormalHeight;
    emit normalHeightChanged();
}

const DTColor &UKUITextFiled::normalBC() const
{
    return m_normalBC;
}

void UKUITextFiled::setNormalBC(const DTColor &newNormalBC)
{
    if (m_normalBC == newNormalBC)
        return;
    m_normalBC = newNormalBC;
    emit normalBCChanged();
}

const DTColor &UKUITextFiled::clickedBC() const
{
    return m_clickedBC;
}

void UKUITextFiled::setClickedBC(const DTColor &newClickedBC)
{
    if (m_clickedBC == newClickedBC)
        return;
    m_clickedBC = newClickedBC;
    emit clickedBCChanged();
}

const DTColor &UKUITextFiled::hoveredBC() const
{
    return m_hoveredBC;
}

void UKUITextFiled::setHoveredBC(const DTColor &newHoveredBC)
{
    if (m_hoveredBC == newHoveredBC)
        return;
    m_hoveredBC = newHoveredBC;
    emit hoveredBCChanged();
}

const DTColor &UKUITextFiled::disableBC() const
{
    return m_disableBC;
}

void UKUITextFiled::setDisableBC(const DTColor &newDisableBC)
{
    if (m_disableBC == newDisableBC)
        return;
    m_disableBC = newDisableBC;
    emit disableBCChanged();
}

const DTColor &UKUITextFiled::disableTextColor() const
{
    return m_disableTextColor;
}

void UKUITextFiled::setDisableTextColor(const DTColor &newDisableTextColor)
{
    if (m_disableTextColor == newDisableTextColor)
        return;
    m_disableTextColor = newDisableTextColor;
    emit disableTextColorChanged();
}

const DTColor &UKUITextFiled::normalTextColor() const
{
    return m_normalTextColor;
}

void UKUITextFiled::setNormalTextColor(const DTColor &newNormalTextColor)
{
    if (m_normalTextColor == newNormalTextColor)
        return;
    m_normalTextColor = newNormalTextColor;
    emit normalTextColorChanged();
}

int UKUITextFiled::borderWidth() const
{
    return m_borderWidth;
}

void UKUITextFiled::setBorderWidth(int newBorderWidth)
{
    if (m_borderWidth == newBorderWidth)
        return;
    m_borderWidth = newBorderWidth;
    emit borderWidthChanged();
}

int UKUITextFiled::focusBorderWidth() const
{
    return m_focusBorderWidth;
}

void UKUITextFiled::setFocusBorderWidth(int newFocusBorderWidth)
{
    if (m_focusBorderWidth == newFocusBorderWidth)
        return;
    m_focusBorderWidth = newFocusBorderWidth;
    emit focusBorderWidthChanged();
}

const DTColor &UKUITextFiled::normalBorderColor() const
{
    return m_normalBorderColor;
}

void UKUITextFiled::setNormalBorderColor(const DTColor &newNormalBorderColor)
{
    if (m_normalBorderColor == newNormalBorderColor)
        return;
    m_normalBorderColor = newNormalBorderColor;
    emit normalBorderColorChanged();
}

const DTColor &UKUITextFiled::clickBorderColor() const
{
    return m_clickBorderColor;
}

void UKUITextFiled::setClickBorderColor(const DTColor &newClickBorderColor)
{
    if (m_clickBorderColor == newClickBorderColor)
        return;
    m_clickBorderColor = newClickBorderColor;
    emit clickBorderColorChanged();
}

const DTColor &UKUITextFiled::disableBorderColor() const
{
    return m_disableBorderColor;
}

void UKUITextFiled::setDisableBorderColor(const DTColor &newDisableBorderColor)
{
    if (m_disableBorderColor == newDisableBorderColor)
        return;
    m_disableBorderColor = newDisableBorderColor;
    emit disableBorderColorChanged();
}

const DTColor &UKUITextFiled::focusBorderColor() const
{
    return m_focusBorderColor;
}

void UKUITextFiled::setFocusBorderColor(const DTColor &newFocusBorderColor)
{
    if (m_focusBorderColor == newFocusBorderColor)
        return;
    m_focusBorderColor = newFocusBorderColor;
    emit focusBorderColorChanged();
}

const DTColor &UKUITextFiled::hoverBorderColor() const
{
    return m_hoverBorderColor;
}

void UKUITextFiled::setHoverBorderColor(const DTColor &newHoverBorderColor)
{
    if (m_hoverBorderColor == newHoverBorderColor)
        return;
    m_hoverBorderColor = newHoverBorderColor;
    emit hoverBorderColorChanged();
}

const DTColor &UKUITextFiled::placeHolderNormalTextColor() const
{
    return m_placeHolderNormalTextColor;
}

void UKUITextFiled::setPlaceHolderNormalTextColor(const DTColor &newPlaceHolderNormalTextColor)
{
    if (m_placeHolderNormalTextColor == newPlaceHolderNormalTextColor)
        return;
    m_placeHolderNormalTextColor = newPlaceHolderNormalTextColor;
    emit placeHolderNormalTextColorChanged();
}

const DTColor &UKUITextFiled::placeHolderDisableTextColor() const
{
    return m_placeHolderDisableTextColor;
}

void UKUITextFiled::setPlaceHolderDisableTextColor(const DTColor &newPlaceHolderDisableTextColor)
{
    if (m_placeHolderDisableTextColor == newPlaceHolderDisableTextColor)
        return;
    m_placeHolderDisableTextColor = newPlaceHolderDisableTextColor;
    emit placeHolderDisableTextColorChanged();
}

const DTColor &UKUITextFiled::placeHolderNormalBC() const
{
    return m_placeHolderNormalBC;
}

void UKUITextFiled::setPlaceHolderNormalBC(const DTColor &newPlaceHolderNormalBC)
{
    if (m_placeHolderNormalBC == newPlaceHolderNormalBC)
        return;
    m_placeHolderNormalBC = newPlaceHolderNormalBC;
    emit placeHolderNormalBCChanged();
}

const DTColor &UKUITextFiled::placeHolderClickedBC() const
{
    return m_placeHolderClickedBC;
}

void UKUITextFiled::setPlaceHolderClickedBC(const DTColor &newPlaceHolderClickedBC)
{
    if (m_placeHolderClickedBC == newPlaceHolderClickedBC)
        return;
    m_placeHolderClickedBC = newPlaceHolderClickedBC;
    emit placeHolderClickedBCChanged();
}

const DTColor &UKUITextFiled::placeHolderHoveredBC() const
{
    return m_placeHolderHoveredBC;
}

void UKUITextFiled::setPlaceHolderHoveredBC(const DTColor &newPlaceHolderHoveredBC)
{
    if (m_placeHolderHoveredBC == newPlaceHolderHoveredBC)
        return;
    m_placeHolderHoveredBC = newPlaceHolderHoveredBC;
    emit placeHolderHoveredBCChanged();
}

const DTColor &UKUITextFiled::placeHolderDisableBC() const
{
    return m_placeHolderDisableBC;
}

void UKUITextFiled::setPlaceHolderDisableBC(const DTColor &newPlaceHolderDisableBC)
{
    if (m_placeHolderDisableBC == newPlaceHolderDisableBC)
        return;
    m_placeHolderDisableBC = newPlaceHolderDisableBC;
    emit placeHolderDisableBCChanged();
}

const DTColor &UKUITextFiled::inputNormalBC() const
{
    return m_inputNormalBC;
}

void UKUITextFiled::setInputNormalBC(const DTColor &newInputNormalBC)
{
    if (m_inputNormalBC == newInputNormalBC)
        return;
    m_inputNormalBC = newInputNormalBC;
    emit inputNormalBCChanged();
}
