/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yan Wang <wangyan@kylinos.cn>
 *
 */

#ifndef UKUITEXTFILED_H
#define UKUITEXTFILED_H

#include <QObject>
#include <QColor>
#include <QFont>
#include <QQuickItem>
#include "tokenparameter.h"

namespace UKUIQQC2Style {

class UKUITextFiled : public QQuickItem
{
    Q_OBJECT

    Q_PROPERTY(double radius READ radius WRITE setRadius NOTIFY radiusChanged)
    Q_PROPERTY(double leftRightPadding READ leftRightPadding WRITE setLeftRightPadding NOTIFY leftRightPaddingChanged)
    Q_PROPERTY(double upDownMargin READ upDownMargin WRITE setUpDownMargin NOTIFY upDownMarginChanged)
    Q_PROPERTY(double space READ space WRITE setSpace NOTIFY spaceChange)

    Q_PROPERTY(int normalWidth READ normalWidth WRITE setNormalWidth NOTIFY normalWidthChanged)
    Q_PROPERTY(int normalHeight READ normalHeight WRITE setNormalHeight NOTIFY normalHeightChanged)
    Q_PROPERTY(DTColor normalBC READ normalBC WRITE setNormalBC NOTIFY normalBCChanged)
    Q_PROPERTY(DTColor inputNormalBC READ inputNormalBC WRITE setInputNormalBC NOTIFY inputNormalBCChanged)

    Q_PROPERTY(DTColor clickedBC READ clickedBC WRITE setClickedBC NOTIFY clickedBCChanged)
    Q_PROPERTY(DTColor hoveredBC READ hoveredBC WRITE setHoveredBC NOTIFY hoveredBCChanged)
    Q_PROPERTY(DTColor disableBC READ disableBC WRITE setDisableBC NOTIFY disableBCChanged)

    Q_PROPERTY(DTColor placeHolderNormalBC  READ placeHolderNormalBC WRITE  setPlaceHolderNormalBC   NOTIFY   placeHolderNormalBCChanged)
    Q_PROPERTY(DTColor placeHolderClickedBC READ placeHolderClickedBC WRITE setPlaceHolderClickedBC NOTIFY placeHolderClickedBCChanged)
    Q_PROPERTY(DTColor placeHolderHoveredBC READ placeHolderHoveredBC WRITE setPlaceHolderHoveredBC NOTIFY placeHolderHoveredBCChanged)
    Q_PROPERTY(DTColor placeHolderDisableBC READ placeHolderDisableBC WRITE setPlaceHolderDisableBC NOTIFY placeHolderDisableBCChanged)

    Q_PROPERTY(DTColor placeHolderNormalTextColor READ placeHolderNormalTextColor WRITE setPlaceHolderNormalTextColor NOTIFY placeHolderNormalTextColorChanged)
    Q_PROPERTY(DTColor placeHolderDisableTextColor READ placeHolderDisableTextColor WRITE setPlaceHolderDisableTextColor NOTIFY placeHolderDisableTextColorChanged)
    Q_PROPERTY(DTColor disableTextColor READ disableTextColor WRITE setDisableTextColor NOTIFY disableTextColorChanged)
    Q_PROPERTY(DTColor normalTextColor READ normalTextColor WRITE setNormalTextColor NOTIFY normalTextColorChanged)

    Q_PROPERTY(int borderWidth READ borderWidth WRITE setBorderWidth NOTIFY borderWidthChanged)
    Q_PROPERTY(int focusBorderWidth READ focusBorderWidth WRITE setFocusBorderWidth NOTIFY focusBorderWidthChanged)
    Q_PROPERTY(DTColor normalBorderColor READ normalBorderColor WRITE setNormalBorderColor NOTIFY normalBorderColorChanged)
    Q_PROPERTY(DTColor hoverBorderColor READ hoverBorderColor WRITE setHoverBorderColor NOTIFY hoverBorderColorChanged)

    Q_PROPERTY(DTColor clickBorderColor READ clickBorderColor WRITE setClickBorderColor NOTIFY clickBorderColorChanged)
    Q_PROPERTY(DTColor disableBorderColor READ disableBorderColor WRITE setDisableBorderColor NOTIFY disableBorderColorChanged)
    Q_PROPERTY(DTColor focusBorderColor READ focusBorderColor WRITE setFocusBorderColor NOTIFY focusBorderColorChanged)


public:
    explicit UKUITextFiled(QQuickItem *parent = nullptr);
    ~UKUITextFiled();

    static UKUITextFiled* qmlAttachedProperties(QObject* parent);

    void initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance);


    double radius() const;
    void setRadius(double newRadius);

    double leftRightPadding() const;
    void setLeftRightPadding(double newLeftRightPadding);

    double upDownMargin() const;
    void setUpDownMargin(double newUpDownMargin);

    double space() const;
    void setSpace(double newSpace);

    int normalWidth() const;
    void setNormalWidth(int newNormalWidth);

    int normalHeight() const;
    void setNormalHeight(int newNormalHeight);

    const DTColor &normalBC() const;
    void setNormalBC(const DTColor &newNormalBC);

    const DTColor &clickedBC() const;
    void setClickedBC(const DTColor &newClickedBC);

    const DTColor &hoveredBC() const;
    void setHoveredBC(const DTColor &newHoveredBC);

    const DTColor &disableBC() const;
    void setDisableBC(const DTColor &newDisableBC);

    const DTColor &disableTextColor() const;
    void setDisableTextColor(const DTColor &newDisableTextColor);

    const DTColor &normalTextColor() const;
    void setNormalTextColor(const DTColor &newNormalTextColor);

    int borderWidth() const;
    void setBorderWidth(int newBorderWidth);

    int focusBorderWidth() const;
    void setFocusBorderWidth(int newFocusBorderWidth);

    const DTColor &normalBorderColor() const;
    void setNormalBorderColor(const DTColor &newNormalBorderColor);

    const DTColor &clickBorderColor() const;
    void setClickBorderColor(const DTColor &newClickBorderColor);

    const DTColor &disableBorderColor() const;
    void setDisableBorderColor(const DTColor &newDisableBorderColor);

    const DTColor &focusBorderColor() const;
    void setFocusBorderColor(const DTColor &newFocusBorderColor);

    const DTColor &hoverBorderColor() const;
    void setHoverBorderColor(const DTColor &newHoverBorderColor);

    const DTColor &placeHolderNormalTextColor() const;
    void setPlaceHolderNormalTextColor(const DTColor &newPlaceHolderNormalTextColor);

    const DTColor &placeHolderDisableTextColor() const;
    void setPlaceHolderDisableTextColor(const DTColor &newPlaceHolderDisableTextColor);

    const DTColor &placeHolderNormalBC() const;
    void setPlaceHolderNormalBC(const DTColor &newPlaceHolderNormalBC);

    const DTColor &placeHolderClickedBC() const;
    void setPlaceHolderClickedBC(const DTColor &newPlaceHolderClickedBC);

    const DTColor &placeHolderHoveredBC() const;
    void setPlaceHolderHoveredBC(const DTColor &newPlaceHolderHoveredBC);

    const DTColor &placeHolderDisableBC() const;
    void setPlaceHolderDisableBC(const DTColor &newPlaceHolderDisableBC);

    const DTColor &inputNormalBC() const;
    void setInputNormalBC(const DTColor &newInputNormalBC);

signals:

    void radiusChanged();

    void leftRightPaddingChanged();

    void upDownMarginChanged();

    void spaceChange();

    void normalWidthChanged();

    void normalHeightChanged();

    void normalBCChanged();

    void clickedBCChanged();

    void hoveredBCChanged();

    void disableBCChanged();

    void disableTextColorChanged();

    void normalTextColorChanged();

    void borderWidthChanged();

    void focusBorderWidthChanged();

    void normalBorderColorChanged();

    void clickBorderColorChanged();

    void disableBorderColorChanged();

    void focusBorderColorChanged();

    void hoverBorderColorChanged();

    void placeHolderNormalTextColorChanged();

    void placeHolderDisableTextColorChanged();

    void placeHolderNormalBCChanged();

    void placeHolderClickedBCChanged();

    void placeHolderHoveredBCChanged();

    void placeHolderDisableBCChanged();

    void inputNormalBCChanged();

private:

    double m_radius;
    double m_leftRightPadding;
    double m_upDownMargin;
    double m_space;
    int m_normalWidth;
    int m_normalHeight;
    Q_INVOKABLE DTColor m_normalBC;
    Q_INVOKABLE DTColor m_clickedBC;
    Q_INVOKABLE DTColor m_hoveredBC;
    Q_INVOKABLE DTColor m_disableBC;
    Q_INVOKABLE DTColor m_disableTextColor;
    Q_INVOKABLE DTColor m_normalTextColor;
    int m_borderWidth;
    int m_focusBorderWidth;
    Q_INVOKABLE DTColor m_normalBorderColor;
    Q_INVOKABLE DTColor m_clickBorderColor;
    Q_INVOKABLE DTColor m_disableBorderColor;
    Q_INVOKABLE DTColor m_focusBorderColor;
    Q_INVOKABLE DTColor m_hoverBorderColor;
    Q_INVOKABLE DTColor m_placeHolderNormalTextColor;
    Q_INVOKABLE DTColor m_placeHolderDisableTextColor;
    Q_INVOKABLE DTColor m_placeHolderNormalBC;
    Q_INVOKABLE DTColor m_placeHolderClickedBC;
    Q_INVOKABLE DTColor m_placeHolderHoveredBC;
    Q_INVOKABLE DTColor m_placeHolderDisableBC;
    Q_INVOKABLE DTColor m_inputNormalBC;

    UKUIGlobalDTConfig::GlobalDTConfig* m_instance = nullptr;

};
}
QML_DECLARE_TYPEINFO(UKUIQQC2Style::UKUITextFiled, QML_HAS_ATTACHED_PROPERTIES)

#endif // UKUITEXTFILED_H
