#include "ukuitooltip.h"
#include "qdebug.h"

using namespace UKUIQQC2Style;

UKUIToolTip::UKUIToolTip(QQuickItem *parent) : QQuickItem(parent)
{
    if(!qApp || !qApp->property("qqc2-globaltoken").isValid())
        return;
    TokenParameter * token = qApp->property("qqc2-globaltoken").value<TokenParameter *>();
    m_instance = token->getInstance();
    initParam(m_instance);
    connect(m_instance, &UKUIGlobalDTConfig::GlobalDTConfig::tokenChanged, [=](){
        initParam(m_instance);
    });
}

UKUIToolTip::~UKUIToolTip()
{

}

void UKUIToolTip::initParam(UKUIGlobalDTConfig::GlobalDTConfig* instance)
{
    setPadding(12);
    setBackColor(instance->baseActive());
    setBackBorderColor(instance->kLineWindowAcitive());
    //setShadowColor(instance->kShadowMin());
    setTextColor(instance->windowTextActive());
    setRadius(6);
}

UKUIToolTip* UKUIToolTip::qmlAttachedProperties(QObject* parent)
{
    auto p = qobject_cast<QQuickItem*>(parent);
    return new UKUIToolTip(p);
}

int UKUIToolTip::padding() const
{
    return m_padding;
}

void UKUIToolTip::setPadding(int newPadding)
{
    if (m_padding == newPadding)
        return;
    m_padding = newPadding;
    emit paddingChanged();
}

const DTColor &UKUIToolTip::backColor() const
{
    return m_backColor;
}

void UKUIToolTip::setBackColor(const DTColor &newBackColor)
{
    if (m_backColor == newBackColor)
        return;
    m_backColor = newBackColor;
    emit backColorChanged();
}

const DTColor &UKUIToolTip::backBorderColor() const
{
    return m_backBorderColor;
}

void UKUIToolTip::setBackBorderColor(const DTColor &newBackBorderColor)
{
    if (m_backBorderColor == newBackBorderColor)
        return;
    m_backBorderColor = newBackBorderColor;
    emit backBorderColorChanged();
}

const DTColor &UKUIToolTip::shadowColor() const
{
    return m_shadowColor;
}

void UKUIToolTip::setShadowColor(const DTColor &newShadowColor)
{
    if (m_shadowColor == newShadowColor)
        return;
    m_shadowColor = newShadowColor;
    emit shadowColorChanged();
}

const DTColor &UKUIToolTip::textColor() const
{
    return m_textColor;
}

void UKUIToolTip::setTextColor(const DTColor &newTextColor)
{
    if (m_textColor == newTextColor)
        return;
    m_textColor = newTextColor;
    emit textColorChanged();
}

int UKUIToolTip::radius() const
{
    return m_radius;
}

void UKUIToolTip::setRadius(int newRadius)
{
    if (m_radius == newRadius)
        return;
    m_radius = newRadius;
    emit radiusChanged();
}

int UKUIToolTip::margins() const
{
    return m_margins;
}

void UKUIToolTip::setMargins(int newMargins)
{
    if (m_margins == newMargins)
        return;
    m_margins = newMargins;
    emit marginsChanged();
}
