
import QtQuick 2.6
import QtQuick.Templates 2.5 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate


T.CheckBox {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)

    padding: 6
    spacing: StylePrivate.UKUICheckBox.space

    property var borderColor: control.checked ? (!control.enabled ? StylePrivate.UKUICheckBox.checked_disableIndicatorBorderColor :
                                                                    control.pressed ? StylePrivate.UKUICheckBox.checked_clickIndicatorBorderColor : control.hovered ?
                                                                    StylePrivate.UKUICheckBox.checked_hoverIndicatorBorderColor : StylePrivate.UKUICheckBox.checked_normalIndicatorBorderColor) :
                                                                   (!control.enabled ? StylePrivate.UKUICheckBox.disableIndicatorBorderColor : control.pressed ?
                                                                    StylePrivate.UKUICheckBox.clickIndicatorBorderColor : control.hovered ?
                                                                    StylePrivate.UKUICheckBox.hoverIndicatorBorderColor : StylePrivate.UKUICheckBox.normalIndicatorBorderColor)

    property var checkBoxColor: control.checked ? (!control.enabled ? StylePrivate.UKUICheckBox.checked_disableIndicatorColor :
                                                                        control.pressed ? StylePrivate.UKUICheckBox.checked_clickIndicatorColor : control.hovered ?
                                                                        StylePrivate.UKUICheckBox.checked_hoverIndicatorColor : StylePrivate.UKUICheckBox.checked_normalIndicatorColor) :
                                                                       (!control.enabled ? StylePrivate.UKUICheckBox.disableIndicatorColor : control.pressed ?
                                                                        StylePrivate.UKUICheckBox.clickIndicatorColor : control.hovered ?
                                                                        StylePrivate.UKUICheckBox.hoverIndicatorColor : StylePrivate.UKUICheckBox.normalIndicatorColor)
    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }

    // keep in sync with CheckDelegate.qml (shared CheckIndicator.qml was removed for performance reasons)
    indicator: Rectangle {
        implicitWidth: StylePrivate.UKUICheckBox.indicatorWidth
        implicitHeight: StylePrivate.UKUICheckBox.indicatorWidth

        x: control.text ? (control.mirrored ? control.width - width - control.rightPadding : control.leftPadding) : control.leftPadding + (control.availableWidth - width) / 2
        y: control.topPadding + (control.availableHeight - height) / 2
        radius: StylePrivate.UKUICheckBox.radius

        border.width: StylePrivate.UKUICheckBox.borderWidth
        border.color: getStartColor(borderColor)
        color: gradientRec.visible ? "transparent" : getStartColor(checkBoxColor)

        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                id:gradient
                GradientStop { position: 0.0; color: getStartColor(checkBoxColor) }

                GradientStop { position: 1.0; color: getEndColor(checkBoxColor)}
            }
            visible: !parseInterface.isSolidPattern(checkBoxColor)
        }

        Image {
            x: (parent.width - width) / 2
            y: (parent.height - height) / 2
            width: 14
            height: 12
//            defaultColor: "#353637"
//            color: control.palette.text
            source: {
                var model = !control.enabled ? "disenable" : control.checked ? "clicked" : "normal"
                return "image://imageProvider/" + "object-select-symbolic" + "/" + model;
            }
            visible: control.checkState === Qt.Checked
        }

        Rectangle {
            x: (parent.width - width) / 2
            y: (parent.height - height) / 2
            width: 9
            height: 1
            color: {
                getStartColor(!control.enabled ? StylePrivate.UKUICheckBox.checked_disableChildrenColor :
                                   control.pressed ? StylePrivate.UKUICheckBox.checked_clickChildrenColor:
                                                     control.hovered ? StylePrivate.UKUICheckBox.checked_hoverChildrenColor:
                                                                       StylePrivate.UKUICheckBox.checked_normalChildrenColor)
            }
            visible: control.checkState === Qt.PartiallyChecked
        }
    }

    contentItem: Label {
        leftPadding: control.indicator && !control.mirrored ? control.indicator.width + control.spacing : 0
        rightPadding: control.indicator && control.mirrored ? control.indicator.width + control.spacing : 0

        text: control.text
        font: StylePrivate.APPParameter.font
        color: getStartColor(control.enabled ? StylePrivate.UKUICheckBox.normalTextColor : StylePrivate.UKUICheckBox.disableTextColor)
    }
}
