import QtQuick 2.15
import QtQuick.Window 2.15
import QtQuick.Controls 2.15
import QtQuick.Controls.impl 2.15
import QtQuick.Templates 2.15 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.ComboBox {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)
    padding: StylePrivate.UKUIComboBox.leftRightPadding
    leftPadding: padding + (!control.mirrored || !indicator || !indicator.visible ? 0 : indicator.width + spacing)
    rightPadding: 0//padding + (control.mirrored || !indicator || !indicator.visible ? 0 : indicator.width + spacing)
    hoverEnabled: true

    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }

    delegate: ItemDelegate {
        width: ListView.view.width - scrollbar.width
        text: control.textRole ? (Array.isArray(control.model) ? modelData[control.textRole] : model[control.textRole]) : modelData
        hoverEnabled: control.hoverEnabled
    }

    indicator: Image {
        x: control.mirrored ? control.padding : control.width - width - control.padding
        y: control.topPadding + (control.availableHeight - height) / 2
        width: StylePrivate.APPParameter.iconWidth
        height: width
        source: {
            var model = !control.enabled ? "disenable" : "normal"

            if(!popup.visible){
                return "image://imageProvider/" + "ukui-down-symbolic" + "/" + model;
            }
            else{
                return "image://imageProvider/" + "ukui-up-symbolic" + "/" + model;
            }
        }
    }

    contentItem: T.TextField {
        leftPadding: 0//!control.mirrored ? 12 : control.editable && activeFocus ? 3 : 1
        rightPadding:0// control.mirrored ? 12 : control.editable && activeFocus ? 3 : 1
        anchors.verticalCenter: control.verticalCenter

        text: control.editable ? control.editText : control.displayText

        enabled: control.editable
        autoScroll: control.editable
        readOnly: control.down
        inputMethodHints: control.inputMethodHints
        validator: control.validator
        selectByMouse: control.selectTextByMouse

        font: StylePrivate.APPParameter.font
        color: getStartColor(!control.enabled ? StylePrivate.UKUIComboBox.disableTextColor : StylePrivate.UKUIComboBox.normalTextColor)
        selectionColor: control.palette.highlight
        selectedTextColor: control.palette.highlightedText
        verticalAlignment: Text.AlignVCenter
    }

    background: Rectangle {
        implicitWidth: StylePrivate.UKUIComboBox.normalWidth
        implicitHeight: StylePrivate.UKUIComboBox.normalHeight
        radius: StylePrivate.UKUIComboBox.radius

        color: gradientRec.visible ? "transparent" : getStartColor(StylePrivate.UKUIComboBox.normalBC)
        border.color: getStartColor(!control.enabled ? StylePrivate.UKUIComboBox.disableBorderColor :
                                     control.focus ? StylePrivate.UKUIComboBox.focusBorderColor : StylePrivate.UKUIComboBox.normalBorderColor)
        border.width: control.focus ? StylePrivate.UKUIComboBox.focusBorderWidth : StylePrivate.UKUIComboBox.borderWidth;


        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                id:gradient
                GradientStop { position: 0.0; color: getStartColor(StylePrivate.UKUIComboBox.normalBC) }

                GradientStop { position: 1.0; color: getEndColor(StylePrivate.UKUIComboBox.normalBC)}
            }
            visible: !parseInterface.isSolidPattern(StylePrivate.UKUIComboBox.normalBC)
        }
    }


    popup: Popup {
        id: pop
        y: control.height
        width: control.width
        height: Math.min(contentItem.implicitHeight, control.Window.height - topMargin - bottomMargin)
        topMargin: 6
        bottomMargin: 6
        contentItem: ListView {
            clip: true
            implicitHeight: contentHeight
            model: control.delegateModel
            //delegate: control.delegate
            currentIndex: control.highlightedIndex
            highlightMoveDuration: 0
            interactive: true

            ScrollBar.vertical: ScrollBar {
                anchors.right: parent.right
                id: scrollbar
                active: hovered || pressed
            }
//            onImplicitHeightChanged: {
//                console.log("listview implicitHeight changedddd", pop.height, implicitHeight, control.Window.height - topMargin - bottomMargin, visible, pop.visible)
//                pop.height = contentItem.implicitHeight >= (control.Window.height - topMargin - bottomMargin) ?
//                            (control.Window.height - topMargin - bottomMargin) : contentItem.implicitHeight;
//                console.log("listview implicitHeight 111111111", pop.height, implicitHeight, control.Window.height - topMargin - bottomMargin, visible)

//            }
//            onHeightChanged: console.log("listview height changed", height)
        }
    }
}
