
import QtQuick 2.7
import QtQuick.Window 2.15
import QtQuick.Layouts 1.2
import QtGraphicalEffects 1.0
import QtQuick.Controls 2.5 as Controls
import QtQuick.Templates 2.5 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.Menu {
    id: control
//    StylePrivate.APPParameter{
//        id: appP
//    }
    palette: StylePrivate.APPParameter.palette
    font: StylePrivate.APPParameter.font

    implicitWidth: Math.max(background ? background.implicitWidth : 0,
                            contentItem ? contentItem.implicitWidth + leftPadding + rightPadding : 0)
    implicitHeight: Math.max(background ? background.implicitHeight : 0,
                             contentItem ? contentItem.implicitHeight : 0) + topPadding + bottomPadding

    margins: 0

    leftPadding: StylePrivate.UKUIMenu.leftRightPadding
    rightPadding: StylePrivate.UKUIMenu.leftRightPadding
    topPadding: StylePrivate.UKUIMenu.topBottomPadding
    bottomPadding: StylePrivate.UKUIMenu.topBottomPadding

//    StylePrivate.UKUIMenu{
//        id: uMenu
//    }


    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }

    delegate: MenuItem {
        id: item
    }
    contentItem: ListView {
        implicitHeight: contentHeight
        property bool hasCheckables: false
        property bool hasIcons: false
        model: control.contentModel

        implicitWidth: {
            var maxWidth = 0;
            for (var i = 0; i < contentItem.children.length; ++i) {
                if(!(contentItem.children[i] instanceof Controls.MenuSeparator))
                maxWidth = Math.max(maxWidth, contentItem.children[i].width);
                //console.log("maxwidth..... iiiii,,,", contentItem.children[i].text, contentItem.children[i], contentItem.children[i].width, contentItem.children[i].implicitWidth)
            }
            return maxWidth + scrollbar.width;
        }

        //todo   why ApplicationWindow.window is null
        interactive: true//ApplicationWindow.window ? contentHeight > ApplicationWindow.window.height : false
        clip: true//interactive
        currentIndex: control.currentIndex || 0
        keyNavigationEnabled: true
        keyNavigationWraps: true

        //Component.onCompleted: console.log("listview......", ApplicationWindow.window.height)

        ScrollBar.vertical: ScrollBar {
            id: scrollbar
            active: hovered || pressed
        }
    }

    Connections {
        target: control.contentItem.contentItem
        function onChildrenChanged() {
            var checkable = false;
            var needIcon = false;
            for (var i in control.contentItem.contentItem.children) {
                var child = control.contentItem.contentItem.children[i];
                if (child.checkable) {
                    control.contentItem.hasCheckables = true;
                    checkable = true;
                }
                if (child.icon && child.icon.hasOwnProperty("name") && (child.icon.name.length > 0 || child.icon.source.toString().length > 0)) {
                    control.contentItem.hasIcons = true;
                    needIcon = true;
                }
            }
            if(checkable){
                for (var k in control.contentItem.contentItem.children) {
                    var childk = control.contentItem.contentItem.children[k];
                    if(childk.hasOwnProperty("itemLeftSpace")){
                        childk.itemLeftSpace = 20 + childk.leftPadding;
                        console.log("itemLeftSpace........", childk.text, childk.itemLeftSpace)
                    }
                }
            }
            if(needIcon){
                for (var j in control.contentItem.contentItem.children) {
                    var childj = control.contentItem.contentItem.children[j];
                    var b = childj.icon && childj.icon.hasOwnProperty("name") && (childj.icon.name.length > 0 || childj.icon.source.toString().length > 0);
                    if(childj.hasOwnProperty("labelLeftSpace"))
                        childj.labelLeftSpace = b ? 4 : 20;
                }
            }
            var maxWidth = 0;
            for (var l in control.contentItem.contentItem.children) {
                maxWidth = Math.max(maxWidth, control.contentItem.contentItem.children[l].width)
            }
            for (var m in control.contentItem.contentItem.children) {
                control.contentItem.contentItem.children[m].width = maxWidth;
            }
        }
    }

    enter: Transition {
        NumberAnimation {
            property: "opacity"
            from: 0
            to: 1
            easing.type: Easing.InOutQuad
            duration: 150
        }
    }

    exit: Transition {
        NumberAnimation {
            property: "opacity"
            from: 1
            to: 0
            easing.type: Easing.InOutQuad
            duration: 150
        }
    }

    background: Rectangle {
        radius: StylePrivate.UKUIMenu.radius

        color: gradientRec.visible ? "transparent" : getStartColor(StylePrivate.UKUIMenu.normalBC)
        border.color: getStartColor(StylePrivate.UKUIMenu.normalBorderColor)
        border.width: StylePrivate.UKUIMenu.border
        layer.enabled: true
        
        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                id:gradient
                GradientStop { position: 0.0; color: getStartColor(StylePrivate.UKUIMenu.normalBC) }

                GradientStop { position: 1.0; color: getEndColor(StylePrivate.UKUIMenu.normalBC)}
            }
            visible: !parseInterface.isSolidPattern(StylePrivate.UKUIMenu.normalBC)
        }

        layer.effect: DropShadow {
            transparentBorder: true
            radius: StylePrivate.UKUIMenu.radius
            samples: StylePrivate.UKUIMenu.radius
            horizontalOffset: 0
            verticalOffset: 2
            color: getStartColor(enabled ? StylePrivate.UKUIMenu.shadowNormalColor : StylePrivate.UKUIMenu.shadowDisableColor)
        }
    }
}
