
import QtQuick 2.6
import QtQuick.Layouts 1.2
import QtQuick.Templates 2.5 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate
import QtQuick.Controls 2.5

T.MenuItem {
    id: controlRoot

    palette: StylePrivate.APPParameter.palette
    font: StylePrivate.APPParameter.font


    width: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            image.width + label.width + labelLeftSpace + leftPadding + rightPadding +
                            (controlRoot.checkable ? /*arrow.implicitWidth*/StylePrivate.UKUIMenuItem.imageWidth + StylePrivate.UKUIMenuItem.imageSpace : 0) +
                            (controlRoot.subMenu ? /*indicator.implicitWidth*/StylePrivate.UKUIMenuItem.imageWidth + StylePrivate.UKUIMenuItem.imageSpace : 0) + itemLeftSpace)
    implicitHeight: visible ? Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             Math.max(contentItem.height,
                                      controlRoot.subMenu ? indicator.implicitHeight : 0) + topPadding + bottomPadding, StylePrivate.UKUIMenuItem.normalHeight) : 0

    baselineOffset: contentItem.y + contentItem.baselineOffset

//    Layout.fillWidth: true
    padding: StylePrivate.UKUIMenuItem.topBottomPadding

    property int gridUnit: fontMetrics.height
    property int labelLeftSpace: 0
    property int itemLeftSpace: (!controlRoot.checkable/* && !controlRoot.subMenu*/) ? controlRoot.leftPadding : 20 + controlRoot.leftPadding
    property alias backColor: backrect.color

    property var bacDtColor: !controlRoot.enabled ? StylePrivate.UKUIMenuItem.disableBC :
                                                    controlRoot.pressed ? StylePrivate.UKUIMenuItem.clickedBC :
                                                                            controlRoot.hovered ? StylePrivate.UKUIMenuItem.hoveredBC : StylePrivate.UKUIMenuItem.normalBC

    leftPadding: StylePrivate.UKUIMenuItem.leftRightPadding/* : Math.floor(gridUnit/4)*2*/
    rightPadding: StylePrivate.UKUIMenuItem.leftRightPadding// Math.floor(gridUnit/4)*2
    hoverEnabled: true


//    StylePrivate.APPParameter{
//        id: appP
//    }
//    StylePrivate.UKUIButton{
//        id: btn
//    }
//    StylePrivate.UKUIMenuItem{
//        id: mItem
//    }
    NormalControlColor{
    id:ncColor
    }
    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }
    Shortcut {
        //in case of explicit & the button manages it by itself
        enabled: !(RegExp(/\&[^\&]/).test(controlRoot.text))

        onActivated: {
            if (controlRoot.checkable) {
                controlRoot.toggle();
            } else {
                controlRoot.clicked();
            }
        }
    }

    contentItem:Item{
        anchors.left: controlRoot.left
        anchors.leftMargin: itemLeftSpace
        anchors.right: parent.right
        anchors.rightMargin: controlRoot.rightPadding
        Image {
            id: image
            source: //controlRoot.icon.source
            {
                if((controlRoot.icon.source.toString() === "" && controlRoot.icon.name.toString() === ""))
                    return controlRoot.icon.source

                var model = !controlRoot.enabled ? "disenable" : controlRoot.pressed ? "clicked" : controlRoot.hovered ? "hover" : "normal"

                let s = controlRoot.icon.source.toString()
                return "image://imageProvider/" + s + "/" + model;
            }
            anchors.verticalCenter: parent.verticalCenter
            width: (controlRoot.display !== AbstractButton.TextOnly && source !== "" && status != Image.Null) ? StylePrivate.UKUIMenuItem.imageWidth : 0
            visible: controlRoot.display !== AbstractButton.TextOnly && source !== "" && status != Image.Null
        }
        Label {
            id:label
            text: controlRoot.text
            font:controlRoot.font
            color: getStartColor(controlRoot.enabled ? StylePrivate.UKUIMenuItem.normalTextColor : StylePrivate.UKUIMenuItem.disableTextColor)
            visible: controlRoot.display !== AbstractButton.IconOnly && text !== ""

            anchors.verticalCenter: parent.verticalCenter

            anchors.left: image.right
            anchors.leftMargin: labelLeftSpace//(image.visible && image.status !== Image.Null) ? 4 : labelLeftSpace
        }

    }

    indicator: Image {
        x: controlRoot.mirrored ? controlRoot.width - width - controlRoot.rightPadding : controlRoot.leftPadding
        y: controlRoot.topPadding + (controlRoot.availableHeight - height) / 2

        visible: controlRoot.checked
        source: controlRoot.checkable ? "image://imageProvider/object-select-symbolic" : ""

        width: StylePrivate.UKUIMenuItem.imageWidth
        height: StylePrivate.UKUIMenuItem.imageWidth
    }

    arrow: Image {
        x: controlRoot.mirrored ? controlRoot.leftPadding : controlRoot.width - width - controlRoot.rightPadding
        anchors.verticalCenter: parent.verticalCenter
        width: StylePrivate.UKUIMenuItem.imageWidth
        height: StylePrivate.UKUIMenuItem.imageWidth

        visible: controlRoot.subMenu
        mirror: controlRoot.mirrored
        source: controlRoot.subMenu ? "image://imageProvider/ukui-end-symbolic" : ""
    }

    background:
        Rectangle {
        id: backrect
        width: controlRoot.width
        height: controlRoot.height
        radius: StylePrivate.UKUIMenuItem.radius
        //opacity: (controlRoot.highlighted || controlRoot.hovered || controlRoot.pressed || controlRoot.checked) ? 1 : 0
        border.width: 1

        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                id:gradient
                GradientStop { position: 0.0; color: getStartColor(bacDtColor) }

                GradientStop { position: 1.0; color: getEndColor(bacDtColor)}
            }
            visible: !parseInterface.isSolidPattern(bacDtColor)
        }
    }

    onPressedChanged: {
        stateChange()
    }
    onHoveredChanged: {
        stateChange()

    }
    Component.onCompleted: {
        stateChange()
    }

    function stateChange()
    {
        //controlColor = !enable ? StylePrivate.UKUIButton.disableHBC : click ? StylePrivate.UKUIButton.clickedHBC : hover ? StylePrivate.UKUIButton.hoveredHBC : StylePrivate.UKUIButton.normalHBC

        backColor = gradientRec.visible ? "transparent" : getStartColor(bacDtColor);

    backrect.border.color = getStartColor(!controlRoot.enabled ? StylePrivate.UKUIMenuItem.disableBorderColor :
                                                  controlRoot.pressed ? StylePrivate.UKUIMenuItem.clickBorderColor :
                                                  controlRoot.hovered ? StylePrivate.UKUIMenuItem.hoverBorderColor : StylePrivate.UKUIMenuItem.normalBorderColor);
    }
//    onVisibleChanged: {
//        if(visible){
//            var backWidth = implicitBackgroundWidth + leftInset + rightInset;
//            var itemWidth = iconLabel.width + leftPadding + rightPadding +
//                    (arrow.visible ? arrow.implicitWidth : 0) +
//                    (indicator.visible ? indicator.implicitWidth : 0)
//            width =  Math.max(backWidth, itemWidth)
//            console.log("menuitem visible..........", controlRoot.text, width, backWidth, itemWidth, iconLabel.width, implicitBackgroundWidth)

//        }
//    }
    property variant fontMetrics: TextMetrics {
        text: "M"
        function roundedIconSize(size) {
            if (size < 16) {
                return size;
            } else if (size < 22) {
                return 16;
            } else if (size < 32) {
                return 22;
            } else if (size < 48) {
                return 32;
            } else if (size < 64) {
                return 48;
            } else {
                return size;
            }
        }
    }
}





