import QtQuick 2.12
import QtQuick.Templates 2.12 as T
import QtQuick.Controls 2.12
import QtQuick.Controls.impl 2.12
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.ProgressBar {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding)

    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }

    background: Rectangle {
        radius: StylePrivate.UKUIProgressBar.radius
        implicitWidth: StylePrivate.UKUIProgressBar.normalWidth
        implicitHeight: StylePrivate.UKUIProgressBar.normalHeight

        height: StylePrivate.UKUIProgressBar.normalHeight

        color: gradientRec.visible ? "transparent" : getStartColor(StylePrivate.UKUIProgressBar.normalColor)
        border.width: StylePrivate.UKUIProgressBar.borderWidth
        border.color: getStartColor(StylePrivate.UKUIProgressBar.borderColor)

        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                GradientStop { position: 0.0; color: getStartColor(StylePrivate.UKUIProgressBar.normalColor) }

                GradientStop { position: 1.0; color: getEndColor(StylePrivate.UKUIProgressBar.normalColor)}
            }
            visible: !parseInterface.isSolidPattern(StylePrivate.UKUIProgressBar.normalColor)
        }


    }

    contentItem: Item{
        implicitHeight: background.height
        implicitWidth: background.width
        Rectangle {
            x: !control.mirrored ? 0 : (control.width * (1.0 - control.position))
            implicitHeight: StylePrivate.UKUIProgressBar.normalHeight
            implicitWidth: control.width * control.position
            visible: !control.indeterminate
            //indeterminate: control.visible && control.indeterminate
            color: gradientItem.visible ? "transparent" : getStartColor(StylePrivate.UKUIProgressBar.childrenColor)
            radius: StylePrivate.UKUIProgressBar.radius

            Rectangle{
                id: gradientItem
                anchors.fill: parent
                radius: parent.radius
                border.width: parent.border.width
                border.color: parent.border.color
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: getStartColor(StylePrivate.UKUIProgressBar.childrenColor) }

                    GradientStop { position: 1.0; color: getEndColor(StylePrivate.UKUIProgressBar.childrenColor)}
                }
                visible: !parseInterface.isSolidPattern(StylePrivate.UKUIProgressBar.childrenColor)
            }
        }
        Label{
            visible: !control.indeterminate
            anchors.centerIn: parent
            text: (control.position * 100).toString() + "%"
        }
        Rectangle {
            id:rec
            implicitHeight: StylePrivate.UKUIProgressBar.normalHeight
            implicitWidth: StylePrivate.UKUIProgressBar.indeterminateChildrenWidth
            visible: control.indeterminate
            //indeterminate: control.visible && control.indeterminate
            color: gradientInterminate.visible ? "transparent" : getStartColor(StylePrivate.UKUIProgressBar.childrenColor)
            radius: StylePrivate.UKUIProgressBar.radius

            Rectangle{
                id: gradientInterminate
                anchors.fill: parent
                radius: parent.radius
                border.width: parent.border.width
                border.color: parent.border.color
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: getStartColor(StylePrivate.UKUIProgressBar.childrenColor) }

                    GradientStop { position: 1.0; color: getEndColor(StylePrivate.UKUIProgressBar.childrenColor)}
                }
                visible: !parseInterface.isSolidPattern(StylePrivate.UKUIProgressBar.childrenColor)
            }
        }

        Timer {
            id: slideTimer
            interval: 1
            running: control.indeterminate
            repeat: true
            onTriggered: {
                slideAnimation.start()
            }
        }

        PropertyAnimation {
            id: slideAnimation
            target: rec
            property: "x"
            to: rec.x + rec.width >= control.width ? 0 : control.width - rec.width
            duration: 500 + control.width
            easing.type: Easing.InOutQuad
        }
    }
}
