import QtQuick 2.12
import QtQuick.Controls 2.12
import QtQuick.Controls.impl 2.12
import QtQuick.Templates 2.12 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.Slider {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitHandleWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitHandleHeight + topPadding + bottomPadding)

    padding: 6

    hoverEnabled: true

    property var handleColor: !control.enabled ? StylePrivate.UKUISlider.disableHandleColor : handleClick ? StylePrivate.UKUISlider.clickHandleColor :
                               handleHover ?StylePrivate.UKUISlider.hoverHandleColor : StylePrivate.UKUISlider.normalHandleColor
    property var handleBorderColor: !control.enabled ? StylePrivate.UKUISlider.disableHandleBorderColor : handleClick ? StylePrivate.UKUISlider.clickHandleBorderColor :
                                    handleHover ? StylePrivate.UKUISlider.hoverHandleBorderColor : StylePrivate.UKUISlider.normalHandleBorderColor

    property bool handleClick: false
    property bool handleHover: false
    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }

    handle: Rectangle {
        id: handleRec
        x: control.leftPadding + (control.horizontal ? control.visualPosition * (control.availableWidth - width) : (control.availableWidth - width) / 2)
        y: control.topPadding + (control.horizontal ? (control.availableHeight - height) / 2 : control.visualPosition * (control.availableHeight - height))
        implicitWidth: StylePrivate.UKUISlider.handleHeight
        implicitHeight: StylePrivate.UKUISlider.handleHeight
        radius: width / 2
        color: gradientHandleRec.visible ? "transparent" : getStartColor(handleColor)
        border.width: StylePrivate.UKUISlider.handleBorderWidth
        border.color: getStartColor(handleBorderColor)



        Rectangle{
            id: gradientHandleRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                GradientStop { position: 0.0; color: getStartColor(handleBorderColor) }

                GradientStop { position: 1.0; color: getEndColor(handleBorderColor)}
            }
            visible: !parseInterface.isSolidPattern(handleBorderColor)
        }

        MouseArea{
            id: mouseArea
            anchors.fill: parent
            hoverEnabled: true
            onPressed: handleClick = true
            onReleased: handleClick = false
            onEntered: handleHover = true
            onExited: handleHover = false

        }
    }

    background: Item{
        id: item

//        x: control.leftPadding + (control.horizontal ? 0 : (control.availableWidth - width) / 2)
//        y: control.topPadding + (control.horizontal ? (control.availableHeight - height) / 2 : 0)
        implicitWidth: control.horizontal ? (StylePrivate.UKUISlider.normalWidth + handle.width) : StylePrivate.UKUISlider.normalHeight
        implicitHeight: control.horizontal ? StylePrivate.UKUISlider.normalHeight : (StylePrivate.UKUISlider.normalWidth + handle.height)

        Rectangle {
            width: item.width
            height: item.height
            border.color: getStartColor(StylePrivate.UKUISlider.focusBorderColor)
            border.width: control.activeFocus ? StylePrivate.UKUISlider.focusBorderWidth : 0
            scale: control.horizontal && control.mirrored ? -1 : 1

            Rectangle{
                id: unGroove
                x: (control.horizontal ? handle.width / 2 : ((item.width - width) / 2))
                y:(control.horizontal ? ((item.height - height) / 2) : handle.height / 2)
                width: control.horizontal ? (item.width - handle.width) : StylePrivate.UKUISlider.grooveHeight
                height: control.horizontal ? StylePrivate.UKUISlider.grooveHeight : (item.height - handle.height)
                radius: control.horizontal ? height/2 : width/2
                border.width: StylePrivate.UKUISlider.grooveBorderWidth
                border.color: getStartColor(!control.enabled ? StylePrivate.UKUISlider.disableUnGrooveBorderColor : StylePrivate.UKUISlider.normalUnGrooveBorderColor)
                color: gradientUNGrooveRec.visible ? "transparent" : getStartColor(!control.enabled ? StylePrivate.UKUISlider.disableUnGrooveColor : StylePrivate.UKUISlider.normalUnGrooveColor)

                Rectangle{
                    id: gradientUNGrooveRec
                    anchors.fill: parent
                    radius: parent.radius
                    border.width: parent.border.width
                    border.color: parent.border.color
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: getStartColor(!control.enabled ? StylePrivate.UKUISlider.disableUnGrooveColor : StylePrivate.UKUISlider.normalUnGrooveColor) }

                        GradientStop { position: 1.0; color: getEndColor(!control.enabled ? StylePrivate.UKUISlider.disableUnGrooveColor : StylePrivate.UKUISlider.normalUnGrooveColor)}
                    }
                    visible: !parseInterface.isSolidPattern(!control.enabled ? StylePrivate.UKUISlider.disableUnGrooveColor : StylePrivate.UKUISlider.normalUnGrooveColor)
                }
            }

            Rectangle{
                id:groove
                x: (control.horizontal ? handle.width / 2  : ((item.width - width) / 2))
                y: (control.horizontal ? ((item.height - height) / 2) : handle.height / 2)
                width: control.horizontal ? control.position * unGroove.width : StylePrivate.UKUISlider.grooveHeight
                height: control.horizontal ? StylePrivate.UKUISlider.grooveHeight : control.position * unGroove.height
                radius: StylePrivate.UKUISlider.grooveHeight / 2
                border.width: StylePrivate.UKUISlider.grooveBorderWidth
                border.color: getStartColor(!control.enabled ? StylePrivate.UKUISlider.disableGrooveBorderColor : StylePrivate.UKUISlider.normalGrooveBorderColor)
                color: gradientGrooveRec.visible ? "transparent" : getStartColor(!control.enabled ? StylePrivate.UKUISlider.disableGrooveColor : StylePrivate.UKUISlider.normalGrooveColor)
                Rectangle{
                    id: gradientGrooveRec
                    anchors.fill: parent
                    radius: parent.radius
                    border.width: parent.border.width
                    border.color: parent.border.color
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: getStartColor(!control.enabled ? StylePrivate.UKUISlider.disableGrooveColor : StylePrivate.UKUISlider.normalGrooveColor) }

                        GradientStop { position: 1.0; color: getEndColor(!control.enabled ? StylePrivate.UKUISlider.disableGrooveColor : StylePrivate.UKUISlider.normalGrooveColor)}
                    }
                    visible: !parseInterface.isSolidPattern(!control.enabled ? StylePrivate.UKUISlider.disableGrooveColor : StylePrivate.UKUISlider.normalGrooveColor)
                }
            }

//            Rectangle {
//                id: handle
//                x: control.horizontal ? (control.position * control.width - width/2) : ((item.width - width) / 2)
//                y: control.horizontal ? ((item.height - height) / 2) : (control.position * parent.height - height/2)
//                width: StylePrivate.UKUISlider.grooveHeight
//                height: StylePrivate.UKUISlider.grooveHeight

//                radius: StylePrivate.UKUISlider.grooveHeight / 2
//                color: !control.enabled ? StylePrivate.UKUISlider.disableHandleColor : StylePrivate.UKUISlider.normalHandleColor
//                border.width: StylePrivate.UKUISlider.handleBorderWidth
//                border.color: !control.enabled ? StylePrivate.UKUISlider.disableHandleBorderColor : StylePrivate.UKUISlider.normalHandleBorderColor
//            }
        }
    }
}
