import QtQuick 2.12
import QtQuick.Controls 2.12
import QtQuick.Controls.impl 2.12
import QtQuick.Templates 2.12 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.SpinBox {
    id: control
    hoverEnabled: true

    implicitWidth: implicitBackgroundWidth + leftInset + rightInset//Math.max(implicitBackgroundWidth + leftInset + rightInset,
                   //         contentItem.implicitWidth + 2 * padding +
                   //         up.implicitIndicatorWidth)
    implicitHeight: Math.max(implicitContentHeight + topPadding + bottomPadding,
                             implicitBackgroundHeight,
                             up.implicitIndicatorHeight + down.implicitIndicatorHeight)

    padding: StylePrivate.UKUISpinBox.padding
//    leftPadding: padding + (control.mirrored ? (up.indicator ? up.indicator.width : 0) : (down.indicator ? down.indicator.width : 0))
    rightPadding: padding + (control.mirrored ? (down.indicator ? down.indicator.width : 0) : (up.indicator ? up.indicator.width : 0))

    font: StylePrivate.APPParameter.font

    property bool upHover: control.up.hovered
    property bool upClick: control.up.pressed
    property bool downHover: control.down.hovered
    property bool downClick: control.down.pressed
    property var backColor: !control.enabled ? StylePrivate.UKUISpinBox.disableColor : control.activeFocus ? StylePrivate.UKUISpinBox.focusColor :
                             control.hovered ? StylePrivate.UKUISpinBox.hoverColor : StylePrivate.UKUISpinBox.normalColor

    property var backBorderColor: !control.enabled ? StylePrivate.UKUISpinBox.disableBorderColor : control.activeFocus ? StylePrivate.UKUISpinBox.focusBorderColor :
                                   control.hovered ? StylePrivate.UKUISpinBox.hoverBorderColor : StylePrivate.UKUISpinBox.normalBorderColor

    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }
    onUpHoverChanged:{
        upRadiusRec.canvas.requestPaint();
    }
    onUpClickChanged:{
        upRadiusRec.canvas.requestPaint();
    }
    onDownHoverChanged:{
        downRadiusRec.canvas.requestPaint();
    }
    onDownClickChanged:{
        downRadiusRec.canvas.requestPaint();
    }

    validator: IntValidator {
        locale: control.locale.name
        bottom: Math.min(control.from, control.to)
        top: Math.max(control.from, control.to)
    }

    contentItem: TextInput {
        id:textInput
        z: 2
        text: control.displayText
        font: control.font
        color: getStartColor(!control.enabled ? StylePrivate.UKUISpinBox.disableTextColor : StylePrivate.UKUISpinBox.normalTextColor)
        selectionColor: control.palette.highlight
        selectedTextColor: control.palette.highlightedText
        horizontalAlignment: Qt.AlignLeft
        verticalAlignment: Qt.AlignVCenter

        readOnly: !control.editable
        validator: control.validator
        inputMethodHints: control.inputMethodHints
    }

    up.indicator: RadiusRectangle {
        id:upRadiusRec
        z:3
        implicitWidth: StylePrivate.UKUISpinBox.btnNormalWidth
        implicitHeight: StylePrivate.UKUISpinBox.btnNormalHeight
        anchors.right: control.right
        anchors.top: parent.top

        leftTopRadius: StylePrivate.UKUISpinBox.radius
        rightTopRadius: StylePrivate.UKUISpinBox.radius
        leftBottomRadius: 0
        rightBottomRadius: 0
        backColor: !control.enabled ? StylePrivate.UKUISpinBox.btnDisableColor : control.up.pressed ? StylePrivate.UKUISpinBox.btnClickColor :
                    control.up.hovered ? StylePrivate.UKUISpinBox.btnHoverColor : StylePrivate.UKUISpinBox.btnNormalColor
        borderColor: !control.enabled ? StylePrivate.UKUISpinBox.btnDisableBorderColor : upClick ? StylePrivate.UKUISpinBox.btnClickBorderColor :
                      upHover ? StylePrivate.UKUISpinBox.btnHoverBorderColor : StylePrivate.UKUISpinBox.btnNormalBorderColor
        borderWidth: StylePrivate.UKUISpinBox.btnBorderWidth
        Image {
            anchors.centerIn: parent
            source: {
                var model = !control.enabled ? "disenable" : control.checked ? "clicked" : "normal"
                return "image://imageProvider/" + "ukui-up-symbolic" + "/" + model;
            }
        }
    }

    down.indicator: RadiusRectangle {
        id: downRadiusRec
        z:3
        implicitWidth: StylePrivate.UKUISpinBox.btnNormalWidth
        implicitHeight: StylePrivate.UKUISpinBox.btnNormalHeight

        anchors.right: control.right
        anchors.bottom: parent.bottom
        leftTopRadius: 0
        rightTopRadius: 0
        leftBottomRadius: StylePrivate.UKUISpinBox.radius
        rightBottomRadius: StylePrivate.UKUISpinBox.radius

        backColor: !control.enabled ? StylePrivate.UKUISpinBox.btnDisableColor : control.down.pressed ? StylePrivate.UKUISpinBox.btnClickColor :
                    control.down.hovered ? StylePrivate.UKUISpinBox.btnHoverColor : StylePrivate.UKUISpinBox.btnNormalColor
        borderColor: !control.enabled ? StylePrivate.UKUISpinBox.btnDisableBorderColor : downClick ? StylePrivate.UKUISpinBox.btnClickBorderColor :
                      downHover ? StylePrivate.UKUISpinBox.btnHoverBorderColor : StylePrivate.UKUISpinBox.btnNormalBorderColor
        borderWidth: StylePrivate.UKUISpinBox.btnBorderWidth


        Image {
            anchors.centerIn: parent
            source: {
                var model = !control.enabled ? "disenable" : control.checked ? "clicked" : "normal"
                return "image://imageProvider/" + "ukui-down-symbolic" + "/" + model;
            }
        }
    }

    background: Rectangle {
        implicitWidth: StylePrivate.UKUISpinBox.normalWidth
        implicitHeight: StylePrivate.UKUISpinBox.normalHeight
        radius: StylePrivate.UKUISpinBox.radius
        border.width: control.activeFocus ? StylePrivate.UKUISpinBox.focusBorderWidth : StylePrivate.UKUISpinBox.normalBorderWidth
        color: gradientRec.visible ? "transparent" : getStartColor(backColor)
        border.color: getStartColor(backBorderColor)
        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                GradientStop { position: 0.0; color: getStartColor(backColor) }

                GradientStop { position: 1.0; color: getEndColor(backColor)}
            }
            visible: !parseInterface.isSolidPattern(backColor)
        }
    }
}
