
import QtQuick 2.6
import QtGraphicalEffects 1.0
import QtQuick.Controls 2.5 as Controls
import QtQuick.Templates 2.5 as T
import org.ukui.qqc2style.private 1.0 as StylePrivate


T.ToolTip {
    id: controlRoot

    palette: StylePrivate.APPParameter.palette
    font: StylePrivate.APPParameter.font


    x: parent ? Math.round((parent.width - implicitWidth) / 2) : 0
    y: -implicitHeight - 3

    // Always show the tooltip on top of everything else
    z: 999

    implicitWidth: contentItem.implicitWidth + leftPadding + rightPadding
    implicitHeight: contentItem.implicitHeight + topPadding + bottomPadding

    margins: StylePrivate.UKUIToolTip.margins
    padding: StylePrivate.UKUIToolTip.padding


    // Timeout based on text length, from QTipLabel::restartExpireTimer
    timeout: 10000 + 40 * Math.max(0, text.length - 100)

    closePolicy: T.Popup.CloseOnEscape | T.Popup.CloseOnPressOutsideParent | T.Popup.CloseOnReleaseOutsideParent

    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }
    contentItem: Controls.Label {
        text: controlRoot.text
        wrapMode: Text.WordWrap
        font: controlRoot.font
        color: getStartColor(StylePrivate.UKUIToolTip.textColor)
    }


    background: Rectangle {
        radius: StylePrivate.UKUIToolTip.radius

        //border.color: controlRoot.palette.dark
        color: gradientRec.visible ? "transparent" : getStartColor(StylePrivate.UKUIToolTip.backColor)

        layer.enabled: true

        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                GradientStop { position: 0.0; color: getStartColor(StylePrivate.UKUIToolTip.backColor) }

                GradientStop { position: 1.0; color: getEndColor(StylePrivate.UKUIToolTip.backColor)}
            }
            visible: !parseInterface.isSolidPattern(StylePrivate.UKUIToolTip.backColor)
        }
        layer.effect: DropShadow {
            transparentBorder: true
            radius: 4
            samples: 8
            horizontalOffset: 0
            verticalOffset: 0
            color: getStartColor(StylePrivate.UKUIToolTip.shadowColor)

        }
    }
}
