/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Jing Tan <tanjing@kylinos.cn>
 *
 */

#include "readconfig.h"
#include <QDebug>
#include <QFile>
#include <QString>
#include <QStringList>
#include <QStandardPaths>
#include <QGSettings>
#include <QMetaEnum>
#include <QCoreApplication>
#include <QBrush>
#include <QPainter>
#include "platformthemedebug.h"

#define ThemeConfigPath "/usr/share/config/globaltheme/token/"
#define DefaultConfigName "kdefault-light.css"

using namespace UKUIGlobalDTConfig;

GlobalDTConfigPrivate::GlobalDTConfigPrivate()
{
    {
        windowTextActive         = QBrush(Qt::NoBrush);
        windowTextInactive       = QBrush(Qt::NoBrush);
        windowTextDisable        = QBrush(Qt::NoBrush);
        buttonActive             = QBrush(Qt::NoBrush);
        buttonInactive           = QBrush(Qt::NoBrush);
        buttonDisable            = QBrush(Qt::NoBrush);
        lightActive              = QBrush(Qt::NoBrush);
        lightInactive            = QBrush(Qt::NoBrush);
        lightDisable             = QBrush(Qt::NoBrush);
        midlightActive           = QBrush(Qt::NoBrush);
        midlightInactive         = QBrush(Qt::NoBrush);
        midlightDisable          = QBrush(Qt::NoBrush);
        darkActive               = QBrush(Qt::NoBrush);
        darkInactive             = QBrush(Qt::NoBrush);
        darkDisable              = QBrush(Qt::NoBrush);
        midActive                = QBrush(Qt::NoBrush);
        midInactive              = QBrush(Qt::NoBrush);
        midDisable               = QBrush(Qt::NoBrush);
        textActive               = QBrush(Qt::NoBrush);
        textInactive             = QBrush(Qt::NoBrush);
        textDisable              = QBrush(Qt::NoBrush);
        brightTextActive         = QBrush(Qt::NoBrush);
        brightTextInactive       = QBrush(Qt::NoBrush);
        brightTextDisable        = QBrush(Qt::NoBrush);
        buttonTextActive         = QBrush(Qt::NoBrush);
        buttonTextInactive       = QBrush(Qt::NoBrush);
        buttonTextDisable        = QBrush(Qt::NoBrush);
        baseActive               = QBrush(Qt::NoBrush);
        baseInactive             = QBrush(Qt::NoBrush);
        baseDisable              = QBrush(Qt::NoBrush);
        windowActive             = QBrush(Qt::NoBrush);
        windowInactive           = QBrush(Qt::NoBrush);
        windowDisable            = QBrush(Qt::NoBrush);
        shadowActive             = QBrush(Qt::NoBrush);
        shadowInactive           = QBrush(Qt::NoBrush);
        shadowDisable            = QBrush(Qt::NoBrush);
        highLightActive          = QBrush(Qt::NoBrush);
        highLightInactive        = QBrush(Qt::NoBrush);
        highLightDisable         = QBrush(Qt::NoBrush);
        highLightedTextActive    = QBrush(Qt::NoBrush);
        highLightedTextInactive  = QBrush(Qt::NoBrush);
        highLightedTextDisable   = QBrush(Qt::NoBrush);
        linkActive               = QBrush(Qt::NoBrush);
        linkInactive             = QBrush(Qt::NoBrush);
        linkDisable              = QBrush(Qt::NoBrush);
        linkVisitedActive        = QBrush(Qt::NoBrush);
        linkVisitedInactive      = QBrush(Qt::NoBrush);
        linkVisitedDisable       = QBrush(Qt::NoBrush);
        alternateBaseActive      = QBrush(Qt::NoBrush);
        alternateBaseInactive    = QBrush(Qt::NoBrush);
        alternateBaseDisable     = QBrush(Qt::NoBrush);
        noRoleActive             = QBrush(Qt::NoBrush);
        noRoleInactive           = QBrush(Qt::NoBrush);
        noRoleDisable            = QBrush(Qt::NoBrush);
        toolTipBaseActive        = QBrush(Qt::NoBrush);
        toolTipBaseInactive      = QBrush(Qt::NoBrush);
        toolTipBaseDisable       = QBrush(Qt::NoBrush);
        toolTipTextActive        = QBrush(Qt::NoBrush);
        toolTipTextInactive      = QBrush(Qt::NoBrush);
        toolTipTextDisable       = QBrush(Qt::NoBrush);
        placeholderTextActive    = QBrush(Qt::NoBrush);
        placeholderTextInactive  = QBrush(Qt::NoBrush);
        placeholderTextDisable   = QBrush(Qt::NoBrush);

        kComponentNormal                 = QBrush(Qt::NoBrush);
        kLineBrandDisable                = QBrush(Qt::NoBrush);
        kFontWhiteSecondary              = QBrush(Qt::NoBrush);
        kGray12                          = QBrush(Qt::NoBrush);
        kContainSecondaryAlpphaNormal    = QBrush(Qt::NoBrush);
        kGray16                          = QBrush(Qt::NoBrush);
        kBrand1                          = QBrush(Qt::NoBrush);
        kLineComponentNormal             = QBrush(Qt::NoBrush);
        kLineBrandClick                  = QBrush(Qt::NoBrush);
        kGray3                           = QBrush(Qt::NoBrush);
        kGray0                           = QBrush(Qt::NoBrush);
        kLineDisable                     = QBrush(Qt::NoBrush);
        kGrayAlpha2                      = QBrush(Qt::NoBrush);
        kGrayAlpha0                      = QBrush(Qt::NoBrush);
        kBrand2                          = QBrush(Qt::NoBrush);
        kLineNormal                      = QBrush(Qt::NoBrush);
        kGrayAlpha5                      = QBrush(Qt::NoBrush);
        kGrayAlpha12                     = QBrush(Qt::NoBrush);
        kErrorClick                      = QBrush(Qt::NoBrush);
        kLineWindowActive                = QBrush(Qt::NoBrush);
        kComponentAlphaClick             = QBrush(Qt::NoBrush);
        kBrand3                          = QBrush(Qt::NoBrush);
        kSuccessNormal                   = QBrush(Qt::NoBrush);
        kGrayAlpha1                      = QBrush(Qt::NoBrush);
        kFontWhiteSecondaryDisable       = QBrush(Qt::NoBrush);
        kGray4                           = QBrush(Qt::NoBrush);
        kContainClick                    = QBrush(Qt::NoBrush);
        kGray8                           = QBrush(Qt::NoBrush);
        kGrayAlpha4                      = QBrush(Qt::NoBrush);
        kModalmask                       = QBrush(Qt::NoBrush);
        kLineBrandNormal                 = QBrush(Qt::NoBrush);
        kBrand5                          = QBrush(Qt::NoBrush);
        kGray10                          = QBrush(Qt::NoBrush);
        kWarningNormal                   = QBrush(Qt::NoBrush);
        kGray9                           = QBrush(Qt::NoBrush);
        kGray1                           = QBrush(Qt::NoBrush);
        kGray14                          = QBrush(Qt::NoBrush);
        kLineComponentClick              = QBrush(Qt::NoBrush);
        kWhite                           = QBrush(Qt::NoBrush);
        kGray7                           = QBrush(Qt::NoBrush);
        kBrandFocus                      = QBrush(Qt::NoBrush);
        kGrayAlpha9                      = QBrush(Qt::NoBrush);
        kGrayAlpha10                     = QBrush(Qt::NoBrush);
        kGrayAlpha6                      = QBrush(Qt::NoBrush);
        kContainHover                    = QBrush(Qt::NoBrush);
        kLineComponentDisable            = QBrush(Qt::NoBrush);
        kFontWhite                       = QBrush(Qt::NoBrush);
        kGrayAlpha11                     = QBrush(Qt::NoBrush);
        kGray6                           = QBrush(Qt::NoBrush);
        kFontWhiteDisable                = QBrush(Qt::NoBrush);
        kComponentDisable                = QBrush(Qt::NoBrush);
        kBlack                           = QBrush(Qt::NoBrush);
        kComponentAlphaDisable           = QBrush(Qt::NoBrush);
        kFontSecondaryDisable            = QBrush(Qt::NoBrush);
        kGrayAlpha8                      = QBrush(Qt::NoBrush);
        kFontPrimaryDisable              = QBrush(Qt::NoBrush);
        kGray5                           = QBrush(Qt::NoBrush);
        kFontSecondary                   = QBrush(Qt::NoBrush);
        kErrorNormal                     = QBrush(Qt::NoBrush);
        kComponentHover                  = QBrush(Qt::NoBrush);
        kComponentAlphaHover             = QBrush(Qt::NoBrush);
        kGrayAlpha3                      = QBrush(Qt::NoBrush);
        kGray13                          = QBrush(Qt::NoBrush);
        kGray11                          = QBrush(Qt::NoBrush);
        kErrorHover                      = QBrush(Qt::NoBrush);
        kContainGeneralNormal            = QBrush(Qt::NoBrush);
        kComponentAlphaNormal            = QBrush(Qt::NoBrush);
        kGray15                          = QBrush(Qt::NoBrush);
        kBrand7                          = QBrush(Qt::NoBrush);
        kGrayAlpha7                      = QBrush(Qt::NoBrush);
        kLineBrandHover                  = QBrush(Qt::NoBrush);
        kGrayAlpha13                     = QBrush(Qt::NoBrush);
        kLineComponentHover              = QBrush(Qt::NoBrush);
        kBrand6                          = QBrush(Qt::NoBrush);
        kGray17                          = QBrush(Qt::NoBrush);
        kComponentClick                  = QBrush(Qt::NoBrush);
        kBrandClick                      = QBrush(Qt::NoBrush);
        kFontStrong                      = QBrush(Qt::NoBrush);
        kLineWindow                      = QBrush(Qt::NoBrush);
        kGray2                           = QBrush(Qt::NoBrush);
        kBrand4                          = QBrush(Qt::NoBrush);
        kContainSecondaryNormal          = QBrush(Qt::NoBrush);
        kBrandHover                      = QBrush(Qt::NoBrush);
        kFontPrimary                     = QBrush(Qt::NoBrush);
        kBrandNormal                     = QBrush(Qt::NoBrush);
    }
    if (QGSettings::isSchemaInstalled("org.ukui.style")) {
        QGSettings *settings = new QGSettings("org.ukui.style");

        QString styleName = settings->get("styleName").toString();
        if (styleName == "ukui-light" || styleName == "ukui-white") {
            m_lightMode = "light";
        } else if (styleName == "ukui-dark" || styleName == "ukui-black") {
            m_lightMode = "dark";
        }

        m_widgetThemeName = settings->get("widgetThemeName").toString();
    }

    QString path = ThemeConfigPath;
    //dt config
    m_ukui_dt_path = (QFile::exists(path + "k" + m_widgetThemeName + "-" + m_lightMode + ".css")) ?
                path + "k" + m_widgetThemeName + "-" + m_lightMode + ".css" :
                path + "k" + m_widgetThemeName + ".css";

    m_ukui_dt_loadConfig = this->load(m_ukui_dt_path);

    initUKUIGlobalThemeParameters();
}

GlobalDTConfigPrivate::~GlobalDTConfigPrivate()
{

}

QColor GlobalDTConfigPrivate::composeColor(QColor foreColor, QColor backColor)
{
    qreal alphaF = foreColor.alphaF() * 1.0 +  1.0 *backColor.alphaF() * (1 - foreColor.alphaF());
    qreal red = (foreColor.red() * foreColor.alphaF() * 1.0+ backColor.red() * backColor.alphaF() *(1 - foreColor.alphaF()))/(alphaF * 1.0);
    qreal green = (foreColor.green() * foreColor.alphaF() * 1.0 + backColor.green() * backColor.alphaF() *(1 - foreColor.alphaF()))/(alphaF * 1.0);
    qreal blue = (foreColor.blue() * foreColor.alphaF() * 1.0 + backColor.blue() * backColor.alphaF() *(1 - foreColor.alphaF()))/(alphaF * 1.0);

    QColor color;
    color.setRed(red);
    color.setGreen(green);
    color.setBlue(blue);
    color.setAlphaF(alphaF);
    return color;
}

QColor GlobalDTConfigPrivate::mixColor(QList<QColor> colorList)
{
    //bottom color is the last one on the list.
    QColor color = colorList.takeLast();

    foreach (QColor c, colorList) {
        color = composeColor(c, color);
    }

    return color;
}

bool GlobalDTConfigPrivate::load(const QString &cfg)
{
    qDebug() << "loadddd...." << cfg;
    if (!QFile::exists(cfg)) {
        qWarning() << "TMPReadConfig load file not exists!" << cfg;
        return false;
    }

    QFile file(cfg);
    if(!file.open(QIODevice::ReadOnly)) {
        qWarning() << "TMPReadConfig load file Error!" << cfg;
        return false;
    }

    QByteArray configData = file.readAll();
    file.close();
    m_cfgPath = cfg;
    m_dt_configData = configData;
    return true;
}

QColor GlobalDTConfigPrivate::stringToColor(QString s) const
{
    QColor c = Qt::NoBrush;

    QStringList list = s.split(",");
    if (list.length() >= 3) {
        c.setRed(list[0].toInt());
        c.setGreen(list[1].toInt());
        c.setBlue(list[2].toInt());
        if (list.length() == 4) {
            QStringList alphaList = QString(list[3]).split("*");
            if (alphaList.length() == 2) {
                if (alphaList[0].toFloat() == 255.0)
                    c.setAlphaF(alphaList[1].toFloat());
                else if (alphaList[1].toFloat() == 255.0)
                    c.setAlphaF(alphaList[0].toFloat());
                else
                    c.setAlphaF(alphaList[0].toFloat() * alphaList[1].toFloat() / 255.0);

            } else if (alphaList.length() == 1) {
                if(alphaList[0].toFloat() <= 1.0)
                    c.setAlphaF(alphaList[0].toFloat());
                else
                    c.setAlphaF(alphaList[0].toFloat()/255.0);
            } else
                c.setAlphaF(1.0);
        }
    } else if (list.length() == 1 && list[0].startsWith("#")) {
        c = list[0];
    }

    return c;
}

inline bool GlobalDTConfigPrivate::getColorValue(QBrush &dtBrush, const QString key)
{
    if (m_dt_configData.isEmpty()) {
        cDebug << "get fills array isempty!";
        return false;
    }

    if (!m_dt_configData.contains("--" + key + ":")) {
        cDebug << "Unvalid key!" << key;
        return false;
    }

    int start_index, end_index;
    QString colorStr;

    start_index = m_dt_configData.indexOf("--" + key + ":");
    if (start_index == -1) {
        cDebug <<"Config file format error! Has no key" << key;
        return false;
    }

    start_index += QString("--" + key).length();
    end_index = m_dt_configData.indexOf(";", start_index);
    colorStr = m_dt_configData.mid(start_index, end_index - start_index + 1);

    if (colorStr.contains(": var(")) {
        //quote key
        start_index = colorStr.indexOf(": var(--");
        if (start_index == -1) {
            qWarning() << "Config file format error! type var" << key;
            return false;
        }
        start_index += QString(": var(--").length();
        end_index = colorStr.indexOf(")", start_index);
        getColorValue(dtBrush, colorStr.mid(start_index, end_index - start_index).toLower());
    } else if (colorStr.contains(": rgba(")) {
        //solidcolor
        start_index = colorStr.indexOf(": rgba(");
        if (start_index == -1) {
            qWarning() << "Config file format error! type rgba" << key;
            return false;
        }
        start_index += QString(": rgba(").length();
        end_index = colorStr.indexOf(")", start_index);

        dtBrush = QBrush(stringToColor(colorStr.mid(start_index, end_index - start_index)));

        if (key == "kfont-primary") {
            qDebug()<<"parse kfont-primary"<<colorStr.mid(start_index, end_index - start_index);
        }

    } else if (colorStr.contains(": linear-gradient(0deg, ")) {
        //mix solidcolor
        start_index = colorStr.indexOf(": linear-gradient(0deg, ");
        if (start_index == -1) {
            qWarning() << "Config file format error! type linear-gradient 0deg" << key;
            return false;
        }

        start_index += QString(": linear-gradient(0deg, ").length();
        end_index = colorStr.indexOf(";", start_index);
        colorStr = colorStr.mid(start_index, end_index - start_index);

        QStringList sList = colorStr.split("rgba");
        QList<QColor> listColor;
        QColor solidColor;
        QStringList colorList;
        for(int i = 0; i < sList.length(); i++) {
            QString s = sList[i];
            if(!s.isEmpty()){
                int sIndex = s.indexOf("(");
                int eIndex = s.indexOf(")");
                s = s.mid(sIndex + 1, eIndex - sIndex - 1);
                if(!colorList.contains(s))
                    colorList.append(s);
            }
        }

        for (int i = 0; i < colorList.length(); i++) {
            QString s = colorList[i];

            QColor color = stringToColor(s);
            if(!listColor.contains(color))
                listColor.append(color);
        }

        solidColor = mixColor(listColor);
        dtBrush = QBrush(solidColor);
    } else if (colorStr.contains(": linear-gradient(180deg, ")) {
        //gradient
        start_index = colorStr.indexOf(": linear-gradient(180deg, ");
        if (start_index == -1) {
            qWarning() << "Config file format error! type linear-gradient 180deg" << key;
            return false;
        }

        start_index += QString(": linear-gradient(180deg, ").length();
        end_index = colorStr.indexOf(";", start_index);
        colorStr = colorStr.mid(start_index, end_index - start_index);

        QStringList sList = colorStr.split("rgba");
        QList<QColor> startListColor;
        QList<QColor> endListColor;

        QColor backColor;
        QColor startColor;
        QColor endColor;
        QLinearGradient gradient;

        QString sbackColor = sList.takeLast();
        sbackColor = sbackColor.mid(sbackColor.indexOf("(") + 1, sbackColor.indexOf(")") - sbackColor.indexOf("(") - 1);
        backColor = stringToColor(sbackColor);
        for(int i = 0; i < sList.length(); i++) {
            QString s = sList[i];
            if (s.isEmpty())
                continue;

            int sIndex = s.indexOf("(");
            int eIndex = s.indexOf(")");
            s = s.mid(sIndex + 1, eIndex - sIndex - 1);
            if (i <= sList.length() / 2)
                startListColor.append(stringToColor(s));
            else
                endListColor.append(stringToColor(s));
        }

        startListColor.append(backColor);
        endListColor.append(backColor);

        startColor = mixColor(startListColor);
        endColor   = mixColor(endListColor);

        gradient.setColorAt(0, startColor);
        gradient.setColorAt(1, endColor);

        dtBrush = QBrush(gradient);
    } else {
        cDebug << "Config file format error! " << key << "colorStr" << colorStr;
        return false;
    }

    return true;
}


inline bool GlobalDTConfigPrivate::getValue(int &value, const QString key) const
{
    if (m_dt_configData.isEmpty()) {
        cDebug << "get fills array isempty!";
        return false;
    }

    if (!m_dt_configData.contains(key)) {
        cDebug << "Unvalid key!";
        return false;
    }

    int start_index = m_dt_configData.indexOf("--" + key + ": ");
    if (start_index == -1) {
        cDebug << "Config file format error!";
        return false;
    }
    start_index += QString("--" + key + ": ").length();
    int end_index = m_dt_configData.indexOf("px", start_index);

    value = m_dt_configData.mid(start_index, end_index - start_index).toInt();

    return true;
}

void GlobalDTConfigPrivate::initUKUIGlobalThemeParameters()
{
    qDebug() << "initUKUIGlobalThemeParameters......" << m_ukui_dt_loadConfig;
    if (m_ukui_dt_loadConfig) {

        //default palette
        getColorValue(windowTextActive          , "windowtext-active");
        getColorValue(windowTextInactive        , "windowtext-inactive");
        getColorValue(windowTextDisable         , "windowtext-disable");
        getColorValue(buttonActive              , "button-active");
        getColorValue(buttonInactive            , "button-inactive");
        getColorValue(buttonDisable             , "button-disable");
        getColorValue(lightActive               , "light-active");
        getColorValue(lightInactive             , "light-inactive");
        getColorValue(lightDisable              , "light-disable");
        getColorValue(midlightActive            , "midlight-active");
        getColorValue(midlightInactive          , "midlight-inactive");
        getColorValue(midlightDisable           , "midlight-disable");
        getColorValue(darkActive                , "dark-active");
        getColorValue(darkInactive              , "dark-inactive");
        getColorValue(darkDisable               , "dark-disable");
        getColorValue(midActive                 , "mid-active");
        getColorValue(midInactive               , "mid-inactive");
        getColorValue(midDisable                , "mid-disable");
        getColorValue(textActive                , "text-active");
        getColorValue(textInactive              , "text-inactive");
        getColorValue(textDisable               , "text-disable");
        getColorValue(brightTextActive          , "brighttext-active");
        getColorValue(brightTextInactive        , "brighttext-inactive");
        getColorValue(brightTextDisable         , "brighttext-disable");
        getColorValue(buttonTextActive          , "buttontext-active");
        getColorValue(buttonTextInactive        , "buttontext-inactive");
        getColorValue(buttonTextDisable         , "buttontext-disable");
        getColorValue(baseActive                , "base-active");
        getColorValue(baseInactive              , "base-inactive");
        getColorValue(baseDisable               , "base-disable");
        getColorValue(windowActive              , "window-active");
        getColorValue(windowInactive            , "window-inactive");
        getColorValue(windowDisable             , "window-disable");
        getColorValue(shadowActive              , "shadow-active");
        getColorValue(shadowInactive            , "shadow-inactive");
        getColorValue(shadowDisable             , "shadow-disable");
        getColorValue(highLightActive           , "highlight-active");
        getColorValue(highLightInactive         , "highlight-inactive");
        getColorValue(highLightDisable          , "highlight-disable");
        getColorValue(highLightedTextActive     , "highlightedtext-active");
        getColorValue(highLightedTextInactive   , "highlightedtext-inactive");
        getColorValue(highLightedTextDisable    , "highlightedtext-disable");
        getColorValue(linkActive                , "link-active");
        getColorValue(linkInactive              , "link-inactive");
        getColorValue(linkDisable               , "link-disable");
        getColorValue(linkVisitedActive         , "linkvisited-active");
        getColorValue(linkVisitedInactive       , "linkvisited-inactive");
        getColorValue(linkVisitedDisable        , "linkvisited-disable");
        getColorValue(alternateBaseActive       , "alternatebase-active");
        getColorValue(alternateBaseInactive     , "alternatebase-inactive");
        getColorValue(alternateBaseDisable      , "alternatebase-disable");
        getColorValue(noRoleActive              , "norole-active");
        getColorValue(noRoleInactive            , "norole-inactive");
        getColorValue(noRoleDisable             , "norole-disable");
        getColorValue(toolTipBaseActive         , "tooltipbase-active");
        getColorValue(toolTipBaseInactive       , "tooltipbase-inactive");
        getColorValue(toolTipBaseDisable        , "tooltipbase-disable");
        getColorValue(toolTipTextActive         , "tooltiptext-active");
        getColorValue(toolTipTextInactive       , "tooltiptext-inactive");
        getColorValue(toolTipTextDisable        , "tooltiptext-disable");
        getColorValue(placeholderTextActive     , "placeholdertext-active");
        getColorValue(placeholderTextInactive   , "placeholdertext-inactive");
        getColorValue(placeholderTextDisable    , "placeholdertext-disable");

        //custom palette
        getColorValue(kBlack                        , "kblack");
        getColorValue(kBrand1                       , "kbrand1");
        getColorValue(kBrand2                       , "kbrand2");
        getColorValue(kBrand3                       , "kbrand3");
        getColorValue(kBrand4                       , "kbrand4");
        getColorValue(kBrand5                       , "kbrand5");
        getColorValue(kBrand6                       , "kbrand6");
        getColorValue(kBrand7                       , "kbrand7");
        getColorValue(kBrandClick                   , "kbrand-click");
        getColorValue(kBrandFocus                   , "kbrand-focus");
        getColorValue(kBrandHover                   , "kbrand-hover");
        getColorValue(kBrandNormal                  , "kbrand-normal");
        getColorValue(kComponentAlphaClick          , "kcomponent-alpha-click");
        getColorValue(kComponentAlphaDisable        , "kcomponent-alpha-disable");
        getColorValue(kComponentAlphaHover          , "kcomponent-alpha-hover");
        getColorValue(kComponentAlphaNormal         , "kcomponent-alpha-normal");
        getColorValue(kComponentClick               , "kcomponent-click");
        getColorValue(kComponentDisable             , "kcomponent-disable");
        getColorValue(kComponentHover               , "kcomponent-hover");
        getColorValue(kComponentNormal              , "kcomponent-normal");
        getColorValue(kContainClick                 , "kcontain-click");
        getColorValue(kContainHover                 , "kcontain-hover");
        getColorValue(kContainGeneralNormal         , "kcontain-general-normal");
        getColorValue(kContainSecondaryAlpphaNormal , "kcontain-secondary-alpha-normal");
        getColorValue(kContainSecondaryNormal       , "kcontain-secondary-normal");
        getColorValue(kErrorClick                   , "kerror-click");
        getColorValue(kErrorHover                   , "kerror-hover");
        getColorValue(kErrorNormal                  , "kerror-normal");
        getColorValue(kFontPrimary                  , "kfont-primary");
        getColorValue(kFontPrimaryDisable           , "kfont-primary-disable");
        getColorValue(kFontSecondary                , "kfont-secondary");
        getColorValue(kFontSecondaryDisable         , "kfont-secondary-disable");
        getColorValue(kFontStrong                   , "kfont-strong");
        getColorValue(kFontWhite                    , "kfont-white");
        getColorValue(kFontWhiteDisable             , "kfont-white-disable");
        getColorValue(kFontWhiteSecondary           , "kfont-white-secondary");
        getColorValue(kFontWhiteSecondaryDisable    , "kfont-white-secondary-disable");
        getColorValue(kGray0                        , "kgray-0");
        getColorValue(kGray1                        , "kgray-1");
        getColorValue(kGray2                        , "kgray-2");
        getColorValue(kGray3                        , "kgray-3");
        getColorValue(kGray4                        , "kgray-4");
        getColorValue(kGray5                        , "kgray-5");
        getColorValue(kGray6                        , "kgray-6");
        getColorValue(kGray7                        , "kgray-7");
        getColorValue(kGray8                        , "kgray-8");
        getColorValue(kGray9                        , "kgray-9");
        getColorValue(kGray10                       , "kgray-10");
        getColorValue(kGray11                       , "kgray-11");
        getColorValue(kGray12                       , "kgray-12");
        getColorValue(kGray13                       , "kgray-13");
        getColorValue(kGray14                       , "kgray-14");
        getColorValue(kGray15                       , "kgray-15");
        getColorValue(kGray16                       , "kgray-16");
        getColorValue(kGray17                       , "kgray-17");
        getColorValue(kGrayAlpha0                   , "kgray-alpha0");
        getColorValue(kGrayAlpha1                   , "kgray-alpha1");
        getColorValue(kGrayAlpha2                   , "kgray-alpha2");
        getColorValue(kGrayAlpha3                   , "kgray-alpha3");
        getColorValue(kGrayAlpha4                   , "kgray-alpha4");
        getColorValue(kGrayAlpha5                   , "kgray-alpha5");
        getColorValue(kGrayAlpha6                   , "kgray-alpha6");
        getColorValue(kGrayAlpha7                   , "kgray-alpha7");
        getColorValue(kGrayAlpha8                   , "kgray-alpha8");
        getColorValue(kGrayAlpha9                   , "kgray-alpha9");
        getColorValue(kGrayAlpha10                  , "kgray-alpha10");
        getColorValue(kGrayAlpha11                  , "kgray-alpha11");
        getColorValue(kGrayAlpha12                  , "kgray-alpha12");
        getColorValue(kGrayAlpha13                  , "kgray-alpha13");
        getColorValue(kLineBrandClick               , "kline-brand-click");
        getColorValue(kLineBrandDisable             , "kline-brand-disable");
        getColorValue(kLineBrandHover               , "kline-brand-hover");
        getColorValue(kLineBrandNormal              , "kline-brand-normal");
        getColorValue(kLineComponentClick           , "kline-component-click");
        getColorValue(kLineComponentDisable         , "kline-component-disable");
        getColorValue(kLineComponentHover           , "kline-component-hover");
        getColorValue(kLineComponentNormal          , "kline-component-normal");
        getColorValue(kLineDisable                  , "kline-disable");
        getColorValue(kLineNormal                   , "kline-normal");
        getColorValue(kLineWindow                   , "kline-window");
        getColorValue(kLineWindowActive             , "kline-window-active");
        getColorValue(kModalmask                    , "kmodalmask");
        getColorValue(kSuccessNormal                , "ksuccess-normal");
        getColorValue(kWarningNormal                , "kwarning-normal");
        getColorValue(kWhite                        , "kwhite");

        //line and margin
        getValue(normalline     , "normalline");
        getValue(focusline      , "focusline");
        getValue(tokenGap4      , "token-gap-4");
        getValue(tokenGap8      , "token-gap-8");
        getValue(tokenGap16     , "token-gap-16");
        getValue(tokenGap24     , "token-gap-24");
        getValue(tokenGap40     , "token-gap-40");

        //radius
        getValue(kradiusMin     , "kradius-min");
        getValue(kradiusMenu    , "kradius-menu");
        getValue(kradiusNormal  , "kradius-normal");
        getValue(kradiusWindow  , "kradius-window");
    }


    //default palette
    qApp->setProperty("windowtext-active",          windowTextActive);
    qApp->setProperty("windowtext-inactive",        windowTextInactive);
    qApp->setProperty("windowtext-disable",         windowTextDisable);
    qApp->setProperty("button-active",              buttonActive);
    qApp->setProperty("button-inactive",            buttonInactive);
    qApp->setProperty("button-disable",             buttonDisable);
    qApp->setProperty("light-active",               lightActive);
    qApp->setProperty("light-inactive",             lightInactive);
    qApp->setProperty("light-disable",              lightDisable);
    qApp->setProperty("midlight-active",            midlightActive);
    qApp->setProperty("midlight-inactive",          midlightInactive);
    qApp->setProperty("midlight-disable",           midlightDisable);
    qApp->setProperty("dark-active",                darkActive);
    qApp->setProperty("dark-inactive",              darkInactive);
    qApp->setProperty("dark-disable",               darkDisable);
    qApp->setProperty("mid-active",                 midActive);
    qApp->setProperty("mid-inactive",               midInactive);
    qApp->setProperty("mid-disable",                midDisable);
    qApp->setProperty("text-active",                textActive);
    qApp->setProperty("text-inactive",              textInactive);
    qApp->setProperty("text-disable",               textDisable);
    qApp->setProperty("brighttext-active",          brightTextActive);
    qApp->setProperty("brighttext-inactive",        brightTextInactive);
    qApp->setProperty("brighttext-disable",         brightTextDisable);
    qApp->setProperty("buttontext-active",          buttonTextActive);
    qApp->setProperty("buttontext-inactive",        buttonTextInactive);
    qApp->setProperty("buttontext-disable",         buttonTextDisable);
    qApp->setProperty("base-active",                baseActive);
    qApp->setProperty("base-inactive",              baseInactive);
    qApp->setProperty("base-disable",               baseDisable);
    qApp->setProperty("window-active",              windowActive);
    qApp->setProperty("window-inactive",            windowInactive);
    qApp->setProperty("window-disable",             windowDisable);
    qApp->setProperty("shadow-active",              shadowActive);
    qApp->setProperty("shadow-inactive",            shadowInactive);
    qApp->setProperty("shadow-disable",             shadowDisable);
    qApp->setProperty("highlight-active",           highLightActive);
    qApp->setProperty("highlight-inactive",         highLightInactive);
    qApp->setProperty("highlight-disable",          highLightDisable);
    qApp->setProperty("highlightedtext-active",     highLightedTextActive);
    qApp->setProperty("highlightedtext-inactive",   highLightedTextInactive);
    qApp->setProperty("highlightedtext-disable",    highLightedTextDisable);
    qApp->setProperty("link-active",                linkActive);
    qApp->setProperty("link-inactive",              linkInactive);
    qApp->setProperty("link-disable",               linkDisable);
    qApp->setProperty("linkvisited-active",         linkVisitedActive);
    qApp->setProperty("linkvisited-inactive",       linkVisitedInactive);
    qApp->setProperty("linkvisited-disable",        linkVisitedDisable);
    qApp->setProperty("alternatebase-active",       alternateBaseActive);
    qApp->setProperty("alternatebase-inactive",     alternateBaseInactive);
    qApp->setProperty("alternatebase-disable",      alternateBaseDisable);
    qApp->setProperty("norole-active",              noRoleActive);
    qApp->setProperty("norole-inactive",            noRoleInactive);
    qApp->setProperty("norole-disable",             noRoleDisable);
    qApp->setProperty("tooltipbase-active",         toolTipBaseActive);
    qApp->setProperty("tooltipbase-inactive",       toolTipBaseInactive);
    qApp->setProperty("tooltipbase-disable",        toolTipBaseDisable);
    qApp->setProperty("tooltiptext-active",         toolTipTextActive);
    qApp->setProperty("tooltiptext-inactive",       toolTipTextInactive);
    qApp->setProperty("tooltiptext-disable",        toolTipTextDisable);
    qApp->setProperty("placeholdertext-active",     placeholderTextActive);
    qApp->setProperty("placeholdertext-inactive",   placeholderTextInactive);
    qApp->setProperty("placeholdertext-disable",    placeholderTextDisable);

    //custom palette
    qApp->setProperty("kblack",                           kBlack);
    qApp->setProperty("kbrand1",                          kBrand1);
    qApp->setProperty("kbrand2",                          kBrand2);
    qApp->setProperty("kbrand3",                          kBrand3);
    qApp->setProperty("kbrand4",                          kBrand4);
    qApp->setProperty("kbrand5",                          kBrand5);
    qApp->setProperty("kbrand6",                          kBrand6);
    qApp->setProperty("kbrand7",                          kBrand7);
    qApp->setProperty("kbrand-click",                     kBrandClick);
    qApp->setProperty("kbrand-focus",                     kBrandFocus);
    qApp->setProperty("kbrand-hover",                     kBrandHover);
    qApp->setProperty("kbrand-normal",                    kBrandNormal);
    qApp->setProperty("kcomponent-alpha-click",           kComponentAlphaClick);
    qApp->setProperty("kcomponent-alpha-disable",         kComponentAlphaDisable);
    qApp->setProperty("kcomponent-alpha-hover",           kComponentAlphaHover);
    qApp->setProperty("kcomponent-alpha-normal",          kComponentAlphaNormal);
    qApp->setProperty("kcomponent-click",                 kComponentClick);
    qApp->setProperty("kcomponent-disable",               kComponentDisable);
    qApp->setProperty("kcomponent-hover",                 kComponentHover);
    qApp->setProperty("kcomponent-normal",                kComponentNormal);
    qApp->setProperty("kcontain-click",                   kContainClick);
    qApp->setProperty("kcontain-hover",                   kContainHover);
    qApp->setProperty("kcontain-general-normal",          kContainGeneralNormal);
    qApp->setProperty("kcontain-secondary-alpha-normal",  kContainSecondaryAlpphaNormal);
    qApp->setProperty("kcontain-secondary-normal",        kContainSecondaryNormal);
    qApp->setProperty("kerror-click",                     kErrorClick);
    qApp->setProperty("kerror-hover",                     kErrorHover);
    qApp->setProperty("kerror-normal",                    kErrorNormal);
    qApp->setProperty("kfont-primary",                    kFontPrimary);
    qApp->setProperty("kfont-primary-disable",            kFontPrimaryDisable);
    qApp->setProperty("kfont-secondary",                  kFontSecondary);
    qApp->setProperty("kfont-secondary-disable",          kFontSecondaryDisable);
    qApp->setProperty("kfont-strong",                     kFontStrong);
    qApp->setProperty("kfont-white",                      kFontWhite);
    qApp->setProperty("kfont-white-disable",              kFontWhiteDisable);
    qApp->setProperty("kfont-white-secondary",            kFontWhiteSecondary);
    qApp->setProperty("kfont-white-secondary-disable",    kFontWhiteSecondaryDisable);
    qApp->setProperty("kgray-0",                          kGray0);
    qApp->setProperty("kgray-1",                          kGray1);
    qApp->setProperty("kgray-2",                          kGray2);
    qApp->setProperty("kgray-3",                          kGray3);
    qApp->setProperty("kgray-4",                          kGray4);
    qApp->setProperty("kgray-5",                          kGray5);
    qApp->setProperty("kgray-6",                          kGray6);
    qApp->setProperty("kgray-7",                          kGray7);
    qApp->setProperty("kgray-8",                          kGray8);
    qApp->setProperty("kgray-9",                          kGray9);
    qApp->setProperty("kgray-10",                         kGray10);
    qApp->setProperty("kgray-11",                         kGray11);
    qApp->setProperty("kgray-12",                         kGray12);
    qApp->setProperty("kgray-13",                         kGray13);
    qApp->setProperty("kgray-14",                         kGray14);
    qApp->setProperty("kgray-15",                         kGray15);
    qApp->setProperty("kgray-16",                         kGray16);
    qApp->setProperty("kgray-17",                         kGray17);
    qApp->setProperty("kgray-alpha0",                     kGrayAlpha0);
    qApp->setProperty("kgray-alpha1",                     kGrayAlpha1);
    qApp->setProperty("kgray-alpha2",                     kGrayAlpha2);
    qApp->setProperty("kgray-alpha3",                     kGrayAlpha3);
    qApp->setProperty("kgray-alpha4",                     kGrayAlpha4);
    qApp->setProperty("kgray-alpha5",                     kGrayAlpha5);
    qApp->setProperty("kgray-alpha6",                     kGrayAlpha6);
    qApp->setProperty("kgray-alpha7",                     kGrayAlpha7);
    qApp->setProperty("kgray-alpha8",                     kGrayAlpha8);
    qApp->setProperty("kgray-alpha9",                     kGrayAlpha9);
    qApp->setProperty("kgray-alpha10",                    kGrayAlpha10);
    qApp->setProperty("kgray-alpha11",                    kGrayAlpha11);
    qApp->setProperty("kgray-alpha12",                    kGrayAlpha12);
    qApp->setProperty("kgray-alpha13",                    kGrayAlpha13);
    qApp->setProperty("kline-brand-click",                kLineBrandClick);
    qApp->setProperty("kline-brand-disable",              kLineBrandDisable);
    qApp->setProperty("kline-brand-hover",                kLineBrandHover);
    qApp->setProperty("kline-brand-normal",               kLineBrandNormal);
    qApp->setProperty("kline-component-click",            kLineComponentClick);
    qApp->setProperty("kline-component-disable",          kLineComponentDisable);
    qApp->setProperty("kline-component-hover",            kLineComponentHover);
    qApp->setProperty("kline-component-normal",           kLineComponentNormal);
    qApp->setProperty("kline-disable",                    kLineDisable);
    qApp->setProperty("kline-normal",                     kLineNormal);
    qApp->setProperty("kline-window",                     kLineWindow);
    qApp->setProperty("kline-window-active",              kLineWindowActive);
    qApp->setProperty("kmodalmask",                       kModalmask);
    qApp->setProperty("ksuccess-normal",                  kSuccessNormal);
    qApp->setProperty("kwarning-normal",                  kWarningNormal);
    qApp->setProperty("kwhite",                           kWhite);


    //line and margin
    qApp->setProperty("normalline",      normalline);
    qApp->setProperty("focusline",       focusline);
    qApp->setProperty("token-gap-4",     tokenGap4);
    qApp->setProperty("token-gap-8",     tokenGap8);
    qApp->setProperty("token-gap-16",    tokenGap16);
    qApp->setProperty("token-gap-24",    tokenGap24);
    qApp->setProperty("token-gap-40",    tokenGap40);

    //radius
    qApp->setProperty("kradius-min",     kradiusMin);
    qApp->setProperty("kradius-menu",    kradiusMenu);
    qApp->setProperty("kradius-normal",  kradiusNormal);
    qApp->setProperty("kradius-window",  kradiusWindow);
}

GlobalDTConfig::GlobalDTConfig() : d(new GlobalDTConfigPrivate())
{
    if (QGSettings::isSchemaInstalled("org.ukui.style")) {
        auto *settings = new QGSettings("org.ukui.style");
        connect(settings, &QGSettings::changed, this, [=](const QString &key) {
            if (key == "styleName" || key == "widgetThemeName" || key == "themeColor" ||
                    key == "style-name" || key == "widget-theme-name" || key == "theme-color") {
                emit tokenChanged();
            }
        });
    }
}

GlobalDTConfig::~GlobalDTConfig()
{
    if (d) {
        delete d;
        d = nullptr;
    }
}

QBrush GlobalDTConfig::windowTextActive() const
{
    return d->windowTextActive;
}

QBrush GlobalDTConfig::windowTextInactive() const
{
    return d->windowTextInactive;
}

QBrush GlobalDTConfig::windowTextDisable() const
{
    return d->windowTextDisable;
}

QBrush GlobalDTConfig::buttonActive() const
{
    return d->buttonActive;
}

QBrush GlobalDTConfig::buttonInactive() const
{
    return d->buttonInactive;
}

QBrush GlobalDTConfig::buttonDisable() const
{
    return d->buttonDisable;
}

QBrush GlobalDTConfig::lightActive() const
{
    return d->lightActive;
}

QBrush GlobalDTConfig::lightInactive() const
{
    return d->lightInactive;
}

QBrush GlobalDTConfig::lightDisable() const
{
    return d->lightDisable;
}

QBrush GlobalDTConfig::midlightActive() const
{
    return d->midlightActive;
}

QBrush GlobalDTConfig::midlightInactive() const
{
    return d->midlightInactive;
}

QBrush GlobalDTConfig::midlightDisable() const
{
    return d->midlightDisable;
}

QBrush GlobalDTConfig::darkActive() const
{
    return d->darkActive;
}

QBrush GlobalDTConfig::darkInactive() const
{
    return d->darkInactive;
}

QBrush GlobalDTConfig::darkDisable() const
{
    return d->darkDisable;
}

QBrush GlobalDTConfig::midActive() const
{
    return d->midActive;
}

QBrush GlobalDTConfig::midInactive() const
{
    return d->midInactive;
}

QBrush GlobalDTConfig::midDisable() const
{
    return d->midDisable;
}

QBrush GlobalDTConfig::textActive() const
{
    return d->textActive;
}

QBrush GlobalDTConfig::textInactive() const
{
    return d->textInactive;
}

QBrush GlobalDTConfig::textDisable() const
{
    return d->textDisable;
}

QBrush GlobalDTConfig::brightTextActive() const
{
    return d->brightTextActive;
}

QBrush GlobalDTConfig::brightTextInactive() const
{
    return d->brightTextInactive;
}

QBrush GlobalDTConfig::brightTextDisable() const
{
    return d->brightTextDisable;
}

QBrush GlobalDTConfig::buttonTextActive() const
{
    return d->buttonTextActive;
}

QBrush GlobalDTConfig::buttonTextInactive() const
{
    return d->buttonTextInactive;
}

QBrush GlobalDTConfig::buttonTextDisable() const
{
    return d->buttonTextDisable;
}

QBrush GlobalDTConfig::baseActive() const
{
    return d->baseActive;
}

QBrush GlobalDTConfig::baseInactive() const
{
    return d->baseInactive;
}

QBrush GlobalDTConfig::baseDisable() const
{
    return d->baseDisable;
}

QBrush GlobalDTConfig::windowActive() const
{
    return d->windowActive;
}

QBrush GlobalDTConfig::windowInactive() const
{
    return d->windowInactive;
}

QBrush GlobalDTConfig::windowDisable() const
{
    return d->windowDisable;
}

QBrush GlobalDTConfig::shadowActive() const
{
    return d->shadowActive;
}

QBrush GlobalDTConfig::shadowInactive() const
{
    return d->shadowInactive;
}

QBrush GlobalDTConfig::shadowDisable() const
{
    return d->shadowDisable;
}

QBrush GlobalDTConfig::highLightActive() const
{
    return d->highLightActive;
}

QBrush GlobalDTConfig::highLightInactive() const
{
    return d->highLightInactive;
}

QBrush GlobalDTConfig::highLightDisable() const
{
    return d->highLightDisable;
}

QBrush GlobalDTConfig::highLightedTextActive() const
{
    return d->highLightedTextActive;
}

QBrush GlobalDTConfig::highLightedTextInactive() const
{
    return d->highLightedTextInactive;
}

QBrush GlobalDTConfig::highLightedTextDisable() const
{
    return d->highLightedTextDisable;
}

QBrush GlobalDTConfig::linkActive() const
{
    return d->linkActive;
}

QBrush GlobalDTConfig::linkInactive() const
{
    return d->linkInactive;
}

QBrush GlobalDTConfig::linkDisable() const
{
    return d->linkDisable;
}

QBrush GlobalDTConfig::linkVisitedActive() const
{
    return d->linkVisitedActive;
}

QBrush GlobalDTConfig::linkVisitedInactive() const
{
    return d->linkVisitedInactive;
}

QBrush GlobalDTConfig::linkVisitedDisable() const
{
    return d->linkVisitedDisable;
}

QBrush GlobalDTConfig::alternateBaseActive() const
{
    return d->alternateBaseActive;
}

QBrush GlobalDTConfig::alternateBaseInactive() const
{
    return d->alternateBaseInactive;
}

QBrush GlobalDTConfig::alternateBaseDisable() const
{
    return d->alternateBaseDisable;
}

QBrush GlobalDTConfig::noRoleActive() const
{
    return d->noRoleActive;
}

QBrush GlobalDTConfig::noRoleInactive() const
{
    return d->noRoleInactive;
}

QBrush GlobalDTConfig::noRoleDisable() const
{
    return d->noRoleDisable;
}

QBrush GlobalDTConfig::toolTipBaseActive() const
{
    return d->toolTipBaseActive;
}

QBrush GlobalDTConfig::toolTipBaseInactive() const
{
    return d->toolTipBaseInactive;
}

QBrush GlobalDTConfig::toolTipBaseDisable() const
{
    return d->toolTipBaseDisable;
}

QBrush GlobalDTConfig::toolTipTextActive() const
{
    return d->toolTipTextActive;
}

QBrush GlobalDTConfig::toolTipTextInactive() const
{
    return d->toolTipTextInactive;
}

QBrush GlobalDTConfig::toolTipTextDisable() const
{
    return d->toolTipTextDisable;
}

QBrush GlobalDTConfig::placeholderTextActive() const
{
    return d->placeholderTextActive;
}

QBrush GlobalDTConfig::placeholderTextInactive() const
{
    return d->placeholderTextInactive;
}

QBrush GlobalDTConfig::placeholderTextDisable() const
{
    return d->placeholderTextDisable;
}

QBrush GlobalDTConfig::kComponentNormal() const
{
    return d->kComponentNormal;
}

QBrush GlobalDTConfig::kLineBrandDisable() const
{
    return d->kLineBrandDisable;
}

QBrush GlobalDTConfig::kFontWhiteSecondary() const
{
    return d->kFontWhiteSecondary;
}

QBrush GlobalDTConfig::kGray12() const
{
    return d->kGray12;
}

QBrush GlobalDTConfig::kContainSecondaryAlpphaNormal() const
{
    return d->kContainSecondaryAlpphaNormal;
}

QBrush GlobalDTConfig::kGray16() const
{
    return d->kGray16;
}

QBrush GlobalDTConfig::kBrand1() const
{
    return d->kBrand1;
}

QBrush GlobalDTConfig::kLineComponentNormal() const
{
    return d->kLineComponentNormal;
}

QBrush GlobalDTConfig::kLineBrandClick() const
{
    return d->kLineBrandClick;
}

QBrush GlobalDTConfig::kGray3() const
{
    return d->kGray3;
}

QBrush GlobalDTConfig::kGray0() const
{
    return d->kGray0;
}

QBrush GlobalDTConfig::kLineDisable() const
{
    return d->kLineDisable;
}

QBrush GlobalDTConfig::kGrayAlpha2() const
{
    return d->kGrayAlpha2;
}

QBrush GlobalDTConfig::kGrayAlpha0() const
{
    return d->kGrayAlpha0;
}

QBrush GlobalDTConfig::kBrand2() const
{
    return d->kBrand2;
}

QBrush GlobalDTConfig::kLineNormal() const
{
    return d->kLineNormal;
}

QBrush GlobalDTConfig::kGrayAlpha5() const
{
    return d->kGrayAlpha5;
}

QBrush GlobalDTConfig::kGrayAlpha12() const
{
    return d->kGrayAlpha12;
}

QBrush GlobalDTConfig::kErrorClick() const
{
    return d->kErrorClick;
}

QBrush GlobalDTConfig::kLineWindowActive() const
{
    return d->kLineWindowActive;
}

QBrush GlobalDTConfig::kComponentAlphaClick() const
{
    return d->kComponentAlphaClick;
}

QBrush GlobalDTConfig::kBrand3() const
{
    return d->kBrand3;
}

QBrush GlobalDTConfig::kSuccessNormal() const
{
    return d->kSuccessNormal;
}

QBrush GlobalDTConfig::kGrayAlpha1() const
{
    return d->kGrayAlpha1;
}

QBrush GlobalDTConfig::kFontWhiteSecondaryDisable() const
{
    return d->kFontWhiteSecondaryDisable;
}

QBrush GlobalDTConfig::kGray4() const
{
    return d->kGray4;
}

QBrush GlobalDTConfig::kContainClick() const
{
    return d->kContainClick;
}

QBrush GlobalDTConfig::kGray8() const
{
    return d->kGray8;
}

QBrush GlobalDTConfig::kGrayAlpha4() const
{
    return d->kGrayAlpha4;
}

QBrush GlobalDTConfig::kModalmask() const
{
    return d->kModalmask;
}

QBrush GlobalDTConfig::kLineBrandNormal() const
{
    return d->kLineBrandNormal;
}

QBrush GlobalDTConfig::kBrand5() const
{
    return d->kBrand5;
}

QBrush GlobalDTConfig::kGray10() const
{
    return d->kGray10;
}

QBrush GlobalDTConfig::kWarningNormal() const
{
    return d->kWarningNormal;
}

QBrush GlobalDTConfig::kGray9() const
{
    return d->kGray9;
}

QBrush GlobalDTConfig::kGray1() const
{
    return d->kGray1;
}

QBrush GlobalDTConfig::kGray14() const
{
    return d->kGray14;
}

QBrush GlobalDTConfig::kLineComponentClick() const
{
    return d->kLineComponentClick;
}

QBrush GlobalDTConfig::kWhite() const
{
    return d->kWhite;
}

QBrush GlobalDTConfig::kGray7() const
{
    return d->kGray7;
}

QBrush GlobalDTConfig::kBrandFocus() const
{
    return d->kBrandFocus;
}

QBrush GlobalDTConfig::kGrayAlpha9() const
{
    return d->kGrayAlpha9;
}

QBrush GlobalDTConfig::kGrayAlpha10() const
{
    return d->kGrayAlpha10;
}

QBrush GlobalDTConfig::kGrayAlpha6() const
{
    return d->kGrayAlpha6;
}

QBrush GlobalDTConfig::kContainHover() const
{
    return d->kContainHover;
}

QBrush GlobalDTConfig::kLineComponentDisable() const
{
    return d->kLineComponentDisable;
}

QBrush GlobalDTConfig::kFontWhite() const
{
    return d->kFontWhite;
}

QBrush GlobalDTConfig::kGrayAlpha11() const
{
    return d->kGrayAlpha11;
}

QBrush GlobalDTConfig::kGray6() const
{
    return d->kGray6;
}

QBrush GlobalDTConfig::kFontWhiteDisable() const
{
    return d->kFontWhiteDisable;
}

QBrush GlobalDTConfig::kComponentDisable() const
{
    return d->kComponentDisable;
}

QBrush GlobalDTConfig::kBlack() const
{
    return d->kBlack;
}

QBrush GlobalDTConfig::kComponentAlphaDisable() const
{
    return d->kComponentAlphaDisable;
}

QBrush GlobalDTConfig::kFontSecondaryDisable() const
{
    return d->kFontSecondaryDisable;
}

QBrush GlobalDTConfig::kGrayAlpha8() const
{
    return d->kGrayAlpha8;
}

QBrush GlobalDTConfig::kFontPrimaryDisable() const
{
    return d->kFontPrimaryDisable;
}

QBrush GlobalDTConfig::kGray5() const
{
    return d->kGray5;
}

QBrush GlobalDTConfig::kFontSecondary() const
{
    return d->kFontSecondary;
}

QBrush GlobalDTConfig::kErrorNormal() const
{
    return d->kErrorNormal;
}

QBrush GlobalDTConfig::kComponentHover() const
{
    return d->kComponentHover;
}

QBrush GlobalDTConfig::kComponentAlphaHover() const
{
    return d->kComponentAlphaHover;
}

QBrush GlobalDTConfig::kGrayAlpha3() const
{
    return d->kGrayAlpha3;
}

QBrush GlobalDTConfig::kGray13() const
{
    return d->kGray13;
}

QBrush GlobalDTConfig::kGray11() const
{
    return d->kGray11;
}

QBrush GlobalDTConfig::kErrorHover() const
{
    return d->kErrorHover;
}

QBrush GlobalDTConfig::kContainGeneralNormal() const
{
    return d->kContainGeneralNormal;
}

QBrush GlobalDTConfig::kComponentAlphaNormal() const
{
    return d->kComponentAlphaNormal;
}

QBrush GlobalDTConfig::kGray15() const
{
    return d->kGray15;
}

QBrush GlobalDTConfig::kBrand7() const
{
    return d->kBrand7;
}

QBrush GlobalDTConfig::kGrayAlpha7() const
{
    return d->kGrayAlpha7;
}

QBrush GlobalDTConfig::kLineBrandHover() const
{
    return d->kLineBrandHover;
}

QBrush GlobalDTConfig::kGrayAlpha13() const
{
    return d->kGrayAlpha13;
}

QBrush GlobalDTConfig::kLineComponentHover() const
{
    return d->kLineComponentHover;
}

QBrush GlobalDTConfig::kBrand6() const
{
    return d->kBrand6;
}

QBrush GlobalDTConfig::kGray17() const
{
    return d->kGray17;
}

QBrush GlobalDTConfig::kComponentClick() const
{
    return d->kComponentClick;
}

QBrush GlobalDTConfig::kBrandClick() const
{
    return d->kBrandClick;
}

QBrush GlobalDTConfig::kFontStrong() const
{
    return d->kFontStrong;
}

QBrush GlobalDTConfig::kLineWindow() const
{
    return d->kLineWindow;
}

QBrush GlobalDTConfig::kGray2() const
{
    return d->kGray2;
}

QBrush GlobalDTConfig::kBrand4() const
{
    return d->kBrand4;
}

QBrush GlobalDTConfig::kContainSecondaryNormal() const
{
    return d->kContainSecondaryNormal;
}

QBrush GlobalDTConfig::kBrandHover() const
{
    return d->kBrandHover;
}

QBrush GlobalDTConfig::kFontPrimary() const
{
    return d->kFontPrimary;
}

QBrush GlobalDTConfig::kBrandNormal() const
{
    return d->kBrandNormal;
}

int GlobalDTConfig::normalline() const
{
    return d->normalline;
}

int GlobalDTConfig::focusline() const
{
    return d->focusline;
}

int GlobalDTConfig::tokenGap4() const
{
    return d->tokenGap4;
}

int GlobalDTConfig::tokenGap8() const
{
    return d->tokenGap8;
}

int GlobalDTConfig::tokenGap16() const
{
    return d->tokenGap16;
}

int GlobalDTConfig::tokenGap24() const
{
    return d->tokenGap24;
}

int GlobalDTConfig::tokenGap40() const
{
    return d->tokenGap40;
}

int GlobalDTConfig::kradiusMin() const
{
    return d->kradiusMin;
}

int GlobalDTConfig::kradiusMenu() const
{
    return d->kradiusMenu;
}

int GlobalDTConfig::kradiusNormal() const
{
    return d->kradiusNormal;
}

int GlobalDTConfig::kradiusWindow() const
{
    return d->kradiusWindow;
}


