/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Jing Tan <tanjing@kylinos.cn>
 *
 */

#ifndef READCONFIG_H
#define READCONFIG_H

#include <QObject>
#include <QColor>
#include <QPalette>
#include <QtQuick/QQuickItem>
#include <QMetaType>

namespace UKUIGlobalDTConfig {


class GlobalDTConfigPrivate
{
public:
    explicit GlobalDTConfigPrivate();
    ~GlobalDTConfigPrivate();

    inline bool getColorValue(QBrush &dtBrush, const QString key);
    inline bool getValue(int &value, const QString key) const;
    inline QColor stringToColor(QString s) const;
    inline QColor mixColor(QList<QColor> colorList);
    inline QColor composeColor(QColor foreColor, QColor backColor);

    bool load(const QString &cfg);
    void initUKUIGlobalThemeParameters();


    //qt palette
    QBrush windowTextActive         ;
    QBrush windowTextInactive       ;
    QBrush windowTextDisable        ;
    QBrush buttonActive             ;
    QBrush buttonInactive           ;
    QBrush buttonDisable            ;
    QBrush lightActive              ;
    QBrush lightInactive            ;
    QBrush lightDisable             ;
    QBrush midlightActive           ;
    QBrush midlightInactive         ;
    QBrush midlightDisable          ;
    QBrush darkActive               ;
    QBrush darkInactive             ;
    QBrush darkDisable              ;
    QBrush midActive                ;
    QBrush midInactive              ;
    QBrush midDisable               ;
    QBrush textActive               ;
    QBrush textInactive             ;
    QBrush textDisable              ;
    QBrush brightTextActive         ;
    QBrush brightTextInactive       ;
    QBrush brightTextDisable        ;
    QBrush buttonTextActive         ;
    QBrush buttonTextInactive       ;
    QBrush buttonTextDisable        ;
    QBrush baseActive               ;
    QBrush baseInactive             ;
    QBrush baseDisable              ;
    QBrush windowActive             ;
    QBrush windowInactive           ;
    QBrush windowDisable            ;
    QBrush shadowActive             ;
    QBrush shadowInactive           ;
    QBrush shadowDisable            ;
    QBrush highLightActive          ;
    QBrush highLightInactive        ;
    QBrush highLightDisable         ;
    QBrush highLightedTextActive    ;
    QBrush highLightedTextInactive  ;
    QBrush highLightedTextDisable   ;
    QBrush linkActive               ;
    QBrush linkInactive             ;
    QBrush linkDisable              ;
    QBrush linkVisitedActive        ;
    QBrush linkVisitedInactive      ;
    QBrush linkVisitedDisable       ;
    QBrush alternateBaseActive      ;
    QBrush alternateBaseInactive    ;
    QBrush alternateBaseDisable     ;
    QBrush noRoleActive             ;
    QBrush noRoleInactive           ;
    QBrush noRoleDisable            ;
    QBrush toolTipBaseActive        ;
    QBrush toolTipBaseInactive      ;
    QBrush toolTipBaseDisable       ;
    QBrush toolTipTextActive        ;
    QBrush toolTipTextInactive      ;
    QBrush toolTipTextDisable       ;
    QBrush placeholderTextActive    ;
    QBrush placeholderTextInactive  ;
    QBrush placeholderTextDisable   ;

    //custom palette
    QBrush kComponentNormal                 ;
    QBrush kLineBrandDisable                ;
    QBrush kFontWhiteSecondary              ;
    QBrush kGray12                          ;
    QBrush kContainSecondaryAlpphaNormal    ;
    QBrush kGray16                          ;
    QBrush kBrand1                          ;
    QBrush kLineComponentNormal             ;
    QBrush kLineBrandClick                  ;
    QBrush kGray3                           ;
    QBrush kGray0                           ;
    QBrush kLineDisable                     ;
    QBrush kGrayAlpha2                      ;
    QBrush kGrayAlpha0                      ;
    QBrush kBrand2                          ;
    QBrush kLineNormal                      ;
    QBrush kGrayAlpha5                      ;
    QBrush kGrayAlpha12                     ;
    QBrush kErrorClick                      ;
    QBrush kLineWindowActive                ;
    QBrush kComponentAlphaClick             ;
    QBrush kBrand3                          ;
    QBrush kSuccessNormal                   ;
    QBrush kGrayAlpha1                      ;
    QBrush kFontWhiteSecondaryDisable       ;
    QBrush kGray4                           ;
    QBrush kContainClick                    ;
    QBrush kGray8                           ;
    QBrush kGrayAlpha4                      ;
    QBrush kModalmask                       ;
    QBrush kLineBrandNormal                 ;
    QBrush kBrand5                          ;
    QBrush kGray10                          ;
    QBrush kWarningNormal                   ;
    QBrush kGray9                           ;
    QBrush kGray1                           ;
    QBrush kGray14                          ;
    QBrush kLineComponentClick              ;
    QBrush kWhite                           ;
    QBrush kGray7                           ;
    QBrush kBrandFocus                      ;
    QBrush kGrayAlpha9                      ;
    QBrush kGrayAlpha10                     ;
    QBrush kGrayAlpha6                      ;
    QBrush kContainHover                    ;
    QBrush kLineComponentDisable            ;
    QBrush kFontWhite                       ;
    QBrush kGrayAlpha11                     ;
    QBrush kGray6                           ;
    QBrush kFontWhiteDisable                ;
    QBrush kComponentDisable                ;
    QBrush kBlack                           ;
    QBrush kComponentAlphaDisable           ;
    QBrush kFontSecondaryDisable            ;
    QBrush kGrayAlpha8                      ;
    QBrush kFontPrimaryDisable              ;
    QBrush kGray5                           ;
    QBrush kFontSecondary                   ;
    QBrush kErrorNormal                     ;
    QBrush kComponentHover                  ;
    QBrush kComponentAlphaHover             ;
    QBrush kGrayAlpha3                      ;
    QBrush kGray13                          ;
    QBrush kGray11                          ;
    QBrush kErrorHover                      ;
    QBrush kContainGeneralNormal            ;
    QBrush kComponentAlphaNormal            ;
    QBrush kGray15                          ;
    QBrush kBrand7                          ;
    QBrush kGrayAlpha7                      ;
    QBrush kLineBrandHover                  ;
    QBrush kGrayAlpha13                     ;
    QBrush kLineComponentHover              ;
    QBrush kBrand6                          ;
    QBrush kGray17                          ;
    QBrush kComponentClick                  ;
    QBrush kBrandClick                      ;
    QBrush kFontStrong                      ;
    QBrush kLineWindow                      ;
    QBrush kGray2                           ;
    QBrush kBrand4                          ;
    QBrush kContainSecondaryNormal          ;
    QBrush kBrandHover                      ;
    QBrush kFontPrimary                     ;
    QBrush kBrandNormal                     ;

    //line and margin
    int normalline      = 1;
    int focusline       = 2;
    int tokenGap4       = 4;
    int tokenGap8       = 8;
    int tokenGap16      = 16;
    int tokenGap24      = 40;
    int tokenGap40      = 24;

    //radius
    int kradiusMin      = 4;
    int kradiusMenu     = 8;
    int kradiusNormal   = 6;
    int kradiusWindow   = 12;

    bool m_ukui_dt_loadConfig = false;
    QString m_cfgPath;
    QString m_widgetThemeName = "default";
    QString m_lightMode = "light";
    QString m_ukui_dt_path;
    QString m_dt_configData;
};

class GlobalDTConfig : public QObject
{
    Q_OBJECT

    //QT palette
    Q_PROPERTY(QBrush windowTextActive          READ windowTextActive           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush windowTextInactive        READ windowTextInactive         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush windowTextDisable         READ windowTextDisable          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush buttonActive              READ buttonActive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush buttonInactive            READ buttonInactive             NOTIFY tokenChanged)
    Q_PROPERTY(QBrush buttonDisable             READ buttonDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush lightActive               READ lightActive                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush lightInactive             READ lightInactive              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush lightDisable              READ lightDisable               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush midlightActive            READ midlightActive             NOTIFY tokenChanged)
    Q_PROPERTY(QBrush midlightInactive          READ midlightInactive           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush midlightDisable           READ midlightDisable            NOTIFY tokenChanged)
    Q_PROPERTY(QBrush darkActive                READ darkActive                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush darkInactive              READ darkInactive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush darkDisable               READ darkDisable                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush midActive                 READ midActive                  NOTIFY tokenChanged)
    Q_PROPERTY(QBrush midInactive               READ midInactive                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush midDisable                READ midDisable                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush textActive                READ textActive                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush textInactive              READ textInactive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush textDisable               READ textDisable                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush brightTextActive          READ brightTextActive           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush brightTextInactive        READ brightTextInactive         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush brightTextDisable         READ brightTextDisable          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush buttonTextActive          READ buttonTextActive           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush buttonTextInactive        READ buttonTextInactive         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush buttonTextDisable         READ buttonTextDisable          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush baseActive                READ baseActive                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush baseInactive              READ baseInactive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush baseDisable               READ baseDisable                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush windowActive              READ windowActive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush windowInactive            READ windowInactive             NOTIFY tokenChanged)
    Q_PROPERTY(QBrush windowDisable             READ windowDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush shadowActive              READ shadowActive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush shadowInactive            READ shadowInactive             NOTIFY tokenChanged)
    Q_PROPERTY(QBrush shadowDisable             READ shadowDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush highLightActive           READ highLightActive            NOTIFY tokenChanged)
    Q_PROPERTY(QBrush highLightInactive         READ highLightInactive          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush highLightDisable          READ highLightDisable           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush highLightedTextActive     READ highLightedTextActive      NOTIFY tokenChanged)
    Q_PROPERTY(QBrush highLightedTextInactive   READ highLightedTextInactive    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush highLightedTextDisable    READ highLightedTextDisable     NOTIFY tokenChanged)
    Q_PROPERTY(QBrush linkActive                READ linkActive                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush linkInactive              READ linkInactive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush linkDisable               READ linkDisable                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush linkVisitedActive         READ linkVisitedActive          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush linkVisitedInactive       READ linkVisitedInactive        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush linkVisitedDisable        READ linkVisitedDisable         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush alternateBaseActive       READ alternateBaseActive        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush alternateBaseInactive     READ alternateBaseInactive      NOTIFY tokenChanged)
    Q_PROPERTY(QBrush alternateBaseDisable      READ alternateBaseDisable       NOTIFY tokenChanged)
    Q_PROPERTY(QBrush noRoleActive              READ noRoleActive               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush noRoleInactive            READ noRoleInactive             NOTIFY tokenChanged)
    Q_PROPERTY(QBrush noRoleDisable             READ noRoleDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush toolTipBaseActive         READ toolTipBaseActive          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush toolTipBaseInactive       READ toolTipBaseInactive        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush toolTipBaseDisable        READ toolTipBaseDisable         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush toolTipTextActive         READ toolTipTextActive          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush toolTipTextInactive       READ toolTipTextInactive        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush toolTipTextDisable        READ toolTipTextDisable         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush placeholderTextActive     READ placeholderTextActive      NOTIFY tokenChanged)
    Q_PROPERTY(QBrush placeholderTextInactive   READ placeholderTextInactive    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush placeholderTextDisable    READ placeholderTextDisable     NOTIFY tokenChanged)

    //custom palette
    Q_PROPERTY(QBrush kBlack                        READ kBlack                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand1                       READ kBrand1                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand2                       READ kBrand2                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand3                       READ kBrand3                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand4                       READ kBrand4                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand5                       READ kBrand5                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand6                       READ kBrand6                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrand7                       READ kBrand7                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrandClick                   READ kBrandClick                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrandFocus                   READ kBrandFocus                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrandHover                   READ kBrandHover                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kBrandNormal                  READ kBrandNormal                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentAlphaClick          READ kComponentAlphaClick           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentAlphaDisable        READ kComponentAlphaDisable         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentAlphaHover          READ kComponentAlphaHover           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentAlphaNormal         READ kComponentAlphaNormal          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentClick               READ kComponentClick                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentDisable             READ kComponentDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentHover               READ kComponentHover                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kComponentNormal              READ kComponentNormal               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kContainClick                 READ kContainClick                  NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kContainHover                 READ kContainHover                  NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kContainGeneralNormal         READ kContainGeneralNormal          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kContainSecondaryAlpphaNormal READ kContainSecondaryAlpphaNormal  NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kContainSecondaryNormal       READ kContainSecondaryNormal        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kErrorClick                   READ kErrorClick                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kErrorHover                   READ kErrorHover                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kErrorNormal                  READ kErrorNormal                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontPrimary                  READ kFontPrimary                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontPrimaryDisable           READ kFontPrimaryDisable            NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontSecondary                READ kFontSecondary                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontSecondaryDisable         READ kFontSecondaryDisable          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontStrong                   READ kFontStrong                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontWhite                    READ kFontWhite                     NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontWhiteDisable             READ kFontWhiteDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontWhiteSecondary           READ kFontWhiteSecondary            NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kFontWhiteSecondaryDisable    READ kFontWhiteSecondaryDisable     NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray0                        READ kGray0                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray1                        READ kGray1                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray2                        READ kGray2                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray3                        READ kGray3                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray4                        READ kGray4                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray5                        READ kGray5                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray6                        READ kGray6                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray7                        READ kGray7                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray8                        READ kGray8                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray9                        READ kGray9                         NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray10                       READ kGray10                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray11                       READ kGray11                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray12                       READ kGray12                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray13                       READ kGray13                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray14                       READ kGray14                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray15                       READ kGray15                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray16                       READ kGray16                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGray17                       READ kGray17                        NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha0                   READ kGrayAlpha0                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha1                   READ kGrayAlpha1                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha2                   READ kGrayAlpha2                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha3                   READ kGrayAlpha3                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha4                   READ kGrayAlpha4                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha5                   READ kGrayAlpha5                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha6                   READ kGrayAlpha6                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha7                   READ kGrayAlpha7                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha8                   READ kGrayAlpha8                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha9                   READ kGrayAlpha9                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha10                  READ kGrayAlpha10                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha11                  READ kGrayAlpha11                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha12                  READ kGrayAlpha12                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kGrayAlpha13                  READ kGrayAlpha13                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineBrandClick               READ kLineBrandClick                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineBrandDisable             READ kLineBrandDisable              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineBrandHover               READ kLineBrandHover                NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineBrandNormal              READ kLineBrandNormal               NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineComponentClick           READ kLineComponentClick            NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineComponentDisable         READ kLineComponentDisable          NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineComponentHover           READ kLineComponentHover            NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineComponentNormal          READ kLineComponentNormal           NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineDisable                  READ kLineDisable                   NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineNormal                   READ kLineNormal                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineWindow                   READ kLineWindow                    NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kLineWindowActive             READ kLineWindowActive              NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kModalmask                    READ kModalmask                     NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kSuccessNormal                READ kSuccessNormal                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kWarningNormal                READ kWarningNormal                 NOTIFY tokenChanged)
    Q_PROPERTY(QBrush kWhite                        READ kWhite                         NOTIFY tokenChanged)

    //line and margin
    Q_PROPERTY(int normalline       READ normalline     NOTIFY tokenChanged)
    Q_PROPERTY(int focusline        READ focusline      NOTIFY tokenChanged)
    Q_PROPERTY(int tokenGap4        READ tokenGap4      NOTIFY tokenChanged)
    Q_PROPERTY(int tokenGap8        READ tokenGap8      NOTIFY tokenChanged)
    Q_PROPERTY(int tokenGap16       READ tokenGap16     NOTIFY tokenChanged)
    Q_PROPERTY(int tokenGap24       READ tokenGap24     NOTIFY tokenChanged)
    Q_PROPERTY(int tokenGap40       READ tokenGap40     NOTIFY tokenChanged)

    //radius
    Q_PROPERTY(int kradiusMin       READ kradiusMin     NOTIFY tokenChanged)
    Q_PROPERTY(int kradiusMenu      READ kradiusMenu    NOTIFY tokenChanged)
    Q_PROPERTY(int kradiusNormal    READ kradiusNormal  NOTIFY tokenChanged)
    Q_PROPERTY(int kradiusWindow    READ kradiusWindow  NOTIFY tokenChanged)

public:
    explicit GlobalDTConfig();
    ~GlobalDTConfig();

    //QT palette
    QBrush windowTextActive() const;
    QBrush windowTextInactive() const;
    QBrush windowTextDisable() const;
    QBrush buttonActive() const;
    QBrush buttonInactive() const;
    QBrush buttonDisable() const;
    QBrush lightActive() const;
    QBrush lightInactive() const;
    QBrush lightDisable() const;
    QBrush midlightActive() const;
    QBrush midlightInactive() const;
    QBrush midlightDisable() const;
    QBrush darkActive() const;
    QBrush darkInactive() const;
    QBrush darkDisable() const;
    QBrush midActive() const;
    QBrush midInactive() const;
    QBrush midDisable() const;
    QBrush textActive() const;
    QBrush textInactive() const;
    QBrush textDisable() const;
    QBrush brightTextActive() const;
    QBrush brightTextInactive() const;
    QBrush brightTextDisable() const;
    QBrush buttonTextActive() const;
    QBrush buttonTextInactive() const;
    QBrush buttonTextDisable() const;
    QBrush baseActive() const;
    QBrush baseInactive() const;
    QBrush baseDisable() const;
    QBrush windowActive() const;
    QBrush windowInactive() const;
    QBrush windowDisable() const;
    QBrush shadowActive() const;
    QBrush shadowInactive() const;
    QBrush shadowDisable() const;
    QBrush highLightActive() const;
    QBrush highLightInactive() const;
    QBrush highLightDisable() const;
    QBrush highLightedTextActive() const;
    QBrush highLightedTextInactive() const;
    QBrush highLightedTextDisable() const;
    QBrush linkActive() const;
    QBrush linkInactive() const;
    QBrush linkDisable() const;
    QBrush linkVisitedActive() const;
    QBrush linkVisitedInactive() const;
    QBrush linkVisitedDisable() const;
    QBrush alternateBaseActive() const;
    QBrush alternateBaseInactive() const;
    QBrush alternateBaseDisable() const;
    QBrush noRoleActive() const;
    QBrush noRoleInactive() const;
    QBrush noRoleDisable() const;
    QBrush toolTipBaseActive() const;
    QBrush toolTipBaseInactive() const;
    QBrush toolTipBaseDisable() const;
    QBrush toolTipTextActive() const;
    QBrush toolTipTextInactive() const;
    QBrush toolTipTextDisable() const;
    QBrush placeholderTextActive() const;
    QBrush placeholderTextInactive() const;
    QBrush placeholderTextDisable() const;

    //custompalette
    QBrush kBlack() const;
    QBrush kBrand1() const;
    QBrush kBrand2() const;
    QBrush kBrand3() const;
    QBrush kBrand4() const;
    QBrush kBrand5() const;
    QBrush kBrand6() const;
    QBrush kBrand7() const;
    QBrush kBrandClick() const;
    QBrush kBrandFocus() const;
    QBrush kBrandHover() const;
    QBrush kBrandNormal() const;
    QBrush kComponentAlphaClick() const;
    QBrush kComponentAlphaDisable() const;
    QBrush kComponentAlphaHover() const;
    QBrush kComponentAlphaNormal() const;
    QBrush kComponentClick() const;
    QBrush kComponentDisable() const;
    QBrush kComponentHover() const;
    QBrush kComponentNormal() const;
    QBrush kContainClick() const;
    QBrush kContainHover() const;
    QBrush kContainGeneralNormal() const;
    QBrush kContainSecondaryAlpphaNormal() const;
    QBrush kContainSecondaryNormal() const;
    QBrush kErrorClick() const;
    QBrush kErrorHover() const;
    QBrush kErrorNormal() const;
    QBrush kFontPrimary() const;
    QBrush kFontPrimaryDisable() const;
    QBrush kFontSecondary() const;
    QBrush kFontSecondaryDisable() const;
    QBrush kFontStrong() const;
    QBrush kFontWhite() const;
    QBrush kFontWhiteDisable() const;
    QBrush kFontWhiteSecondary() const;
    QBrush kFontWhiteSecondaryDisable() const;
    QBrush kGray0() const;
    QBrush kGray1() const;
    QBrush kGray2() const;
    QBrush kGray3() const;
    QBrush kGray4() const;
    QBrush kGray5() const;
    QBrush kGray6() const;
    QBrush kGray7() const;
    QBrush kGray8() const;
    QBrush kGray9() const;
    QBrush kGray10() const;
    QBrush kGray11() const;
    QBrush kGray12() const;
    QBrush kGray13() const;
    QBrush kGray14() const;
    QBrush kGray15() const;
    QBrush kGray16() const;
    QBrush kGray17() const;
    QBrush kGrayAlpha0() const;
    QBrush kGrayAlpha1() const;
    QBrush kGrayAlpha2() const;
    QBrush kGrayAlpha3() const;
    QBrush kGrayAlpha4() const;
    QBrush kGrayAlpha5() const;
    QBrush kGrayAlpha6() const;
    QBrush kGrayAlpha7() const;
    QBrush kGrayAlpha8() const;
    QBrush kGrayAlpha9() const;
    QBrush kGrayAlpha10() const;
    QBrush kGrayAlpha11() const;
    QBrush kGrayAlpha12() const;
    QBrush kGrayAlpha13() const;
    QBrush kLineBrandClick() const;
    QBrush kLineBrandDisable() const;
    QBrush kLineBrandHover() const;
    QBrush kLineBrandNormal() const;
    QBrush kLineComponentClick() const;
    QBrush kLineComponentDisable() const;
    QBrush kLineComponentHover() const;
    QBrush kLineComponentNormal() const;
    QBrush kLineDisable() const;
    QBrush kLineNormal() const;
    QBrush kLineWindow() const;
    QBrush kLineWindowActive() const;
    QBrush kModalmask() const;
    QBrush kSuccessNormal() const;
    QBrush kWarningNormal() const;
    QBrush kWhite() const;

    //line and margin
    int normalline() const;
    int focusline() const;
    int tokenGap4() const;
    int tokenGap8() const;
    int tokenGap16() const;
    int tokenGap24() const;
    int tokenGap40() const;

    //radius
    int kradiusMin() const;
    int kradiusMenu() const;
    int kradiusNormal() const;
    int kradiusWindow() const;

Q_SIGNALS:
    void tokenChanged();

private:

    GlobalDTConfigPrivate *d {nullptr};
};

}

#endif // READCONFIG_H
